@@ -1,29 +1,7 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file dmdbushandler.cpp
- *
- * @brief 数据接口类，通过dbus与后端服务进行通信
- *
- * @date 2020-09-03 16:46
- *
- * Author: yuandandan  <yuandandan@uniontech.com>
- *
- * Maintainer: yuandandan  <yuandandan@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
 #include "dmdbushandler.h"
 
 #include <QObject>
@@ -74,6 +52,14 @@ DMDbusHandler::DMDbusHandler(QObject *parent)
     qDBusRegisterMetaType<QList<PVData>>();
     qDBusRegisterMetaType<QList<LVAction>>();
 
+    //注册结构体 luks dbus通信使用
+    qDBusRegisterMetaType<LUKS_INFO>();
+    qDBusRegisterMetaType<LUKS_MapperInfo>();
+    qDBusRegisterMetaType<CRYPT_CIPHER_Support>();
+    qDBusRegisterMetaType<LUKSInfoMap>();
+    qDBusRegisterMetaType<LUKSMap>();
+    qDBusRegisterMetaType<WipeAction>();
+
     m_dbus = new DMDBusInterface("com.deepin.diskmanager", "/com/deepin/diskmanager",
                                  QDBusConnection::systemBus(), this);
     //Note: when dealing with remote objects, it is not always possible to determine if it exists when creating a QDBusInterface.
@@ -91,6 +77,7 @@ void DMDbusHandler::initConnection()
     connect(m_dbus, &DMDBusInterface::MessageReport, this, &DMDbusHandler::onMessageReport);
     //  connect(m_dbus, &DMDBusInterface::sigUpdateDeviceInfo, this, &DMDbusHandler::sigUpdateDeviceInfo);
     connect(m_dbus, &DMDBusInterface::updateDeviceInfo, this, &DMDbusHandler::onUpdateDeviceInfo);
+    connect(m_dbus, &DMDBusInterface::updateLUKSInfo, this, &DMDbusHandler::onUpdateLUKSInfo);
     connect(m_dbus, &DMDBusInterface::unmountPartition, this, &DMDbusHandler::onUnmountPartition);
     connect(m_dbus, &DMDBusInterface::deletePartition, this, &DMDbusHandler::onDeletePartition);
     connect(m_dbus, &DMDBusInterface::hidePartitionInfo, this, &DMDbusHandler::onHidePartition);
@@ -106,6 +93,8 @@ void DMDbusHandler::initConnection()
     connect(m_dbus, &DMDBusInterface::pvDeleteMessage, this, &DMDbusHandler::pvDeleteMessage);
     connect(m_dbus, &DMDBusInterface::vgDeleteMessage, this, &DMDbusHandler::vgDeleteMessage);
     connect(m_dbus, &DMDBusInterface::lvDeleteMessage, this, &DMDbusHandler::lvDeleteMessage);
+    connect(m_dbus, &DMDBusInterface::deCryptMessage, this, &DMDbusHandler::deCryptMessage);
+    connect(m_dbus, &DMDBusInterface::createFailedMessage, this, &DMDbusHandler::createFailedMessage);
 //    connect(m_dbus, &DMDBusInterface::rootLogin, this, &DMDbusHandler::onRootLogin);
 }
 
@@ -326,6 +315,8 @@ void DMDbusHandler::onUpdateDeviceInfo(const DeviceInfoMap &infoMap, const LVMIn
 //                 << info.m_cylinders << info.m_cylsize << info.m_model << info.m_serialNumber << info.m_disktype
 //                 << info.m_sectorSize << info.m_maxPrims << info.m_highestBusy << info.m_readonly
 //                 << info.m_maxPartitionNameLength << info.m_mediaType << info.m_interface << info.m_vgFlag;
+
+        m_cryptSupport = info.m_crySupport;
         if (info.m_path.isEmpty() || info.m_path.contains("/dev/mapper")) {
             continue;
         }
@@ -333,15 +324,20 @@ void DMDbusHandler::onUpdateDeviceInfo(const DeviceInfoMap &infoMap, const LVMIn
         m_deviceNameList << info.m_path;
         QString isExistUnallocated = "false";
         QString isJoinAllVG = "true";
+        QString isAllEncryption = "true";
         for (auto it = info.m_partition.begin(); it != info.m_partition.end(); it++) {
 //                    qDebug() << it->m_path << it->m_devicePath << it->m_partitionNumber << it->m_sectorsUsed << it->m_sectorsUnused << it->m_sectorStart << it->m_sectorEnd;
-           if (it->m_path == "unallocated") {
-               isExistUnallocated = "true";
-           }
+            if (it->m_path == "unallocated") {
+                isExistUnallocated = "true";
+            }
 
-           if (it->m_vgFlag == LVMFlag::LVM_FLAG_NOT_PV) {
-               isJoinAllVG = "false";
-           }
+            if (it->m_vgFlag == LVMFlag::LVM_FLAG_NOT_PV) {
+                isJoinAllVG = "false";
+            }
+
+            if (it->m_luksFlag == LUKSFlag::NOT_CRYPT_LUKS) {
+                isAllEncryption = "false";
+            }
         }
 
         if (("unrecognized" == info.m_disktype || "none" == info.m_disktype) && (info.m_vgFlag != LVMFlag::LVM_FLAG_NOT_PV)) {
@@ -353,8 +349,13 @@ void DMDbusHandler::onUpdateDeviceInfo(const DeviceInfoMap &infoMap, const LVMIn
             isJoinAllVG = "false";
         }
 
+        if (info.m_partition.size() == 0 && info.m_luksFlag == LUKSFlag::NOT_CRYPT_LUKS) {
+            isAllEncryption = "false";
+        }
+
         m_isExistUnallocated[info.m_path] = isExistUnallocated;
         m_isJoinAllVG[info.m_path] = isJoinAllVG;
+        m_isAllEncryption[info.m_path] = isAllEncryption;
     }
 
     QMap<QString, VGInfo> lstVGInfo = lvmInfo.m_vgInfo;
@@ -367,20 +368,31 @@ void DMDbusHandler::onUpdateDeviceInfo(const DeviceInfoMap &infoMap, const LVMIn
 
         m_vgNameList << vgInformation.m_vgName;
         QString isExistUnallocated = "false";
+        QString isAllEncryption = "true";
         for (int i = 0; i < vgInformation.m_lvlist.count(); i++) {
             LVInfo info = vgInformation.m_lvlist.at(i);
             if (info.m_lvName.isEmpty() && info.m_lvUuid.isEmpty()) {
                 isExistUnallocated = "true";
             }
+
+            if (info.m_luksFlag == LUKSFlag::NOT_CRYPT_LUKS) {
+                isAllEncryption = "false";
+            }
         }
 
         m_isExistUnallocated[vgInformation.m_vgName] = isExistUnallocated;
+        m_isAllEncryption[vgInformation.m_vgName] = isAllEncryption;
     }
 
     emit updateDeviceInfo();
     emit showSpinerWindow(false, "");
 }
 
+void DMDbusHandler::onUpdateLUKSInfo(const LUKSMap &infomap)
+{
+    m_curLUKSInfoMap = infomap;
+}
+
 QMap<QString, QString> DMDbusHandler::getIsExistUnallocated()
 {
     return m_isExistUnallocated;
@@ -514,9 +526,9 @@ QString DMDbusHandler::getCurDevicePath()
     return m_curDevicePath;
 }
 
-void DMDbusHandler::clear(const QString &fstype, const QString &path , const QString &name, const QString &user, const int &diskType , const int &clearType)
+void DMDbusHandler::clear(const WipeAction &wipe)
 {
-    m_dbus->clear(fstype, path, name, user, diskType, clearType);
+    m_dbus->clear(wipe);
 }
 
 const LVMInfo &DMDbusHandler::probLVMInfo() const
@@ -551,22 +563,60 @@ QMap<QString, QString> DMDbusHandler::getIsJoinAllVG()
 
 bool DMDbusHandler::isExistMountLV(const VGInfo &info)
 {
-    bool isExist = false;
-
     for (int i = 0; i < info.m_lvlist.count(); i++) {
-        LVInfo lvInfo = info.m_lvlist.at(i);
-        QString mountPoint = "";
-        for (int j = 0; j < lvInfo.m_mountPoints.size(); j++) {
-            mountPoint += lvInfo.m_mountPoints[j];
-        }
-
-        if (!mountPoint.isEmpty()){
-            isExist = true;
-            break;
+        if (lvIsMount(info.m_lvlist.at(i))) {
+            return true;
         }
     }
 
-    return isExist;
+    return false;
+}
+
+bool DMDbusHandler::lvIsMount(const LVInfo &lvInfo)
+{
+    if (lvInfo.m_luksFlag == LUKSFlag::IS_CRYPT_LUKS) {
+        LUKS_INFO luksInfo = probLUKSInfo().m_luksMap.value(lvInfo.m_lvPath);
+        if (luksInfo.isDecrypt) {
+            if (!luksInfo.m_mapper.m_mountPoints.isEmpty()) {
+                return true;
+            }
+        }
+    } else {
+        if (!lvInfo.m_mountPoints.isEmpty()) {
+            return true;
+        }
+    }
+
+    return false;
+}
+
+bool DMDbusHandler::isExistMountPartition(const DeviceInfo &info)
+{
+    for (int i = 0; i < info.m_partition.size(); i++) {
+        if (partitionISMount(info.m_partition.at(i))) {
+            return true;
+        }
+    }
+
+    return false;
+}
+
+bool DMDbusHandler::partitionISMount(const PartitionInfo &info)
+{
+    if (info.m_luksFlag == LUKSFlag::IS_CRYPT_LUKS) {
+        LUKS_INFO luksInfo = probLUKSInfo().m_luksMap.value(info.m_path);
+        if (luksInfo.isDecrypt) {
+            if (!luksInfo.m_mapper.m_mountPoints.isEmpty()) {
+                return true;
+            }
+        }
+    } else {
+        if (!info.m_mountPoints.isEmpty()) {
+            return true;
+        }
+    }
+
+    return false;
 }
 
 void DMDbusHandler::createVG(const QString &vgName, const QList<PVData> &devList, const long long &size)
@@ -631,3 +681,180 @@ void DMDbusHandler::onDeletePVList(QList<PVData> devList)
     m_dbus->onDeletePVList(devList);
 }
 
+QStringList DMDbusHandler::getEncryptionFormate(const QStringList &formateList)
+{
+    bool isSupportAES = m_cryptSupport.supportEncrypt(m_cryptSupport.aes_xts_plain64);
+    bool isSupportSM4 = m_cryptSupport.supportEncrypt(m_cryptSupport.sm4_xts_plain64);
+
+    QStringList lstFormate;
+    for (int i = 0; i < formateList.count(); ++i) {
+        lstFormate << formateList.at(i);
+        if (isSupportAES) {
+            lstFormate << QString("%1 (%2)").arg(formateList.at(i)).arg(tr("AES Encryption"));
+            if (isSupportSM4) {
+                lstFormate << QString("%1 (%2)").arg(formateList.at(i)).arg(tr("SM4 Encryption"));
+            }
+        }
+    }
+
+    return lstFormate;
+}
+
+const LUKSMap &DMDbusHandler::probLUKSInfo() const
+{
+    return m_curLUKSInfoMap;
+}
+
+void DMDbusHandler::updateLUKSInfo(const QString &devPath, const LUKS_INFO &luks)
+{
+    m_curLUKSInfoMap.m_luksMap[devPath] = luks;
+}
+
+bool DMDbusHandler::getIsSystemDisk(const QString &devName)
+{
+    if (m_curLevel == DeviceType::DISK || m_curLevel == DeviceType::PARTITION) {
+        DeviceInfo devInfo = m_deviceMap.value(devName);
+        for (int i = 0; i < devInfo.m_partition.size(); ++i) {
+            PartitionInfo partitionInfo = devInfo.m_partition.at(i);
+            if (partitionInfo.m_flag == 4) {
+                return true;
+            }
+
+            for (int j = 0; j < partitionInfo.m_mountPoints.size(); ++j) {
+                if (partitionInfo.m_mountPoints[j] == "/boot/efi" || partitionInfo.m_mountPoints[j] == "/"
+                        || partitionInfo.m_mountPoints[j] == "/recovery" || partitionInfo.m_mountPoints[j] == "/boot") {
+                    return true;
+                }
+            }
+        }
+    } else if (m_curLevel == DeviceType::VOLUMEGROUP || m_curLevel == DeviceType::LOGICALVOLUME) {
+        VGInfo vgInfo = m_lvmInfo.m_vgInfo.value(devName);
+        for (int i = 0; i < vgInfo.m_lvlist.size(); ++i) {
+            LVInfo lvInfo = vgInfo.m_lvlist.at(i);
+            for (int j = 0; j < lvInfo.m_mountPoints.size(); ++j) {
+                if (lvInfo.m_mountPoints[j] == "/boot/efi" || lvInfo.m_mountPoints[j] == "/"
+                        || lvInfo.m_mountPoints[j] == "/recovery" || lvInfo.m_mountPoints[j] == "/boot") {
+                    return true;
+                }
+            }
+        }
+    }
+
+    return false;
+}
+
+void DMDbusHandler::deCrypt(const LUKS_INFO &luks)
+{
+    m_dbus->deCrypt(luks);
+}
+
+void DMDbusHandler::cryptMount(const LUKS_INFO &luks, const QString &devName)
+{
+    emit showSpinerWindow(true, tr("Mounting %1 ...").arg(devName));
+
+    m_dbus->cryptMount(luks);
+}
+
+void DMDbusHandler::cryptUmount(const LUKS_INFO &luks, const QString &devName)
+{
+    emit showSpinerWindow(true, tr("Unmounting %1 ...").arg(devName));
+
+    m_dbus->cryptUmount(luks);
+}
+
+QMap<QString, QString> DMDbusHandler::getIsAllEncryption()
+{
+    return m_isAllEncryption;
+}
+
+void DMDbusHandler::refreshMainWindowData()
+{
+    emit curSelectChanged();
+}
+
+QString DMDbusHandler::getFailedMessage(const QString &key, const int &value, const QString &devPath)
+{
+    QString failedMessage = "";
+    if (key == "CRYPTError") {
+        switch (value) {
+        case CRYPTError::CRYPT_ERR_ENCRYPT_FAILED: {
+            failedMessage = tr("Failed to encrypt %1, please try again!").arg(devPath);
+            break;
+        }
+        case CRYPTError::CRYPT_ERR_DECRYPT_FAILED: {
+            failedMessage = tr("Failed to decrypt %1, please try again!").arg(devPath);
+            break;
+        }
+        case CRYPTError::CRYPT_ERR_CLOSE_FAILED: {
+            failedMessage = tr("%1 failed to close the crypto map").arg(devPath);
+            break;
+        }
+        }
+    } else if (key == "DISK_ERROR") {
+        switch (value) {
+        case DISK_ERROR::DISK_ERR_CREATE_PART_FAILED: {
+            failedMessage = tr("Failed to create partitions, please try again!");
+            break;
+        }
+        case DISK_ERROR::DISK_ERR_CREATE_FS_FAILED: {
+            failedMessage = tr("Failed to create %1 file system, please try again!").arg(devPath);
+            break;
+        }
+        case DISK_ERROR::DISK_ERR_UPDATE_KERNEL_FAILED: {
+            failedMessage = tr("Failed to submit the request to the kernel");
+            break;
+        }
+        case DISK_ERROR::DISK_ERR_DBUS_ARGUMENT: {
+            failedMessage = tr("DBUS parameter error");
+            break;
+        }
+        case DISK_ERROR::DISK_ERR_MOUNT_FAILED: {
+            failedMessage = tr("Failed to mount %1").arg(devPath);
+            break;
+        }
+        case DISK_ERROR::DISK_ERR_CREATE_MOUNTDIR_FAILED: {
+            failedMessage = tr("%1 failed to create mounting folders").arg(devPath);
+            break;
+        }
+        case DISK_ERROR::DISK_ERR_CHOWN_FAILED: {
+            failedMessage = tr("%1 failed to change the owner of mounting folders").arg(devPath);
+            break;
+        }
+        case DISK_ERROR::DISK_ERR_CREATE_PARTTAB_FAILED: {
+            failedMessage = tr("Creating partition table failed");
+            break;
+        }
+        }
+    } else if (key == "LVMError") {
+        switch (value) {
+        case LVMError::LVM_ERR_LV_CREATE_FAILED: {
+            failedMessage = tr("Failed to create a logical volume, please try again!");
+            break;
+        }
+        case LVMError::LVM_ERR_LV_CREATE_FS_FAILED: {
+            failedMessage = tr("Failed to create %1 file system, please try again!").arg(devPath);
+            break;
+        }
+        case LVMError::LVM_ERR_LV_ARGUMENT: {
+            failedMessage = tr("DBUS parameter error");
+            break;
+        }
+        }
+    }
+
+    return failedMessage;
+}
+
+QString DMDbusHandler::getEncryptionFsType(const LUKS_INFO &luksInfo)
+{
+    if (luksInfo.isDecrypt) {
+        if (luksInfo.m_crypt == CRYPT_CIPHER::AES_XTS_PLAIN64) {
+            return QString("%1 (%2)").arg(Utils::fileSystemTypeToString(luksInfo.m_mapper.m_luksFs)).arg(tr("AES Encryption"));
+        } else if (luksInfo.m_crypt == CRYPT_CIPHER::SM4_XTS_PLAIN64){
+            return QString("%1 (%2)").arg(Utils::fileSystemTypeToString(luksInfo.m_mapper.m_luksFs)).arg(tr("SM4 Encryption"));
+        }
+    }
+
+    return Utils::fileSystemTypeToString(FSType::FS_LUKS);
+}
+
