@@ -1,29 +1,7 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file dmdbushandler.h
- *
- * @brief 数据接口类，通过dbus与后端服务进行通信
- *
- * @date 2020-09-03 16:46
- *
- * Author: yuandandan  <yuandandan@uniontech.com>
- *
- * Maintainer: yuandandan  <yuandandan@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
 #ifndef DMDBUSHANDLER_H
 #define DMDBUSHANDLER_H
 
@@ -249,15 +227,10 @@ public:
     QString getCurDevicePath();
 
     /**
-     * @brief 擦除
-     * @param type 分区类型
-     * @param path 磁盘或分区路径
-     * @param name 劵标名
-     * @param user 当前用户名
-     * @param diskType 磁盘或者分区类型 0是磁盘 1是分区
-     * @param clearType 擦除标准 1为快速 2安全 3为安全擦除7次 4为安全擦除35次
-     */
-    void clear(const QString &fstype, const QString &path, const QString &name,const QString &user, const int &diskType, const int &clearType);
+    * @brief 擦除
+    * @param wipe 擦除信息
+    */
+    void clear(const WipeAction &wipe);
 
     /**
      * @brief 获取所有逻辑卷信息
@@ -298,6 +271,26 @@ public:
      */
     bool isExistMountLV(const VGInfo &info);
 
+    /**
+     * @brief 判断LV是否被挂载
+     * @param lvInfo lv信息
+     * @return 挂载返回true，否则返回false
+     */
+    bool lvIsMount(const LVInfo &lvInfo);
+
+    /**
+     * @brief 判断当前磁盘是否存在已被挂载分区
+     * @return 存在返回true，否则返回false
+     */
+    bool isExistMountPartition(const DeviceInfo &info);
+
+    /**
+     * @brief 判断分区是否被挂载
+     * @param info 分区信息
+     * @return 挂载返回true，否则返回false
+     */
+    bool partitionISMount(const PartitionInfo &info);
+
     /**
      * @brief 创建vg
      * @param vgName:待创建vg名称
@@ -363,6 +356,78 @@ public:
      */
     void onDeletePVList(QList<PVData>devList);
 
+    /**
+     * @brief 获取加密格式
+     * @param formateList: 当前支持的文件系统
+     * @return 加密格式文件系统
+     */
+    QStringList getEncryptionFormate(const QStringList &formateList);
+
+    /**
+     * @brief 获取所有加密盘信息
+     */
+    const LUKSMap &probLUKSInfo() const;
+
+    /**
+     * @brief 更新加密磁盘数据
+     * @param devPath 设备路径
+     * @param luks 加密磁盘属性
+     */
+    void updateLUKSInfo(const QString &devPath, const LUKS_INFO &luks);
+
+    /**
+     * @brief 获取是否为系统盘
+     * @param devName: 设备名称
+     * @return true是,false不是
+     */
+    bool getIsSystemDisk(const QString &devName);
+
+    /**
+     * @brief 加密磁盘解密
+     * @param luks 加密磁盘属性
+     */
+    void deCrypt(const LUKS_INFO &luks);
+
+    /**
+     * @brief 加密磁盘挂载
+     * @param luks 加密磁盘属性
+     * @param devName 设备名称
+     */
+    void cryptMount(const LUKS_INFO &luks, const QString &devName);
+
+    /**
+     * @brief 加密磁盘卸载
+     * @param luks 加密磁盘属性
+     * @param devName 设备名称
+     */
+    void cryptUmount(const LUKS_INFO &luks, const QString &devName);
+
+    /**
+     * @brief 获取是否全部加密
+     * @return 返回是否全部加密
+     */
+    QMap<QString, QString> getIsAllEncryption();
+
+    /**
+     * @brief 刷新主界面显示数据
+     */
+    void refreshMainWindowData();
+
+    /**
+     * @brief 获取失败提示信息
+     * @param key 枚举信息
+     * @param value 枚举值
+     * @param devPath 设备路径
+     */
+    QString getFailedMessage(const QString &key, const int &value, const QString &devPath);
+
+    /**
+     * @brief 获取加密文件系统类型
+     * @param luksInfo 加密信息
+     * @return 加密文件系统类型
+     */
+    QString getEncryptionFsType(const LUKS_INFO &luksInfo);
+
 private:
     explicit DMDbusHandler(QObject *parent = nullptr);
 
@@ -392,6 +457,8 @@ signals:
     void pvDeleteMessage(const QString &pvMessage);
     void vgDeleteMessage(const QString &vgMessage);
     void lvDeleteMessage(const QString &lvMessage);
+    void deCryptMessage(const LUKS_INFO &luks);
+    void createFailedMessage(const QString &message);
 
 public slots:
     /**
@@ -415,9 +482,16 @@ private slots:
     /**
      * @brief 数据更新信号响应的槽函数
      * @param infoMap 设备信息
+     * @param lvmInfo LVM信息
      */
     void onUpdateDeviceInfo(const DeviceInfoMap &infoMap, const LVMInfo &lvmInfo);
 
+    /**
+     * @brief 加密设备数据更新信号响应的槽函数
+     * @param infomap：所有加密设备分区信息
+     */
+    void onUpdateLUKSInfo(const LUKSMap &infomap);
+
     /**
      * @brief 接收卸载分区返回执行结果的槽函数
      * @param unmountMessage 执行结果
@@ -477,6 +551,9 @@ private:
     LVInfo m_curLVInfo;
     VGInfo m_curVGInfo;
     QMap<QString, QString> m_isJoinAllVG;
+    LUKSMap m_curLUKSInfoMap;
+    CRYPT_CIPHER_Support m_cryptSupport;
+    QMap<QString, QString> m_isAllEncryption;
 };
 
 #endif // DMDBUSHANDLER_H
