@@ -1,31 +1,14 @@
-/**
- * @copyright 2020-2022 Uniontech Technology Co., Ltd.
- *
- * @file createlvwidget.cpp
- *
- * @brief 创建逻辑卷窗口
- *
- * @date 2022-01-25 14:54
- *
- * Author: yuandandan  <yuandandan@uniontech.com>
- *
- * Maintainer: yuandandan  <yuandandan@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
+
 #include "createlvwidget.h"
 #include "common.h"
+#include "customcontrol/passwordinputdialog.h"
+#include "messagebox.h"
+
+#include <DScrollArea>
 
 #include <QDebug>
 #include <QApplication>
@@ -50,7 +33,7 @@ void CreateLVWidget::initUi()
     VGInfo vgInfo = DMDbusHandler::instance()->getCurVGInfo();
     setTitle(tr("Creating logical volumes on %1").arg(vgInfo.m_vgName));
 
-    DLabel *tipLabel = new DLabel(tr("Click ‘+’ to create a logical volume. "), m_mainFrame);
+    DLabel *tipLabel = new DLabel(QString(tr("Click %1 to create a logical volume. ")).arg("+"), m_mainFrame);
     tipLabel->setWordWrap(true);
     tipLabel->setAlignment(Qt::AlignCenter);
 
@@ -112,7 +95,7 @@ void CreateLVWidget::topFrameSetting()
     hLayout->setSpacing(5);
     hLayout->setContentsMargins(30, 0, 0, 0);
     DLabel *picLabel = new DLabel(m_topFrame);
-    picLabel->setPixmap(Common::getIcon("disk").pixmap(85, 85));
+    picLabel->setPixmap(Common::getIcon("vg").pixmap(85, 85));
     picLabel->setMinimumSize(85, 85);
     //垂直布局-右侧三行标签
     QVBoxLayout *vLayout = new QVBoxLayout();
@@ -265,6 +248,11 @@ void CreateLVWidget::partInfoShowing()
 {
     auto formateList = DMDbusHandler::instance()->getAllSupportFileSystem();
     formateList.removeOne("linux-swap");
+    //lvm暂时不支持加密
+//    if (!DMDbusHandler::instance()->getIsSystemDisk(DMDbusHandler::instance()->getCurVGInfo().m_vgName)) {
+//        formateList = DMDbusHandler::instance()->getEncryptionFormate(formateList);
+//    }
+
     //整体垂直布局-三行
     QVBoxLayout *vLayout = new QVBoxLayout(m_partWidget);
     //第一行
@@ -322,13 +310,13 @@ void CreateLVWidget::partInfoShowing()
     line2Layout->addWidget(m_partNameEdit, 7);
     //第三行
     QHBoxLayout *line3Layout = new QHBoxLayout();
-    DLabel *partFormateLabel = new DLabel(tr("LV file system:"), m_partWidget);
-    DFontSizeManager::instance()->bind(partFormateLabel, DFontSizeManager::T8, QFont::Normal);
-    partFormateLabel->setPalette(infoPalette);
+    m_partFormateLabel = new DLabel(tr("LV file system:"), m_partWidget);
+    DFontSizeManager::instance()->bind(m_partFormateLabel, DFontSizeManager::T8, QFont::Normal);
+    m_partFormateLabel->setPalette(infoPalette);
 
     m_partFormateCombox = new DComboBox(m_partWidget);
     m_partFormateCombox->addItems(formateList);
-    m_partFormateCombox->setCurrentIndex(2);
+    m_partFormateCombox->setCurrentText("ext4");
     m_partFormateCombox->setAccessibleName("File system");
 
     DLabel *partSizeLabel = new DLabel(tr("LV capacity:"), m_partWidget);
@@ -348,7 +336,7 @@ void CreateLVWidget::partInfoShowing()
     m_partComboBox->setCurrentText("GiB");
     m_partComboBox->setAccessibleName("unit");
 
-    line3Layout->addWidget(partFormateLabel, 1);
+    line3Layout->addWidget(m_partFormateLabel, 1);
     line3Layout->addWidget(m_partFormateCombox, 7);
     line3Layout->addWidget(space, 1);
     line3Layout->addWidget(partSizeLabel);
@@ -356,10 +344,46 @@ void CreateLVWidget::partInfoShowing()
     line3Layout->addWidget(m_partSizeEdit, 3);
     line3Layout->addWidget(m_partComboBox, 2);
 
+    // 第四行
+    DPalette palette;
+    palette.setColor(DPalette::Text, QColor("#526a7f"));
+
+    QFont font;
+    font.setWeight(QFont::Normal);
+    font.setFamily("Source Han Sans");
+    font.setPixelSize(12);
+
+    m_emptyLabel = new DLabel(m_partWidget);
+    m_emptyLabel->setFixedWidth(m_partFormateLabel->fontMetrics().width(tr("LV file system:")));
+    m_encryptionInfo = new DLabel(m_partWidget);
+    m_encryptionInfo->setFont(font);
+    m_encryptionInfo->setPalette(palette);
+    m_encryptionInfo->adjustSize();
+    m_encryptionInfo->setWordWrap(true);
+    m_encryptionInfo->setAlignment(Qt::AlignTop);
+    m_encryptionInfo->setAccessibleName("encryptionInfo");
+
+    m_scrollArea = new DScrollArea;
+    m_scrollArea->setFrameShadow(QFrame::Plain);
+    m_scrollArea->setFrameShape(QFrame::NoFrame);
+    m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);//隐藏横向滚动条
+    m_scrollArea->setWidget(m_encryptionInfo);
+
+    // 设置滚动区域背景颜色为透明
+    QPalette areaPalette;
+    areaPalette.setColor(QPalette::Base, QColor(255, 255, 255, 0));
+    m_scrollArea->setPalette(areaPalette);
+
+    QHBoxLayout *line4Layout = new QHBoxLayout();
+    line4Layout->addWidget(m_emptyLabel, 1);
+    line4Layout->addWidget(m_scrollArea, 7);
+    line4Layout->addStretch();
+
     vLayout->addWidget(m_partInfoLabel);
     vLayout->addLayout(line2Layout);
     vLayout->addSpacing(4);
     vLayout->addLayout(line3Layout);
+    vLayout->addLayout(line4Layout);
     vLayout->addStretch();
     vLayout->setContentsMargins(0, 0, 0, 0);
     //输入框正则表达
@@ -443,6 +467,7 @@ void CreateLVWidget::initConnection()
     connect(m_cancleBtn, &DPushButton::clicked, this, &CreateLVWidget::onCancelButton);
     connect(m_partComboBox, static_cast<void (DComboBox:: *)(const int)>(&DComboBox::currentIndexChanged),
             this, &CreateLVWidget::onComboxCurTextChange);
+    connect(m_partFormateCombox, &DComboBox::currentTextChanged, this, &CreateLVWidget::onComboxFormatTextChange);
     connect(m_partChartWidget, &PartChartShowing::sendMoveFlag, this, &CreateLVWidget::onShowTip);
     connect(m_partChartWidget, &PartChartShowing::sendFlag, this, &CreateLVWidget::onShowSelectPathInfo);
     connect(m_partChartWidget, &PartChartShowing::judgeLastPartition, this, &CreateLVWidget::onJudgeLastPartition);
@@ -508,7 +533,7 @@ void CreateLVWidget::setAddOrRemResult(const bool &isExceed)
 
 void CreateLVWidget::setRegValidator()
 {
-    QRegExp reg("^[0-9]+(.[0-9]{1,4})?$");
+    QRegExp reg("^[0-9]+(\\.[0-9]{1,4})?$");
     QRegExpValidator *va = new QRegExpValidator(reg, this);
     m_partSizeEdit->lineEdit()->setValidator(va);
 
@@ -660,6 +685,33 @@ void CreateLVWidget::onComboxCurTextChange(int index)
 
 }
 
+void CreateLVWidget::onComboxFormatTextChange(const QString &text)
+{
+    if (m_partSizeEdit->isAlert()) {
+        m_partSizeEdit->setAlert(false);
+        m_partSizeEdit->hideAlertMessage();
+    }
+
+    m_scrollArea->setFixedWidth(m_partFormateCombox->width());
+    if (text.contains("AES")) {
+        QString text = tr("Use the aes-xts-plain64 standard algorithm to encrypt the disk. "
+                          "You should decrypt it before mounting it again.");
+        m_encryptionInfo->setFixedSize(m_partFormateCombox->width(),
+                                       Common::getLabelAdjustHeight(m_partFormateCombox->width(), text, m_encryptionInfo->font()));
+        m_encryptionInfo->setText(text);
+    } else if (text.contains("SM4")) {
+        QString text = tr("Use the sm4-xts-plain state cryptographic algorithm to encrypt the disk. "
+                          "You should decrypt it before mounting it again. "
+                          "Operating Systems that do not support the state cryptographic "
+                          "algorithm will not be able to decrypt the disk.");
+        m_encryptionInfo->setFixedSize(m_partFormateCombox->width(),
+                                       Common::getLabelAdjustHeight(m_partFormateCombox->width(), text, m_encryptionInfo->font()) - 1);
+        m_encryptionInfo->setText(text);
+    } else {
+        m_encryptionInfo->setText("");
+    }
+}
+
 void CreateLVWidget::onJudgeLastPartition()
 {
     m_slider->setEnabled(false);
@@ -697,6 +749,11 @@ void CreateLVWidget::onSliderValueChanged(int value)
 
 void CreateLVWidget::onSetSliderValue()
 {
+    if (m_partSizeEdit->isAlert()) {
+        m_partSizeEdit->setAlert(false);
+        m_partSizeEdit->hideAlertMessage();
+    }
+
     if(m_partSizeEdit->text().trimmed().isEmpty()) {
         m_addButton->setDisabled(true);
         return;
@@ -709,7 +766,7 @@ void CreateLVWidget::onSetSliderValue()
     m_slider->setValue(static_cast<int>((value / (m_total - (sumValue() / 1024))) * 100));
     m_currentEditSize = QString::number(value * 1024, 'f', 2);
 
-    if (0.00 == value) {
+    if (0.00 == value || value > (m_total - sumValue() / 1024)) {
         m_addButton->setDisabled(true);
     } else {
         m_addButton->setDisabled(false);
@@ -733,11 +790,57 @@ void CreateLVWidget::onAddPartition()
         peCount += 1;
     }
     currentSize = peCount * m_peSize;
+    QString formate = m_partFormateCombox->currentText();
+    if (formate.contains("AES") || formate.contains("SM4")) {
+        if (currentSize <= 100) {
+            m_partSizeEdit->setAlert(true);
+            m_partSizeEdit->showAlertMessage(tr("To encrypt a volume, it should be larger than 100 MiB"));
+            return;
+        }
+
+        QColor color = QColor(palette().buttonText().color());
+
+        PasswordInputDialog passwordInputDialog(this);
+        passwordInputDialog.setDeviceName(m_partNameEdit->text());
+        passwordInputDialog.setObjectName("passwordInputDialog");
+        passwordInputDialog.setAccessibleName("passwordInputDialog");
+        if (passwordInputDialog.exec() != DDialog::Accepted) {
+            return;
+        } else {
+            part.m_password = passwordInputDialog.getPassword();
+            part.m_passwordHint = passwordInputDialog.getPasswordHint();
+            if (formate.contains("AES")) {
+                part.m_encryption = CRYPT_CIPHER::AES_XTS_PLAIN64;
+                part.m_dmName = QString("%1_%2_aesE").arg(m_deviceName->text()).arg(m_partNameEdit->text());
+            } else if (formate.contains("SM4")) {
+                part.m_encryption = CRYPT_CIPHER::SM4_XTS_PLAIN64;
+                part.m_dmName = QString("%1_%2_sm4E").arg(m_deviceName->text()).arg(m_partNameEdit->text());
+            }
+            part.m_isEncryption = true;
+
+            MessageBox warningBox(this);
+            warningBox.setObjectName("messageBox");
+            warningBox.setAccessibleName("messageBox");
+            // 为防止遗忘密码，请您自行备份密码，并妥善保存！  确 定
+            warningBox.setWarings(tr("To avoid losing the password, please back up your password and keep it properly!"),
+                                  tr("OK", "button"), DDialog::ButtonRecommend, "OK");
+            warningBox.setGeometry(pos().x() + (width() - warningBox.width()) / 2, pos().y() + (height() - warningBox.height()) / 2,
+                                   warningBox.width(), warningBox.height());
+            warningBox.exec();
+        }
+
+        DPalette palette = DApplicationHelper::instance()->palette(m_botFrame);
+        palette.setColor(QPalette::ButtonText, color);
+        DApplicationHelper::instance()->setPalette(this, palette);
+
+        formate = formate.trimmed().split(" ").at(0);
+    }
+
     m_sizeInfo.append(currentSize);
     //绘制新建逻辑卷图形
     m_partChartWidget->transInfos(m_totalSize, m_sizeInfo);
     part.m_lvName = m_partNameEdit->text();
-    part.m_fstype = m_partFormateCombox->currentText();
+    part.m_fstype = formate;
     part.m_lvByteSize = static_cast<long long>(currentSize * 1024 * 1024);
 
     if (m_partComboBox->currentText() == "GiB") {
@@ -807,6 +910,25 @@ void CreateLVWidget::onApplyButton()
         info.m_user = userName;
         info.m_lvAct = LVMAction::LVM_ACT_LV_CREATE;
 
+        if (m_patrinfo.at(i).m_isEncryption) {
+            info.m_luksFlag = LUKSFlag::IS_CRYPT_LUKS;
+            info.m_crypt = m_patrinfo.at(i).m_encryption;
+            QStringList tokenList;
+            if (!m_patrinfo.at(i).m_passwordHint.isEmpty()) {
+                tokenList.append(m_patrinfo.at(i).m_passwordHint);
+            }
+
+            info.m_tokenList = tokenList;
+            info.m_decryptStr = m_patrinfo.at(i).m_password;
+            info.m_dmName = m_patrinfo.at(i).m_dmName;
+        } else {
+            info.m_luksFlag = LUKSFlag::NOT_CRYPT_LUKS;
+            info.m_crypt = CRYPT_CIPHER::NOT_CRYPT;
+            info.m_tokenList = QStringList();
+            info.m_decryptStr = "";
+            info.m_dmName = "";
+        }
+
         lstLVInfo.append(info);
     }
 
@@ -831,7 +953,7 @@ void CreateLVWidget::onRevertButton()
         }
     }
     m_partNameEdit->setText(lvName());
-    m_partFormateCombox->setCurrentIndex(2);
+    m_partFormateCombox->setCurrentText("ext4");
     m_partComboBox->setCurrentIndex(0);
     m_partChartWidget->transInfos(m_totalSize, m_sizeInfo);
     m_isExceed = true;
@@ -859,7 +981,10 @@ bool CreateLVWidget::event(QEvent *event)
     if (QEvent::ApplicationFontChange == event->type()) {
         qDebug() << event->type() << QApplication::font().pointSizeF() / 0.75;
         QFontMetrics fm(m_deviceNameLabel->font());
-        m_deviceNameLabel->setFixedWidth(fm.boundingRect(tr("Disk:")).width() + 5);
+        m_deviceNameLabel->setFixedWidth(fm.boundingRect(tr("VG name:")).width() + 5);
+        m_emptyLabel->setFixedWidth(m_partFormateLabel->fontMetrics().width(tr("LV file system:")));
+        m_encryptionInfo->setFixedWidth(m_partFormateCombox->width());
+        m_scrollArea->setFixedWidth(m_partFormateCombox->width());
         DWidget::event(event);
     }
 
