@@ -1,29 +1,8 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file dmtreeviewdelegate.cpp
- *
- * @brief 设备树结构代理类
- *
- * @date 2020-09-18 09:06
- *
- * Author: yuandandan  <yuandandan@uniontech.com>
- *
- * Maintainer: yuandandan  <yuandandan@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
+
 #include "dmtreeviewdelegate.h"
 #include "common.h"
 #include "dmtreeview.h"
@@ -66,7 +45,7 @@ QSize DmTreeviewDelegate::sizeHint(const QStyleOptionViewItem &option,
 
 void DmTreeviewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    if(!index.isValid()) {
+    if (!index.isValid()) {
         return;
     }
 
@@ -84,7 +63,7 @@ void DmTreeviewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &op
     }
 
     rect.setWidth(option.rect.width());
-//    rect.setHeight(option.rect.height()); // 分区节点间有间隔
+    //    rect.setHeight(option.rect.height()); // 分区节点间有间隔
     // 去掉分区节点间隔
     if (data.m_level == DMDbusHandler::DISK || data.m_level == DMDbusHandler::VOLUMEGROUP) {
         rect.setHeight(option.rect.height() - 9);
@@ -103,21 +82,24 @@ void DmTreeviewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &op
     path.moveTo(paintRect.bottomRight() - QPoint(0, radius));
     path.lineTo(paintRect.topRight() + QPoint(0, radius));
     path.arcTo(QRect(QPoint(paintRect.topRight() - QPoint(radius * 2, 0)),
-                     QSize(radius * 2, radius * 2)), 0, 90);
+                     QSize(radius * 2, radius * 2)),
+               0, 90);
     path.lineTo(paintRect.topLeft() + QPoint(radius, 0));
     path.arcTo(QRect(QPoint(paintRect.topLeft()), QSize(radius * 2, radius * 2)), 90, 90);
     path.lineTo(paintRect.bottomLeft() - QPoint(0, radius));
     path.arcTo(QRect(QPoint(paintRect.bottomLeft() - QPoint(0, radius * 2)),
-                     QSize(radius * 2, radius * 2)), 180, 90);
+                     QSize(radius * 2, radius * 2)),
+               180, 90);
     path.lineTo(paintRect.bottomLeft() + QPoint(radius, 0));
     path.arcTo(QRect(QPoint(paintRect.bottomRight() - QPoint(radius * 2, radius * 2)),
-                     QSize(radius * 2, radius * 2)), 270, 90);
-//    设置分区背景色
-//            if (data.level == 1) {
-//        QBrush brush = m_parentPb.itemBackground();
-//        painter->setBrush(brush);
-//        painter->fillPath(path, brush);
-//    }
+                     QSize(radius * 2, radius * 2)),
+               270, 90);
+    //    设置分区背景色
+    //            if (data.level == 1) {
+    //        QBrush brush = m_parentPb.itemBackground();
+    //        painter->setBrush(brush);
+    //        painter->fillPath(path, brush);
+    //    }
 
     // 设置分区选中时文本颜色
     if ((option.state & QStyle::State_Selected) && (data.m_level != DMDbusHandler::OTHER)) {
@@ -128,8 +110,8 @@ void DmTreeviewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &op
     }
 
     DmTreeview *treeView = qobject_cast<DmTreeview *>(m_parentView);
-//    if (treeView == nullptr) {
-//    }
+    //    if (treeView == nullptr) {
+    //    }
 
     QIcon directionIcon;
     int pixmapWidth = 8; // 伸缩按钮宽
@@ -196,7 +178,8 @@ void DmTreeviewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &op
 
         painter->setFont(font);
         textRect.setRect(paintRect.left() + 10, paintRect.top(), 130, 100);
-        painter->drawText(textRect, text);
+        QString path = painter->fontMetrics().elidedText(text, Qt::ElideMiddle, 120);
+        painter->drawText(textRect, path);
 
         lefticon1Rect.setRect(paintRect.left() + 160, paintRect.top() + 6, pixmapWidth, pixmapHeight);
         painter->drawPixmap(lefticon1Rect, directionIcon.pixmap(17, 17));
@@ -208,20 +191,22 @@ void DmTreeviewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &op
         height = 9 + static_cast<int>((QApplication::font().pointSizeF() / 0.75 - 14) * 1);
         lefticonRect2.setRect(paintRect.left() + 20, paintRect.top() + height, 40, 40);
 
+        QIcon icon = Common::getIcon("treedisk");
         if (data.m_level == DMDbusHandler::DISK) {
-            QMap<QString, QString> isJoinAllVG = DMDbusHandler::instance()->getIsJoinAllVG();
-            if (isJoinAllVG.value(text) == "true") {
-                QIcon icon = Common::getIcon("treevg");
-                painter->drawPixmap(lefticonRect2, icon.pixmap(38, 38));
-            } else {
-                QIcon icon = Common::getIcon("treedisk");
-                painter->drawPixmap(lefticonRect2, icon.pixmap(38, 38));
+            if (DMDbusHandler::instance()->getIsJoinAllVG().value(text) == "true") {
+                icon = Common::getIcon("treevg");
+            } else if (DMDbusHandler::instance()->getIsAllEncryption().value(text) == "true") {
+                icon = Common::getIcon("treedisklock");
             }
         } else if (data.m_level == DMDbusHandler::VOLUMEGROUP) {
-            QIcon icon = Common::getIcon("treevg");
-            painter->drawPixmap(lefticonRect2, icon.pixmap(38, 38));
+            if (DMDbusHandler::instance()->getIsAllEncryption().value(text) == "true") {
+                icon = Common::getIcon("treevglock");
+            } else {
+                icon = Common::getIcon("treevg");
+            }
         }
-//        QTextOption option;
+        painter->drawPixmap(lefticonRect2, icon.pixmap(38, 38));
+
         QFont font = DFontSizeManager::instance()->get(DFontSizeManager::T6);
         if ((option.state & QStyle::State_Selected) && (data.m_level == DMDbusHandler::DISK || data.m_level == DMDbusHandler::VOLUMEGROUP)) {
             QColor textcolor = m_parentPb.color(DPalette::Normal, DPalette::HighlightedText);
@@ -257,14 +242,21 @@ void DmTreeviewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &op
     } else {
         int height = 10 + static_cast<int>((QApplication::font().pointSizeF() / 0.75 - 14) * 1);
         lefticon1Rect.setRect(paintRect.left() + 25, paintRect.top() + height, 30, 30);
-
-        if (data.m_level == DMDbusHandler::LOGICALVOLUME || data.m_vgFlag != LVMFlag::LVM_FLAG_NOT_PV) {
-            QIcon icon = Common::getIcon("treelv");
-            painter->drawPixmap(lefticon1Rect, icon.pixmap(28, 28));
+        QIcon icon = Common::getIcon("harddisk");
+        if (data.m_level == DMDbusHandler::LOGICALVOLUME) {
+            if (data.m_luksFlag == LUKSFlag::IS_CRYPT_LUKS) {
+                icon = Common::getIcon("treelvlock");
+            } else {
+                icon = Common::getIcon("treelv");
+            }
         } else {
-            QIcon icon = Common::getIcon("harddisk");
-            painter->drawPixmap(lefticon1Rect, icon.pixmap(28, 28));
+            if (data.m_vgFlag != LVMFlag::LVM_FLAG_NOT_PV) {
+                icon = Common::getIcon("treelv");
+            } else if (data.m_luksFlag == LUKSFlag::IS_CRYPT_LUKS) {
+                icon = Common::getIcon("treepartitionlock");
+            }
         }
+        painter->drawPixmap(lefticon1Rect, icon.pixmap(28, 28));
 
         QIcon icon1 = Common::getIcon("mounticon");
         QIcon icon2 = Common::getIcon("uninstallicon");
@@ -272,14 +264,14 @@ void DmTreeviewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &op
         height = 28 + static_cast<int>((QApplication::font().pointSizeF() / 0.75 - 14) * 1);
         QRect mounticonRect = QRect(paintRect.left() + 45, paintRect.top() + height, 10, 10);
 
-//        // 获取分区是否隐藏
-//        int hide = 0;
-//        if (data.mountpoints.isEmpty() || data.mountpoints == "/recovery") {
-//            int result = DMDbusHandler::instance()->getPartitionHiddenFlag(data.diskpath, data.partitonpath);
-//            if (1 == result) {
-//                hide = 1;
-//            }
-//        }
+        //        // 获取分区是否隐藏
+        //        int hide = 0;
+        //        if (data.mountpoints.isEmpty() || data.mountpoints == "/recovery") {
+        //            int result = DMDbusHandler::instance()->getPartitionHiddenFlag(data.diskpath, data.partitonpath);
+        //            if (1 == result) {
+        //                hide = 1;
+        //            }
+        //        }
 
         if (data.m_fstype == "unallocated") {
             painter->drawPixmap(mounticonRect, icon2.pixmap(10, 10));
