@@ -1,31 +1,14 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file partitionwidget.cpp
- *
- * @brief 创建分区窗口
- *
- * @date 2020-09-08 15:34
- *
- * Author: yuandandan  <yuandandan@uniontech.com>
- *
- * Maintainer: yuandandan  <yuandandan@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
+
 #include "partitionwidget.h"
 #include "common.h"
+#include "passwordinputdialog.h"
+#include "widgets/messagebox.h"
+
+#include <DScrollArea>
 
 #include <QDebug>
 #include <QApplication>
@@ -40,7 +23,6 @@ PartitionWidget::PartitionWidget(QWidget *parent)
 }
 PartitionWidget::~PartitionWidget()
 {
-
 }
 void PartitionWidget::initUi()
 {
@@ -54,8 +36,9 @@ void PartitionWidget::initUi()
     PartitionInfo info = DMDbusHandler::instance()->getCurPartititonInfo();
     setTitle(tr("Partitioning %1").arg(info.m_path));
 
-    DLabel *tipLabel = new DLabel(tr("Click ‘+’ to increase the number of partitions. Click on each partition to change its name and file system."), m_mainFrame);
-    tipLabel->setWordWrap(true);
+    DLabel *tipLabel = new DLabel(tr("Click %1 to increase the number of partitions. Click on each partition to change its name and file system.").arg("+"), m_mainFrame);
+    tipLabel->setWordWrap(false);
+    tipLabel->setElideMode(Qt::ElideMiddle);
     tipLabel->setAlignment(Qt::AlignCenter);
 
     if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::LightType) {
@@ -64,7 +47,7 @@ void PartitionWidget::initUi()
         tipColor.setAlphaF(0.7);
         tipPalette.setColor(DPalette::WindowText, tipColor);
         tipLabel->setPalette(tipPalette);
-    }  else if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::DarkType) {
+    } else if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::DarkType) {
         DPalette tipPalette;
         QColor tipColor("#FFFFFF");
         tipColor.setAlphaF(0.7);
@@ -81,17 +64,17 @@ void PartitionWidget::initUi()
     palette.setBrush(DPalette::Base, palette.itemBackground());
     DApplicationHelper::instance()->setPalette(m_topFrame, palette);
     m_topFrame->setAutoFillBackground(true);
-//    m_topFrame->setStyleSheet("background:red");
-    m_topFrame->setFixedSize(864,110);
+    //    m_topFrame->setStyleSheet("background:red");
+    m_topFrame->setFixedSize(864, 110);
 
     m_midFrame = new DFrame(m_mainFrame);
     //分区页中间部分的图形绘制
     midFrameSetting();
     m_midFrame->setFrameStyle(DFrame::NoFrame);
-//    m_midFrame->setStyleSheet("background:blue");
+    //    m_midFrame->setStyleSheet("background:blue");
     m_midFrame->setFixedSize(864, 85);
     m_botFrame = new DFrame(m_mainFrame);
-//    m_botFrame->setStyleSheet("background:green");
+    //    m_botFrame->setStyleSheet("background:green");
     m_botFrame->setFixedSize(864, 253);
     //分区页最下端的布局等
     botFrameSetting();
@@ -106,7 +89,6 @@ void PartitionWidget::initUi()
 
     setIcon(QIcon::fromTheme(appName));
     addContent(m_mainFrame);
-
 }
 
 void PartitionWidget::topFrameSetting()
@@ -161,7 +143,7 @@ void PartitionWidget::topFrameSetting()
     m_deviceNameLabel->setFixedWidth(fm.boundingRect(tr("Disk:")).width() + 5);
 
     m_deviceName = new DLabel("/dev/sda", m_topFrame);
-//    m_deviceName->setMinimumWidth(103);
+    //    m_deviceName->setMinimumWidth(103);
     m_deviceName->setAlignment(Qt::AlignVCenter | Qt::AlignLeft);
     DFontSizeManager::instance()->bind(m_deviceName, DFontSizeManager::T8, QFont::Normal);
     m_deviceName->setPalette(infoPalette);
@@ -269,6 +251,10 @@ void PartitionWidget::partInfoShowing()
 {
     auto formateList = DMDbusHandler::instance()->getAllSupportFileSystem();
     formateList.removeOne("linux-swap");
+    if (!DMDbusHandler::instance()->getIsSystemDisk(DMDbusHandler::instance()->getCurPartititonInfo().m_devicePath)) {
+        formateList = DMDbusHandler::instance()->getEncryptionFormate(formateList);
+    }
+
     //整体垂直布局-三行
     QVBoxLayout *vLayout = new QVBoxLayout(m_partWidget);
     //第一行
@@ -289,10 +275,10 @@ void PartitionWidget::partInfoShowing()
     m_partDoLabel->setPalette(infoPalette);
 
     DLabel *labelSpace = new DLabel(m_partWidget);
-    m_addButton = new DIconButton(DStyle::SP_IncreaseElement);
+    m_addButton = new DIconButton(DStyle::SP_IncreaseElement, m_partWidget);
     m_addButton->setObjectName("addButton");
     m_addButton->setAccessibleName("addButton");
-    m_remButton = new DIconButton(DStyle::SP_DecreaseElement);
+    m_remButton = new DIconButton(DStyle::SP_DecreaseElement, m_partWidget);
     m_remButton->setObjectName("removeButton");
     m_remButton->setAccessibleName("removeButton");
     m_remButton->setToolTip(tr("Delete last partition"));
@@ -324,13 +310,13 @@ void PartitionWidget::partInfoShowing()
     line2Layout->addWidget(m_partNameEdit, 7);
     //第三行
     QHBoxLayout *line3Layout = new QHBoxLayout();
-    DLabel *partFormateLabel = new DLabel(tr("File system:"), m_partWidget);
-    DFontSizeManager::instance()->bind(partFormateLabel, DFontSizeManager::T8, QFont::Normal);
-    partFormateLabel->setPalette(infoPalette);
+    m_partFormateLabel = new DLabel(tr("File system:"), m_partWidget);
+    DFontSizeManager::instance()->bind(m_partFormateLabel, DFontSizeManager::T8, QFont::Normal);
+    m_partFormateLabel->setPalette(infoPalette);
 
     m_partFormateCombox = new DComboBox(m_partWidget);
     m_partFormateCombox->addItems(formateList);
-    m_partFormateCombox->setCurrentIndex(2);
+    m_partFormateCombox->setCurrentText("ext4");
     m_partFormateCombox->setAccessibleName("File system");
 
     DLabel *partSizeLabel = new DLabel(tr("Size:"), m_partWidget);
@@ -350,7 +336,7 @@ void PartitionWidget::partInfoShowing()
     m_partComboBox->setCurrentText("GiB");
     m_partComboBox->setAccessibleName("unit");
 
-    line3Layout->addWidget(partFormateLabel, 1);
+    line3Layout->addWidget(m_partFormateLabel, 1);
     line3Layout->addWidget(m_partFormateCombox, 7);
     line3Layout->addWidget(space, 1);
     line3Layout->addWidget(partSizeLabel);
@@ -358,10 +344,45 @@ void PartitionWidget::partInfoShowing()
     line3Layout->addWidget(m_partSizeEdit, 3);
     line3Layout->addWidget(m_partComboBox, 2);
 
+    // 第四行
+    DPalette palette;
+    palette.setColor(DPalette::Text, QColor("#526a7f"));
+
+    QFont font;
+    font.setWeight(QFont::Normal);
+    font.setFamily("Source Han Sans");
+    font.setPixelSize(12);
+
+    m_emptyLabel = new DLabel(m_partWidget);
+    m_emptyLabel->setFixedWidth(m_partFormateLabel->fontMetrics().width(tr("File system:")));
+    m_encryptionInfo = new DLabel(m_partWidget);
+    m_encryptionInfo->setFont(font);
+    m_encryptionInfo->setPalette(palette);
+    m_encryptionInfo->adjustSize();
+    m_encryptionInfo->setWordWrap(true);
+    m_encryptionInfo->setAccessibleName("encryptionInfo");
+
+    m_scrollArea = new DScrollArea;
+    m_scrollArea->setFrameShadow(QFrame::Plain);
+    m_scrollArea->setFrameShape(QFrame::NoFrame);
+    m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff); //隐藏横向滚动条
+    m_scrollArea->setWidget(m_encryptionInfo);
+
+    // 设置滚动区域背景颜色为透明
+    QPalette areaPalette;
+    areaPalette.setColor(QPalette::Base, QColor(255, 255, 255, 0));
+    m_scrollArea->setPalette(areaPalette);
+
+    QHBoxLayout *line4Layout = new QHBoxLayout();
+    line4Layout->addWidget(m_emptyLabel, 1);
+    line4Layout->addWidget(m_scrollArea, 7);
+    line4Layout->addStretch();
+
     vLayout->addWidget(m_partInfoLabel);
     vLayout->addLayout(line2Layout);
     vLayout->addSpacing(4);
     vLayout->addLayout(line3Layout);
+    vLayout->addLayout(line4Layout);
     vLayout->addStretch();
     vLayout->setContentsMargins(0, 0, 0, 0);
     //输入框正则表达
@@ -393,7 +414,7 @@ void PartitionWidget::recPartitionInfo()
     m_deviceFormate->setText(partFstype);
     m_total = Utils::sectorToUnit(data.m_sectorEnd - data.m_sectorStart + 1, data.m_sectorSize, SIZE_UNIT::UNIT_GIB);
     m_totalSize = m_total * 1024;
-//    qDebug() << mTotal << total;
+    //    qDebug() << mTotal << total;
     //初始值,显示保留两位小数,真正使用保留4位小数
     m_currentEditSize = QString::number(m_totalSize, 'f', 4);
     m_partComboBox->setEnabled(true);
@@ -411,8 +432,8 @@ void PartitionWidget::initConnection()
     connect(m_applyBtn, &DPushButton::clicked, this, &PartitionWidget::onApplyButton);
     connect(m_reveBtn, &DPushButton::clicked, this, &PartitionWidget::onRevertButton);
     connect(m_cancleBtn, &DPushButton::clicked, this, &PartitionWidget::onCancelButton);
-//    connect(m_partComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(onComboxCurTextChange(int)));
-    connect(m_partComboBox, static_cast<void (DComboBox:: *)(const int)>(&DComboBox::currentIndexChanged),
+    //    connect(m_partComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(onComboxCurTextChange(int)));
+    connect(m_partComboBox, static_cast<void (DComboBox::*)(const int)>(&DComboBox::currentIndexChanged),
             this, &PartitionWidget::onComboxCurTextChange);
     connect(m_partFormateCombox, &DComboBox::currentTextChanged, this, &PartitionWidget::onComboxFormatTextChange);
     connect(m_partChartWidget, &PartChartShowing::sendMoveFlag, this, &PartitionWidget::onShowTip);
@@ -439,9 +460,9 @@ void PartitionWidget::setSelectUnallocatesSpace()
     m_partSizeEdit->setText("");
 
     if (m_partComboBox->currentText() == "GiB") {
-        m_partSizeEdit->setText(QString::number(m_total - (sumValue() / 1024),  'f', 2));
+        m_partSizeEdit->setText(QString::number(m_total - (sumValue() / 1024), 'f', 2));
     } else {
-        m_partSizeEdit->setText(QString::number(m_totalSize - sumValue(),  'f', 2));
+        m_partSizeEdit->setText(QString::number(m_totalSize - sumValue(), 'f', 2));
     }
 }
 
@@ -467,7 +488,7 @@ void PartitionWidget::setAddOrRemResult(const bool &isExceed)
 
 void PartitionWidget::setRegValidator()
 {
-    QRegExp reg("^[0-9]+(.[0-9]{1,4})?$");
+    QRegExp reg("^[0-9]+(\\.[0-9]{1,4})?$");
     QRegExpValidator *va = new QRegExpValidator(reg, this);
     m_partSizeEdit->lineEdit()->setValidator(va);
 
@@ -552,28 +573,27 @@ void PartitionWidget::onShowTip(const int &hover, const int &num, const int &pos
     }
 }
 
-
 void PartitionWidget::setEnable(const int &flag, const bool &isExceed)
 {
     DPalette palette = DApplicationHelper::instance()->palette(m_partNameLabel);
 
-    if (isExceed) {//还有空闲空间剩余
-        if (flag == 2) {//选中新建的分区
+    if (isExceed) { //还有空闲空间剩余
+        if (flag == 2) { //选中新建的分区
             setControlEnable(false);
             m_partNameEdit->setEnabled(false);
         } else {
             setControlEnable(true);
         }
-//        palette.setColor(DPalette::Text, QColor(this->palette().buttonText().color()));
-    } else {//无空闲空间剩余
+        //        palette.setColor(DPalette::Text, QColor(this->palette().buttonText().color()));
+    } else { //无空闲空间剩余
         setControlEnable(false);
-//        if (flag != 2) {
-//            palette.setBrush(DPalette::Text, palette.placeholderText());
-//            m_partNameEdit->setEnabled(false);
-//        } else {
-//            palette.setColor(DPalette::Text, QColor(this->palette().buttonText().color()));
+        //        if (flag != 2) {
+        //            palette.setBrush(DPalette::Text, palette.placeholderText());
+        //            m_partNameEdit->setEnabled(false);
+        //        } else {
+        //            palette.setColor(DPalette::Text, QColor(this->palette().buttonText().color()));
         m_partNameEdit->setEnabled(false);
-//        }
+        //        }
     }
 
     if (m_partNameEdit->text().toUtf8().size() <= 16) {
@@ -583,7 +603,7 @@ void PartitionWidget::setEnable(const int &flag, const bool &isExceed)
         m_addButton->setEnabled(false);
     }
 
-    m_partNameLabel->setPalette(palette);//各情况下,分区名称label的样式
+    m_partNameLabel->setPalette(palette); //各情况下,分区名称label的样式
 
     m_remButton->setEnabled(m_sizeInfo.size());
     m_applyBtn->setEnabled(m_sizeInfo.size());
@@ -624,7 +644,7 @@ void PartitionWidget::setLabelColor(const bool &isOk)
 
 void PartitionWidget::onComboxCurTextChange(int index)
 {
-//    qDebug() << partSizeEdit->text().toDouble();
+    //    qDebug() << partSizeEdit->text().toDouble();
     if (!m_partSizeEdit->text().isEmpty()) {
         double m = m_currentEditSize.toDouble();
 
@@ -634,21 +654,25 @@ void PartitionWidget::onComboxCurTextChange(int index)
             else
                 m_partSizeEdit->setText(QString::number(m, 'f', 2));
         } else if (index == 0) {
-//            double m = partSizeEdit->text().toDouble();
+            //            double m = partSizeEdit->text().toDouble();
             if (m_sizeInfo.size() == 0 && m_slider->value() == 100)
                 m_partSizeEdit->setText(QString::number(m_total, 'f', 2));
             else
                 m_partSizeEdit->setText(QString::number(m / 1024, 'f', 2));
         }
-//        qDebug() << m;
+        //        qDebug() << m;
     }
-
 }
 
 void PartitionWidget::onComboxFormatTextChange(const QString &text)
 {
+    if (m_partSizeEdit->isAlert()) {
+        m_partSizeEdit->setAlert(false);
+        m_partSizeEdit->hideAlertMessage();
+    }
+
     QByteArray byteArray = m_partNameEdit->text().toUtf8();
-    if (text == "fat32") {
+    if (text.contains("fat32")) {
         if (byteArray.size() > 11) {
             m_partNameEdit->setAlert(true);
             m_partNameEdit->showAlertMessage(tr("The length exceeds the limit"), -1);
@@ -669,6 +693,25 @@ void PartitionWidget::onComboxFormatTextChange(const QString &text)
             m_addButton->setEnabled(true);
         }
     }
+
+    m_scrollArea->setFixedWidth(m_partFormateCombox->width());
+    if (text.contains("AES")) {
+        QString text = tr("Use the aes-xts-plain64 standard algorithm to encrypt the disk. "
+                          "If it is encrypted, you should decrypt it before mounting.");
+        m_encryptionInfo->setFixedSize(m_partFormateCombox->width(),
+                                       Common::getLabelAdjustHeight(m_partFormateCombox->width(), text, m_encryptionInfo->font()));
+        m_encryptionInfo->setText(text);
+    } else if (text.contains("SM4")) {
+        QString text = tr("Use the sm4-xts-plain state cryptographic algorithm to encrypt the disk. "
+                          "If it is encrypted, you should decrypt it before mounting. "
+                          "Operating Systems that do not support the state cryptographic "
+                          "algorithm will not be able to decrypt the disk.");
+        m_encryptionInfo->setFixedSize(m_partFormateCombox->width(),
+                                       Common::getLabelAdjustHeight(m_partFormateCombox->width(), text, m_encryptionInfo->font()) - 1);
+        m_encryptionInfo->setText(text);
+    } else {
+        m_encryptionInfo->setText("");
+    }
 }
 
 void PartitionWidget::onJudgeLastPartition()
@@ -686,21 +729,21 @@ void PartitionWidget::onSliderValueChanged(int value)
         //选中分区大小与整个空闲分区的占比
         if (m_flag == 2) {
             if (m_partComboBox->currentText() == "MiB") {
-                size = QString::number((static_cast<double>(value) / 100) * m_totalSize,  'f', 2);
+                size = QString::number((static_cast<double>(value) / 100) * m_totalSize, 'f', 2);
             } else {
-                size = QString::number((static_cast<double>(value) / 100) * m_total,  'f', 2);
+                size = QString::number((static_cast<double>(value) / 100) * m_total, 'f', 2);
             }
 
             m_partSizeEdit->setText(size);
-        } else {//剩余空间为总大小,占比情况
+        } else { //剩余空间为总大小,占比情况
             if (m_partComboBox->currentText() == "MiB") {
-                size = QString::number((static_cast<double>(value) / 100) * (m_totalSize - sumValue()),  'f', 2);
+                size = QString::number((static_cast<double>(value) / 100) * (m_totalSize - sumValue()), 'f', 2);
 
                 if (m_totalSize - sumValue() < 52) {
                     onJudgeLastPartition();
                 }
             } else {
-                size = QString::number(((static_cast<double>(value) / 100) * (m_totalSize - sumValue())) / 1024,  'f', 2);
+                size = QString::number(((static_cast<double>(value) / 100) * (m_totalSize - sumValue())) / 1024, 'f', 2);
 
                 if (m_total - sumValue() / 1024 < 0.05) {
                     onJudgeLastPartition();
@@ -710,33 +753,45 @@ void PartitionWidget::onSliderValueChanged(int value)
             m_partSizeEdit->setText(size);
         }
     }
-//    QString strSize1 = QString::number((static_cast<double>(value) / 100) * (m_totalSize - sumValue()),  'f', 2);
-    m_currentEditSize = QString::number((static_cast<double>(value) / 100) * (m_totalSize - sumValue()),  'f', 4);
+    //    QString strSize1 = QString::number((static_cast<double>(value) / 100) * (m_totalSize - sumValue()),  'f', 2);
+    m_currentEditSize = QString::number((static_cast<double>(value) / 100) * (m_totalSize - sumValue()), 'f', 4);
     qDebug() << m_currentEditSize << size << value << m_totalSize - sumValue();
     m_block = 0;
+    //m_addButton->setEnabled(m_currentEditSize <= )
 }
 
 void PartitionWidget::onSetSliderValue()
 {
-    if(m_partSizeEdit->text().trimmed().isEmpty()) {
-        return;
+    if (m_partSizeEdit->isAlert()) {
+        m_partSizeEdit->setAlert(false);
+        m_partSizeEdit->hideAlertMessage();
     }
 
-    double value = m_partSizeEdit->text().toDouble();
+    double value = 0;
+    if (m_partSizeEdit->text().trimmed().isEmpty()) {
+        value = 0;
+    }
+
+    value = m_partSizeEdit->text().toDouble();
     if (m_partComboBox->currentText() == "MiB")
         value = value / 1024;
     m_block = 1;
     m_slider->setValue(static_cast<int>((value / (m_total - (sumValue() / 1024))) * 100));
     m_currentEditSize = QString::number(value * 1024, 'f', 4);
-//    qDebug() << currentEditSize;
-//    qDebug() << value * 1024 << static_cast<int>((value / total) * 100);
+    if (value == 0.00 || value > (m_total - sumValue() / 1024)) {
+        m_addButton->setEnabled(false);
+    } else {
+        m_addButton->setEnabled(true);
+    }
+    //    qDebug() << currentEditSize;
+    //    qDebug() << value * 1024 << static_cast<int>((value / total) * 100);
 }
 
 void PartitionWidget::onTextChanged(const QString &text)
 {
     if (!text.isEmpty()) {
         QByteArray byteArray = text.toUtf8();
-        if (m_partFormateCombox->currentText() == "fat32") {
+        if (m_partFormateCombox->currentText().contains("fat32")) {
             if (byteArray.size() > 11) {
                 m_partNameEdit->setAlert(true);
                 m_partNameEdit->showAlertMessage(tr("The length exceeds the limit"), -1);
@@ -773,7 +828,7 @@ void PartitionWidget::onAddPartition()
     DeviceInfo device = DMDbusHandler::instance()->getCurDeviceInfo();
 
     int partitionCount = 0;
-    for (int i = 0; i < device.m_partition.size(); i ++) {
+    for (int i = 0; i < device.m_partition.size(); i++) {
         PartitionInfo info = device.m_partition.at(i);
         if (info.m_path != "unallocated") {
             partitionCount++;
@@ -787,7 +842,7 @@ void PartitionWidget::onAddPartition()
 
     double currentSize = 0.00;
     stPart part;
-    m_applyBtn->setEnabled(true);
+
     //一次新建不超过24个分区
     if (m_partNameEdit->text().isEmpty()) {
         m_partNameEdit->setText(" ");
@@ -800,31 +855,80 @@ void PartitionWidget::onAddPartition()
         part.m_blast = true;
     }
 
-    if (currentSize <= 52) {
-        DMessageManager::instance()->sendMessage(this, QIcon(":/icons/deepin/builtin/warning.svg"), tr("To create a partition, you need at least 52 MB"));
-        return;
+    QString formate = m_partFormateCombox->currentText();
+    if (formate.contains("AES") || formate.contains("SM4")) {
+        if (currentSize <= 100) {
+            m_partSizeEdit->setAlert(true);
+            m_partSizeEdit->showAlertMessage(tr("To encrypt a partition, it should be larger than 100 MiB"));
+            return;
+        }
+
+        QColor color = QColor(palette().buttonText().color());
+
+        PasswordInputDialog passwordInputDialog(this);
+        passwordInputDialog.setDeviceName(device.m_path);
+        PartitionInfo info = DMDbusHandler::instance()->getCurPartititonInfo();
+        passwordInputDialog.setTitleText(tr("Set a password to encrypt the new partition"));
+        passwordInputDialog.setObjectName("passwordInputDialog");
+        passwordInputDialog.setAccessibleName("passwordInputDialog");
+        if (passwordInputDialog.exec() != DDialog::Accepted) {
+            return;
+        } else {
+            part.m_password = passwordInputDialog.getPassword();
+            part.m_passwordHint = passwordInputDialog.getPasswordHint();
+            if (formate.contains("AES")) {
+                part.m_encryption = CRYPT_CIPHER::AES_XTS_PLAIN64;
+            } else if (formate.contains("SM4")) {
+                part.m_encryption = CRYPT_CIPHER::SM4_XTS_PLAIN64;
+            }
+            part.m_isEncryption = true;
+
+            MessageBox warningBox(this);
+            warningBox.setObjectName("messageBox");
+            warningBox.setAccessibleName("messageBox");
+            // 为防止遗忘密码，请您自行备份密码，并妥善保存！  确 定
+            warningBox.setWarings(tr("To avoid losing the password, please back up your password and keep it properly!"),
+                                  tr("OK", "button"), DDialog::ButtonRecommend, "OK");
+            warningBox.setGeometry(pos().x() + (width() - warningBox.width()) / 2, pos().y() + (height() - warningBox.height()) / 2,
+                                   warningBox.width(), warningBox.height());
+            warningBox.exec();
+        }
+
+        DPalette palette = DApplicationHelper::instance()->palette(m_botFrame);
+        palette.setColor(QPalette::ButtonText, color);
+        DApplicationHelper::instance()->setPalette(this, palette);
+
+        formate = formate.trimmed().split(" ").at(0);
+    } else {
+        if (currentSize <= 52) {
+            DMessageManager::instance()->sendMessage(this, QIcon(":/icons/deepin/builtin/warning.svg"), tr("To create a partition, you need at least 52 MB"));
+            return;
+        }
     }
+
     m_sizeInfo.append(currentSize);
     //绘制新建分区图形
     m_partChartWidget->transInfos(m_totalSize, m_sizeInfo);
     part.m_labelName = m_partNameEdit->text();
-    part.m_fstype = m_partFormateCombox->currentText();
+    part.m_fstype = formate;
     Byte_Value sectorSize = DMDbusHandler::instance()->getCurPartititonInfo().m_sectorSize;
     part.m_count = static_cast<Sector>(currentSize * (MEBIBYTE / sectorSize));
-//    if (partComCobox->currentText().compare("MiB") == 0) {
-//        part.count = static_cast<int>(partSizeEdit->text().toDouble() * (MEBIBYTE / sector_size)) ;
-//    } else {
-//        part.count = static_cast<int>(partSizeEdit->text().toDouble() * (GIBIBYTE / sector_size));
-//    }
+    //    if (partComCobox->currentText().compare("MiB") == 0) {
+    //        part.count = static_cast<int>(partSizeEdit->text().toDouble() * (MEBIBYTE / sector_size)) ;
+    //    } else {
+    //        part.count = static_cast<int>(partSizeEdit->text().toDouble() * (GIBIBYTE / sector_size));
+    //    }
     m_patrinfo.push_back(part);
     m_partChartWidget->update();
 
     //新增分区后样式变化
-    if (sumValue() >= m_totalSize - 0.01)
+    if (sumValue() >= m_totalSize - 0.01) {
         m_isExceed = false;
-    else
+    } else {
         m_isExceed = true;
+    }
 
+    m_applyBtn->setEnabled(true);
     setAddOrRemResult(m_isExceed);
 }
 
@@ -890,8 +994,8 @@ void PartitionWidget::onApplyButton()
         //newpart .type == TYPE_LOGICAL logical partition
         //newpart .sector_start <= (MEBIBYTE / newpart .sector_size) /* Beginning of disk device */
         if ((newPart.m_insideExtended && newPart.m_type == TYPE_UNALLOCATED)
-                || newPart.m_type == TYPE_LOGICAL
-                || newPart.m_sectorStart <= (MEBIBYTE / newPart.m_sectorSize)) {
+            || newPart.m_type == TYPE_LOGICAL
+            || newPart.m_sectorStart <= (MEBIBYTE / newPart.m_sectorSize)) {
             newPart.m_sectorStart += MEBIBYTE / newPart.m_sectorSize;
             newPart.m_sectorEnd += MEBIBYTE / newPart.m_sectorSize;
         }
@@ -923,6 +1027,23 @@ void PartitionWidget::onApplyButton()
 
             beforend = newPart.m_sectorEnd + 1;
 
+            if (m_patrinfo.at(i).m_isEncryption) {
+                newPart.m_luksFlag = LUKSFlag::IS_CRYPT_LUKS;
+                newPart.m_crypt = m_patrinfo.at(i).m_encryption;
+                QStringList tokenList;
+                if (!m_patrinfo.at(i).m_passwordHint.isEmpty()) {
+                    tokenList.append(m_patrinfo.at(i).m_passwordHint);
+                }
+
+                newPart.m_tokenList = tokenList;
+                newPart.m_decryptStr = m_patrinfo.at(i).m_password;
+            } else {
+                newPart.m_luksFlag = LUKSFlag::NOT_CRYPT_LUKS;
+                newPart.m_crypt = CRYPT_CIPHER::NOT_CRYPT;
+                newPart.m_tokenList = QStringList();
+                newPart.m_decryptStr = "";
+            }
+
             partVector.push_back(newPart);
         }
     }
@@ -939,7 +1060,7 @@ void PartitionWidget::onRevertButton()
     m_sizeInfo.clear();
     m_partName.clear();
     m_partNameEdit->clear();
-    m_partFormateCombox->setCurrentIndex(2);
+    m_partFormateCombox->setCurrentText("ext4");
     m_partComboBox->setCurrentIndex(0);
     m_partChartWidget->transInfos(m_totalSize, m_sizeInfo);
     m_isExceed = true;
@@ -968,6 +1089,9 @@ bool PartitionWidget::event(QEvent *event)
         qDebug() << event->type() << QApplication::font().pointSizeF() / 0.75;
         QFontMetrics fm(m_deviceNameLabel->font());
         m_deviceNameLabel->setFixedWidth(fm.boundingRect(tr("Disk:")).width() + 5);
+        m_emptyLabel->setFixedWidth(m_partFormateLabel->fontMetrics().width(tr("File system:")));
+        m_encryptionInfo->setFixedWidth(m_partFormateCombox->width());
+        m_scrollArea->setFixedWidth(m_partFormateCombox->width());
         DWidget::event(event);
     }
 
