@@ -1,29 +1,8 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file partitionwidget.h
- *
- * @brief 创建分区窗口
- *
- * @date 2020-09-08 15:34
- *
- * Author: yuandandan  <yuandandan@uniontech.com>
- *
- * Maintainer: yuandandan  <yuandandan@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
+
 #ifndef PARTITIONWIDGET_H
 #define PARTITIONWIDGET_H
 
@@ -60,12 +39,19 @@ typedef struct STRUCTPART {
         m_count = 0;
         m_labelName = m_fstype = "";
         m_blast = false;
+        m_password = m_passwordHint = "";
+        m_encryption = CRYPT_CIPHER::NOT_CRYPT;
+        m_isEncryption = false;
     }
     double m_size;
     Sector m_count;
     QString m_labelName;
     QString m_fstype;
     bool m_blast;
+    QString m_password;
+    QString m_passwordHint;
+    CRYPT_CIPHER m_encryption;
+    bool m_isEncryption;
 } stPart;
 
 /**
@@ -298,6 +284,10 @@ private:
     QVector<QString> m_partName;
     QVector<stPart> m_patrinfo;
     bool m_isExceed = true;
+    DLabel *m_partFormateLabel;
+    DLabel *m_encryptionInfo;
+    DLabel *m_emptyLabel;
+    DScrollArea *m_scrollArea;
 };
 
 #endif // PARTITIONWIDGET_H
