@@ -1,34 +1,14 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file sizeinfowidget.h
- *
- * @brief 主界面右侧信息展示中间部分实现类
- *
- * @date 2020-09-17 14:35
- *
- * Author: yuandandan  <yuandandan@uniontech.com>
- *
- * Maintainer: yuandandan  <yuandandan@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
+
 #ifndef SIZEINFOWIDGET_H
 #define SIZEINFOWIDGET_H
 
 #include "partitioninfo.h"
 #include "utils.h"
+#include "partedproxy/dmdbushandler.h"
 
 #include <DWidget>
 #include <DApplicationHelper>
@@ -82,6 +62,14 @@ public:
      */
     void setData(LVInfo info, QVector<QColor> color, QVector<double> size, bool flag);
 
+    /**
+     * @brief 设置数据
+     * @param info 当前磁盘信息
+     * @param color 颜色列表
+     * @param flag 是否显示下方标注
+     */
+    void setData(DeviceInfo info, QVector<QColor> color, QVector<double> size, bool flag);
+
 protected:
     /**
      * @brief 重写绘画事件
