@@ -1,29 +1,8 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file devicelistwidget.cpp
- *
- * @brief 主要实现磁盘树结构展示以及右键磁盘信息、硬盘健康检测、分区表错误处理、隐藏分区、显示分区、删除分区等操作
- *
- * @date 2020-09-03 14:54
- *
- * Author: yuandandan  <yuandandan@uniontech.com>
- *
- * Maintainer: yuandandan  <yuandandan@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
+
 #include "devicelistwidget.h"
 #include "customcontrol/dmdiskinfobox.h"
 #include "diskinfodisplaydialog.h"
@@ -88,12 +67,13 @@ void DeviceListWidget::initConnection()
     connect(DMDbusHandler::instance(), &DMDbusHandler::updateUsb, this, &DeviceListWidget::onUpdateUsb);
     connect(DMDbusHandler::instance(), &DMDbusHandler::vgDeleteMessage, this, &DeviceListWidget::onVGDeleteMessage);
     connect(DMDbusHandler::instance(), &DMDbusHandler::lvDeleteMessage, this, &DeviceListWidget::onLVDeleteMessage);
+    connect(DMDbusHandler::instance(), &DMDbusHandler::createFailedMessage, this, &DeviceListWidget::onCreateFailedMessage);
 }
 
 void DeviceListWidget::treeMenu(const QPoint &pos)
 {
-    QModelIndex curIndex = m_treeView->indexAt(pos);      //当前点击的元素的index
-    QModelIndex index = curIndex.sibling(curIndex.row(),0); //该行的第1列元素的index
+    QModelIndex curIndex = m_treeView->indexAt(pos); //当前点击的元素的index
+    QModelIndex index = curIndex.sibling(curIndex.row(), 0); //该行的第1列元素的index
 
     if (!index.isValid()) {
         return;
@@ -143,29 +123,29 @@ void DeviceListWidget::treeMenu(const QPoint &pos)
         connect(createPartitionTable, &QAction::triggered, this, &DeviceListWidget::onCreatePartitionTableClicked);
 
         DeviceInfo info = DMDbusHandler::instance()->getCurDeviceInfo();
-        if (info.m_vgFlag != LVMFlag::LVM_FLAG_NOT_PV) {
+        if (info.m_vgFlag != LVMFlag::LVM_FLAG_NOT_PV || info.m_luksFlag == LUKSFlag::IS_CRYPT_LUKS) {
             createPartitionTable->setDisabled(true);
         }
 
-        menu->exec(QCursor::pos());  //显示菜单
+        menu->exec(QCursor::pos()); //显示菜单
         delete menu;
     } else if (m_curDiskInfoData.m_level == DMDbusHandler::PARTITION) {
         QMenu *menu = new QMenu(this);
         menu->setObjectName("treeMenu");
         menu->setAccessibleName("menu");
 
-//        QAction *actionHidePartition = new QAction(this);
-//        actionHidePartition->setText(tr("Hide partition")); // 隐藏分区
-//        actionHidePartition->setObjectName("Hide partition");
-//        menu->addAction(actionHidePartition);
-//        connect(actionHidePartition, &QAction::triggered, this, &DeviceListWidget::onHidePartitionClicked);
+        //        QAction *actionHidePartition = new QAction(this);
+        //        actionHidePartition->setText(tr("Hide partition")); // 隐藏分区
+        //        actionHidePartition->setObjectName("Hide partition");
+        //        menu->addAction(actionHidePartition);
+        //        connect(actionHidePartition, &QAction::triggered, this, &DeviceListWidget::onHidePartitionClicked);
 
-//        QAction *actionShowPartition = new QAction(this);
-//        actionShowPartition->setText(tr("Unhide partition")); // 显示分区
-//        actionShowPartition->setObjectName("Unhide partition");
-//        menu->addAction(actionShowPartition);
-//        connect(actionShowPartition, &QAction::triggered, this, &DeviceListWidget::onShowPartitionClicked);
-//        //            actionShowPartition->setDisabled(true); // 将按钮置为不可选
+        //        QAction *actionShowPartition = new QAction(this);
+        //        actionShowPartition->setText(tr("Unhide partition")); // 显示分区
+        //        actionShowPartition->setObjectName("Unhide partition");
+        //        menu->addAction(actionShowPartition);
+        //        connect(actionShowPartition, &QAction::triggered, this, &DeviceListWidget::onShowPartitionClicked);
+        //        //            actionShowPartition->setDisabled(true); // 将按钮置为不可选
 
         QAction *actionDelete = new QAction(this);
         actionDelete->setText(tr("Delete partition")); // 删除分区
@@ -191,9 +171,19 @@ void DeviceListWidget::treeMenu(const QPoint &pos)
         }
 
         PartitionInfo info = DMDbusHandler::instance()->getCurPartititonInfo();
-        if (m_curDiskInfoData.m_fstype == "unallocated" || m_curDiskInfoData.m_fstype == "linux-swap" || info.m_vgFlag != LVMFlag::LVM_FLAG_NOT_PV) {
-//            actionHidePartition->setDisabled(true);
-//            actionShowPartition->setDisabled(true);
+        if (info.m_luksFlag == LUKSFlag::IS_CRYPT_LUKS) {
+            LUKS_INFO luksInfo = DMDbusHandler::instance()->probLUKSInfo().m_luksMap.value(info.m_path);
+            if (luksInfo.isDecrypt) {
+                if (!luksInfo.m_mapper.m_mountPoints.isEmpty() || luksInfo.m_mapper.m_luksFs == FSType::FS_LVM2_PV) {
+                    actionDelete->setDisabled(true);
+                }
+            }
+        }
+
+        if (m_curDiskInfoData.m_fstype == "unallocated" || m_curDiskInfoData.m_fstype == "linux-swap"
+            || info.m_vgFlag != LVMFlag::LVM_FLAG_NOT_PV) {
+            //            actionHidePartition->setDisabled(true);
+            //            actionShowPartition->setDisabled(true);
             actionDelete->setDisabled(true);
         } /*else {
             if (1 == m_curDiskInfoData.m_flag) {
@@ -205,7 +195,7 @@ void DeviceListWidget::treeMenu(const QPoint &pos)
             }
         }*/
 
-        menu->exec(QCursor::pos());  //显示菜单
+        menu->exec(QCursor::pos()); //显示菜单
         delete menu;
     } else if (m_curDiskInfoData.m_level == DMDbusHandler::VOLUMEGROUP) {
         QMenu *menu = new QMenu(this);
@@ -236,7 +226,7 @@ void DeviceListWidget::treeMenu(const QPoint &pos)
             actionCreate->setDisabled(true);
         }
 
-        menu->exec(QCursor::pos());  //显示菜单
+        menu->exec(QCursor::pos()); //显示菜单
         delete menu;
     } else if (m_curDiskInfoData.m_level == DMDbusHandler::LOGICALVOLUME) {
         QMenu *menu = new QMenu(this);
@@ -256,11 +246,11 @@ void DeviceListWidget::treeMenu(const QPoint &pos)
 
         // 如果VG异常，删除逻辑卷操作禁用
         VGInfo vgInfo = DMDbusHandler::instance()->getCurVGInfo();
-        if (vgInfo.isPartial()) {
+        if (vgInfo.isPartial() || lvInfo.m_lvFsType == FSType::FS_LINUX_SWAP) {
             actionDelete->setDisabled(true);
         }
 
-        menu->exec(QCursor::pos());  //显示菜单
+        menu->exec(QCursor::pos()); //显示菜单
         delete menu;
     }
 }
@@ -287,7 +277,7 @@ void DeviceListWidget::onDiskCheckHealthClicked()
         warningBox.setObjectName("messageBox");
         warningBox.setAccessibleName("warningMessageBox");
         // 获取不到硬件相应信息  关闭
-        warningBox.setWarings(tr("Failed to get hardware information"), "", tr("Close"), "close");
+        warningBox.setWarings(tr("Health checking does not support this type of device."), "", tr("Close"), "close");
         warningBox.exec();
 
         setCurDevicePath("");
@@ -315,33 +305,11 @@ void DeviceListWidget::onDiskBadSectorsClicked()
     setCurDevicePath("");
 }
 
-bool DeviceListWidget::isExistMountPartition()
-{
-    bool isExist = false;
-
-    DeviceInfo info = DMDbusHandler::instance()->getCurDeviceInfo();
-    for (int i = 0; i < info.m_partition.size(); i++) {
-        PartitionInfo partitionInfo = info.m_partition.at(i);
-
-        QString mountpoints;
-        for (int j = 0; j < partitionInfo.m_mountPoints.size(); j++) {
-            mountpoints += partitionInfo.m_mountPoints[j];
-        }
-
-        if (!mountpoints.isEmpty()) {
-            isExist = true;
-            break;
-        }
-    }
-
-    return isExist;
-}
-
 void DeviceListWidget::onCreatePartitionTableClicked()
 {
     setCurDevicePath(m_curDiskInfoData.m_diskPath);
 
-    if (isExistMountPartition()) {
+    if (DMDbusHandler::instance()->isExistMountPartition(DMDbusHandler::instance()->getCurDeviceInfo())) {
         MessageBox warningBox(this);
         warningBox.setObjectName("messageBox");
         warningBox.setAccessibleName("messageBox");
@@ -350,7 +318,7 @@ void DeviceListWidget::onCreatePartitionTableClicked()
         warningBox.exec();
 
         setCurDevicePath("");
-        
+
         return;
     }
 
@@ -400,8 +368,8 @@ void DeviceListWidget::onHidePartitionClicked()
     messageBox.setWarings(tr("Do you want to hide this partition?"), "", tr("Hide"), "hide", tr("Cancel"), "cancel");
     if (messageBox.exec() == DDialog::Accepted) {
         if (m_curDiskInfoData.m_mountpoints == "/boot/efi" || m_curDiskInfoData.m_mountpoints == "/boot"
-                || m_curDiskInfoData.m_mountpoints == "/" || m_curDiskInfoData.m_mountpoints == "/data/home/opt/root/var"
-                || m_curDiskInfoData.m_mountpoints == "/deepin/userdata/home/opt/root/var") {
+            || m_curDiskInfoData.m_mountpoints == "/" || m_curDiskInfoData.m_mountpoints == "/data/home/opt/root/var"
+            || m_curDiskInfoData.m_mountpoints == "/deepin/userdata/home/opt/root/var") {
             isHideSuccess = false;
             // 隐藏分区失败！无法锁定该分区
             DMessageManager::instance()->sendMessage(this->parentWidget()->parentWidget(), QIcon::fromTheme("://icons/deepin/builtin/warning.svg"), tr("Failed to hide the partition: unable to lock it"));
@@ -448,8 +416,8 @@ void DeviceListWidget::onDeletePartitionClicked()
     messageBox.setWarings(tr("Are you sure you want to delete this partition?"), tr("You will lose all data in it"), tr("Delete"), DDialog::ButtonWarning, "delete", tr("Cancel"), "cancel");
     if (messageBox.exec() == DDialog::Accepted) {
         if (m_curDiskInfoData.m_mountpoints == "/boot/efi" || m_curDiskInfoData.m_mountpoints == "/boot"
-                || m_curDiskInfoData.m_mountpoints == "/" || m_curDiskInfoData.m_mountpoints == "/data/home/opt/root/var"
-                || m_curDiskInfoData.m_fstype == "linux-swap" || m_curDiskInfoData.m_mountpoints == "/deepin/userdata/home/opt/root/var") {
+            || m_curDiskInfoData.m_mountpoints == "/" || m_curDiskInfoData.m_mountpoints == "/data/home/opt/root/var"
+            || m_curDiskInfoData.m_fstype == "linux-swap" || m_curDiskInfoData.m_mountpoints == "/deepin/userdata/home/opt/root/var") {
             isDeleteSuccess = false;
             // 删除分区失败！无法锁定该分区
             DMessageManager::instance()->sendMessage(this->parentWidget()->parentWidget(), QIcon::fromTheme("://icons/deepin/builtin/warning.svg"), tr("Failed to delete the partition: unable to lock it"));
@@ -582,7 +550,7 @@ void DeviceListWidget::onDeleteVGClicked()
 {
     VGInfo vgInfo = DMDbusHandler::instance()->getCurVGInfo();
     setCurVGName(vgInfo.m_vgName);
-    if (DMDbusHandler::instance()->isExistMountLV(vgInfo)){
+    if (DMDbusHandler::instance()->isExistMountLV(vgInfo)) {
         MessageBox warningBox(this);
         warningBox.setObjectName("messageBox");
         warningBox.setAccessibleName("messageBox");
@@ -635,11 +603,7 @@ void DeviceListWidget::onDeleteLVClicked()
     LVInfo lvInfo = DMDbusHandler::instance()->getCurLVInfo();
     setCurVGName(lvInfo.m_vgName);
 
-    QString mountPoint = "";
-    for (int i = 0; i < lvInfo.m_mountPoints.size(); i++) {
-        mountPoint += lvInfo.m_mountPoints[i];
-    }
-    if (!mountPoint.isEmpty()){
+    if (DMDbusHandler::instance()->lvIsMount(lvInfo)) {
         MessageBox warningBox(this);
         warningBox.setObjectName("messageBox");
         warningBox.setAccessibleName("messageBox");
@@ -747,6 +711,22 @@ void DeviceListWidget::onLVDeleteMessage(const QString &lvMessage)
     }
 }
 
+void DeviceListWidget::onCreateFailedMessage(const QString &message)
+{
+    QStringList infoList = message.split(":");
+
+    if (infoList.count() <= 2) {
+        return;
+    }
+
+    QString failedReason = DMDbusHandler::instance()->getFailedMessage(infoList.at(0), infoList.at(1).toInt(), infoList.at(2));
+    if (!failedReason.isEmpty()) {
+        DMessageManager::instance()->sendMessage(this->parentWidget()->parentWidget(),
+                                                 QIcon::fromTheme("://icons/deepin/builtin/warning.svg"), failedReason);
+        DMessageManager::instance()->setContentMargens(this->parentWidget()->parentWidget(), QMargins(0, 0, 0, 20));
+    }
+}
+
 void DeviceListWidget::onUpdateUsb()
 {
     if (m_curChooseDevicePath.isEmpty() && m_curChooseVGName.isEmpty())
@@ -765,9 +745,7 @@ void DeviceListWidget::onUpdateUsb()
                 diskBadSectorsDialog->stopCheckRepair();
 
                 diskBadSectorsDialog->close();
-            } else if (widget->objectName() == "diskInfoDisplayDialog" || widget->objectName() == "diskHealthDetectionDialog" ||
-                       widget->objectName() == "partitionErrorCheck" || widget->objectName() == "createPartitionTable" ||
-                       widget->objectName() == "messageBox") {
+            } else if (widget->objectName() == "diskInfoDisplayDialog" || widget->objectName() == "diskHealthDetectionDialog" || widget->objectName() == "partitionErrorCheck" || widget->objectName() == "createPartitionTable" || widget->objectName() == "messageBox") {
                 widget->close();
             } else if (widget->objectName() == "exitMessageBox") {
                 MessageBox *messageBox = static_cast<MessageBox *>(widget);
@@ -785,8 +763,7 @@ void DeviceListWidget::onUpdateUsb()
         QWidgetList widgetList = QApplication::topLevelWidgets();
         for (int i = 0; i < widgetList.count(); i++) {
             QWidget *widget = widgetList.at(i);
-            if (widget->objectName() == "messageBox" || widget->objectName() == "createLVDialog" ||
-                    widget->objectName() == "createLVWidget") {
+            if (widget->objectName() == "messageBox" || widget->objectName() == "createLVDialog" || widget->objectName() == "createLVWidget") {
                 widget->close();
             }
         }
@@ -840,7 +817,8 @@ void DeviceListWidget::onUpdateDeviceInfo()
             if (vgSize.contains("1024")) {
                 vgSize = Utils::LVMFormatSize(vgInformation.m_peCount * vgInformation.m_PESize + vgInformation.m_PESize);
             }
-            auto vgInfoBox = new DmDiskinfoBox(DMDbusHandler::VOLUMEGROUP, this, vgInformation.m_vgName, vgSize, 0, vgInformation.m_vgName);
+            auto vgInfoBox = new DmDiskinfoBox(DMDbusHandler::VOLUMEGROUP, this, vgInformation.m_vgName, vgSize,
+                                               0, vgInformation.m_luksFlag, vgInformation.m_vgName);
             int lvCount = 0;
 
             for (auto lvInfo = vgInformation.m_lvlist.begin(); lvInfo != vgInformation.m_lvlist.end(); lvInfo++) {
@@ -865,17 +843,18 @@ void DeviceListWidget::onUpdateDeviceInfo()
                 if (lvSize.contains("1024")) {
                     lvSize = Utils::LVMFormatSize(lvInfo->m_lvLECount * lvInfo->m_LESize + lvInfo->m_LESize);
                 }
-                auto lvInfoBox = new DmDiskinfoBox(DMDbusHandler::LOGICALVOLUME, this, lvInfo->m_vgName, "", 0, lvInfo->m_lvPath, lvSize, used, unused,
-                                                   0, 0, 0, fstypeName, mountPoints, lvInfo->m_lvName, 0);
+                auto lvInfoBox = new DmDiskinfoBox(DMDbusHandler::LOGICALVOLUME, this, lvInfo->m_vgName, "", 0, lvInfo->m_luksFlag,
+                                                   lvInfo->m_lvPath, lvSize, used, unused, 0, 0, 0, fstypeName,
+                                                   mountPoints, lvInfo->m_lvName, 0);
 
                 vgInfoBox->m_childs.append(lvInfoBox);
 
-                lvCount ++;
+                lvCount++;
             }
             lvmInfoBox->m_childs.append(vgInfoBox);
 
             countVGMap[vgCount] = lvCount;
-            vgCount ++;
+            vgCount++;
         }
 
         auto infoBox = new DmDiskinfoBox(DMDbusHandler::OTHER, this, tr("Disks"), "");
@@ -887,7 +866,8 @@ void DeviceListWidget::onUpdateDeviceInfo()
             }
 
             QString diskSize = Utils::formatSize(info.m_length, info.m_sectorSize);
-            auto diskinfoBox = new DmDiskinfoBox(DMDbusHandler::DISK, this, info.m_path, diskSize, info.m_vgFlag, info.m_path);
+            auto diskinfoBox = new DmDiskinfoBox(DMDbusHandler::DISK, this, info.m_path, diskSize,
+                                                 info.m_vgFlag, info.m_luksFlag, info.m_path);
             int partitionCount = 0;
 
             for (auto it = info.m_partition.begin(); it != info.m_partition.end(); it++) {
@@ -909,24 +889,24 @@ void DeviceListWidget::onUpdateDeviceInfo()
                 }
 
                 QString fileSystemLabel = it->m_fileSystemLabel;
-                auto childDiskinfoBox = new DmDiskinfoBox(DMDbusHandler::PARTITION, this, it->m_devicePath, "", it->m_vgFlag, partitionPath, partitionSize, used, unused,
+                auto childDiskinfoBox = new DmDiskinfoBox(DMDbusHandler::PARTITION, this, it->m_devicePath, "", it->m_vgFlag, it->m_luksFlag,
+                                                          partitionPath, partitionSize, used, unused,
                                                           it->m_sectorsUnallocated, it->m_sectorStart, it->m_sectorEnd, fstypeName,
                                                           mountpoints, fileSystemLabel, it->m_flag);
                 diskinfoBox->m_childs.append(childDiskinfoBox);
 
-                partitionCount ++;
+                partitionCount++;
             }
             infoBox->m_childs.append(diskinfoBox);
 
             countMap[deviceCount] = partitionCount;
-            deviceCount ++;
+            deviceCount++;
         }
         m_treeView->addTopItem(lvmInfoBox, m_addItem);
         m_treeView->addTopItem(infoBox, m_addItem);
 
         QStringList deviceNameList = DMDbusHandler::instance()->getDeviceNameList();
-        if (DMDbusHandler::DISK == DMDbusHandler::instance()->getCurLevel() ||
-                DMDbusHandler::PARTITION == DMDbusHandler::instance()->getCurLevel()) {
+        if (DMDbusHandler::DISK == DMDbusHandler::instance()->getCurLevel() || DMDbusHandler::PARTITION == DMDbusHandler::instance()->getCurLevel()) {
             if (deviceNameList.indexOf(DMDbusHandler::instance()->getCurDevicePath()) == -1) {
                 m_flag = 0;
             } else {
@@ -954,8 +934,7 @@ void DeviceListWidget::onUpdateDeviceInfo()
         } else {
             int index = m_treeView->getCurrentNum();
             if (-1 != m_treeView->getCurrentGroupNum()) {
-                if (DMDbusHandler::DISK == DMDbusHandler::instance()->getCurLevel() ||
-                        DMDbusHandler::PARTITION == DMDbusHandler::instance()->getCurLevel()) {
+                if (DMDbusHandler::DISK == DMDbusHandler::instance()->getCurLevel() || DMDbusHandler::PARTITION == DMDbusHandler::instance()->getCurLevel()) {
                     if (countMap.value(m_deviceNum) == index) {
                         index = m_treeView->getCurrentNum() - 1;
                     }
@@ -992,7 +971,7 @@ void DeviceListWidget::onUpdateDeviceInfo()
             // 针对于逻辑盘插拔时，没有默认选中节点做的处理
             if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::LOGICALVOLUME) {
                 topNum = topNum == m_deviceNum ? topNum : m_deviceNum;
-            } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::VOLUMEGROUP){
+            } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::VOLUMEGROUP) {
                 index = index == m_deviceNum ? index : m_deviceNum;
             }
 
@@ -1009,7 +988,8 @@ void DeviceListWidget::onUpdateDeviceInfo()
             }
 
             QString diskSize = Utils::formatSize(info.m_length, info.m_sectorSize);
-            auto diskinfoBox = new DmDiskinfoBox(DMDbusHandler::DISK, this, info.m_path, diskSize, info.m_vgFlag, info.m_path);
+            auto diskinfoBox = new DmDiskinfoBox(DMDbusHandler::DISK, this, info.m_path, diskSize,
+                                                 info.m_vgFlag, info.m_luksFlag, info.m_path);
             int partitionCount = 0;
 
             for (auto it = info.m_partition.begin(); it != info.m_partition.end(); it++) {
@@ -1031,18 +1011,19 @@ void DeviceListWidget::onUpdateDeviceInfo()
                 }
 
                 QString fileSystemLabel = it->m_fileSystemLabel;
-                auto childDiskinfoBox = new DmDiskinfoBox(DMDbusHandler::PARTITION, this, it->m_devicePath, "", it->m_vgFlag, partitionPath, partitionSize, used, unused,
+                auto childDiskinfoBox = new DmDiskinfoBox(DMDbusHandler::PARTITION, this, it->m_devicePath, "", it->m_vgFlag, it->m_luksFlag,
+                                                          partitionPath, partitionSize, used, unused,
                                                           it->m_sectorsUnallocated, it->m_sectorStart, it->m_sectorEnd, fstypeName,
                                                           mountpoints, fileSystemLabel, it->m_flag);
                 diskinfoBox->m_childs.append(childDiskinfoBox);
 
-                partitionCount ++;
+                partitionCount++;
             }
 
             m_treeView->addTopItem(diskinfoBox, m_addItem);
 
             countMap[deviceCount] = partitionCount;
-            deviceCount ++;
+            deviceCount++;
         }
 
         QStringList deviceNameList = DMDbusHandler::instance()->getDeviceNameList();
