@@ -1,29 +1,8 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file devicelistwidget.h
- *
- * @brief 主要实现磁盘树结构展示以及右键磁盘信息、硬盘健康检测、分区表错误处理、隐藏分区、显示分区、删除分区等操作
- *
- * @date 2020-09-03 14:55
- *
- * Author: yuandandan  <yuandandan@uniontech.com>
- *
- * Maintainer: yuandandan  <yuandandan@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
+
 #ifndef DEVICELISTWIDGET_H
 #define DEVICELISTWIDGET_H
 #include "customcontrol/dmtreeview.h"
@@ -166,12 +145,6 @@ private slots:
      */
     void onDiskBadSectorsClicked();
 
-    /**
-     * @brief 判断当前检测磁盘是否存在被挂载的分区
-     * @return 存在返回true，否则返回false
-     */
-    bool isExistMountPartition();
-
     /**
      * @brief 磁盘新建分区表按钮点击响应的槽函数
      */
@@ -204,6 +177,12 @@ private slots:
      */
     void onLVDeleteMessage(const QString &lvMessage);
 
+    /**
+     * @brief 创建分区/逻辑卷失败信号响应的槽函数
+     * @param message 失败信息
+     */
+    void onCreateFailedMessage(const QString &message);
+
 private:
     int m_flag = 0;
     int m_num = 0;
