@@ -1,29 +1,8 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file diskbadsectorsdialog.cpp
- *
- * @brief 坏道检测与修复主界面窗口
- *
- * @date 2020-12-22 15:56
- *
- * Author: yuandandan  <yuandandan@uniontech.com>
- *
- * Maintainer: yuandandan  <yuandandan@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
+
 #include "diskbadsectorsdialog.h"
 #include "common.h"
 #include "cylinderwidget.h"
@@ -144,7 +123,7 @@ void DiskBadSectorsDialog::initUI()
     }
 
     m_methodComboBox = new DComboBox;
-    m_methodComboBox->addItem(tr("Verifying times")); // 检测次数
+    m_methodComboBox->addItem(tr("Rounds")); // 检测次数
     m_methodComboBox->addItem(tr("Timeout")); // 超时时间
     m_methodComboBox->setFixedSize(155, 36);
     DFontSizeManager::instance()->bind(m_methodComboBox, DFontSizeManager::T6, QFont::Medium);
@@ -960,30 +939,9 @@ void DiskBadSectorsDialog::onResetButtonClicked()
     m_cylinderInfoWidget->reset(m_blockEnd - m_blockStart + 1);
 }
 
-bool DiskBadSectorsDialog::isExistMountPartition()
-{
-    bool isExist = false;
-
-    for (int i = 0; i < m_deviceInfo.m_partition.size(); i++) {
-        PartitionInfo partitionInfo = m_deviceInfo.m_partition.at(i);
-
-        QString mountpoints;
-        for (int j = 0; j < partitionInfo.m_mountPoints.size(); j++) {
-            mountpoints += partitionInfo.m_mountPoints[j];
-        }
-
-        if (!mountpoints.isEmpty()) {
-            isExist = true;
-            break;
-        }
-    }
-
-    return isExist;
-}
-
 void DiskBadSectorsDialog::onRepairButtonClicked()
 {
-    if (isExistMountPartition()) {
+    if (DMDbusHandler::instance()->isExistMountPartition(m_deviceInfo)) {
         MessageBox warningBox(this);
         warningBox.setObjectName("messageBox");
         warningBox.setAccessibleName("messageBox");
