@@ -1,31 +1,13 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file formatedialog.cpp
- *
- * @brief 格式化窗口类
- *
- * @date 2020-09-10 17:22
- *
- * Author: yuandandan  <yuandandan@uniontech.com>
- *
- * Maintainer: yuandandan  <yuandandan@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
+
 #include "formatedialog.h"
 #include "partedproxy/dmdbushandler.h"
+#include "common.h"
+#include "customcontrol/passwordinputdialog.h"
+#include "messagebox.h"
 
 #include <DFontSizeManager>
 #include <DWindowCloseButton>
@@ -45,25 +27,39 @@ FormateDialog::FormateDialog(QWidget *parent)
 
 void FormateDialog::initUi()
 {
-    setFixedSize(450, 355);
+    m_height = 355;
+    setFixedSize(450, m_height);
 
     m_curWipeMethod = WipeType::FAST;
-    int fileSystemType = 11;
+    int fileSystemType = FSType::FS_EXT4;
+    double size = 0;
+    LUKSFlag luksFlag = LUKSFlag::NOT_CRYPT_LUKS;
+    bool isSystemDevice = false;
     if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::PARTITION) {
         PartitionInfo info = DMDbusHandler::instance()->getCurPartititonInfo();
         m_pathInfo = info.m_path;
         fileSystemType = info.m_fileSystemType;
-
         DeviceInfo diskInfo = DMDbusHandler::instance()->getCurDeviceInfo();
         m_curDiskMediaType = diskInfo.m_mediaType;
+        size = Utils::sectorToUnit(info.m_sectorEnd - info.m_sectorStart + 1, info.m_sectorSize, SIZE_UNIT::UNIT_MIB);
+        luksFlag = info.m_luksFlag;
+        isSystemDevice = DMDbusHandler::instance()->getIsSystemDisk(info.m_devicePath);
     } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::DISK) {
         DeviceInfo info = DMDbusHandler::instance()->getCurDeviceInfo();
         m_pathInfo = info.m_path;
         m_curDiskMediaType = info.m_mediaType;
+        size = Utils::sectorToUnit(info.m_length, info.m_sectorSize, SIZE_UNIT::UNIT_MIB);
+        luksFlag = info.m_luksFlag;
+        isSystemDevice = DMDbusHandler::instance()->getIsSystemDisk(info.m_path);
     } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::LOGICALVOLUME) {
-        setFixedSize(450, 315);
+        m_height = 315;
+        setFixedSize(450, m_height);
         LVInfo lvInfo = DMDbusHandler::instance()->getCurLVInfo();
         m_pathInfo = lvInfo.m_lvPath;
+        fileSystemType = lvInfo.m_lvFsType;
+        size = Utils::LVMSizeToUnit(lvInfo.m_lvLECount * lvInfo.m_LESize, SIZE_UNIT::UNIT_MIB);
+        luksFlag = lvInfo.m_luksFlag;
+        isSystemDevice = DMDbusHandler::instance()->getIsSystemDisk(lvInfo.m_vgName);
     }
 
     DPalette palette1;
@@ -83,14 +79,7 @@ void FormateDialog::initUi()
     palette4.setColor(DPalette::ToolTipText, color4);
 
     QVBoxLayout *mainLayout = new QVBoxLayout(m_mainFrame);
-    m_titleLabel = new DLabel(tr("Wipe %1").arg(m_pathInfo), this);
-    QFont fontTitle/* = DFontSizeManager::instance()->get(DFontSizeManager::T6)*/;
-    fontTitle.setWeight(QFont::Medium);
-    fontTitle.setFamily("Source Han Sans");
-    fontTitle.setPixelSize(14);
-    m_titleLabel->setFont(fontTitle);
-    m_titleLabel->setPalette(palette4);
-    mainLayout->addWidget(m_titleLabel, 0, Qt::AlignCenter);
+    setTitle(tr("Wipe %1").arg(m_pathInfo));
     DLabel *tipLabel = new DLabel(tr("It will erase all data on this disk, which will not be recovered"), this);
     tipLabel->setWordWrap(true);
     tipLabel->setFixedHeight(50);
@@ -125,13 +114,41 @@ void FormateDialog::initUi()
 
     QStringList fslist = DMDbusHandler::instance()->getAllSupportFileSystem();
     fslist.removeOne("linux-swap");
+//    QStringList formateList = fslist;
+    if (size > 100 && !isSystemDevice && DMDbusHandler::instance()->getCurLevel() != DMDbusHandler::LOGICALVOLUME) {
+        fslist = DMDbusHandler::instance()->getEncryptionFormate(fslist);
+    }
+
     m_formatComboBox->addItems(fslist);
     m_formatComboBox->setFixedHeight(36);
 
-    if (-1 == fslist.indexOf(Utils::fileSystemTypeToString(static_cast<FSType>(fileSystemType)))) {
-        m_formatComboBox->setCurrentIndex(fslist.indexOf(Utils::fileSystemTypeToString(static_cast<FSType>(11))));
+    QString fsTypeName = Utils::fileSystemTypeToString(static_cast<FSType>(fileSystemType));
+    // 判断当前设备是否加密
+    if (luksFlag == LUKSFlag::IS_CRYPT_LUKS) {
+        LUKS_INFO luksInfo = DMDbusHandler::instance()->probLUKSInfo().m_luksMap.value(m_pathInfo);
+        // 加密设备是否打开，打开格式设为加密格式，未打开默认设为ext4
+        if (luksInfo.isDecrypt) {
+            fileSystemType = luksInfo.m_mapper.m_luksFs;
+            if (-1 == fslist.indexOf(Utils::fileSystemTypeToString(static_cast<FSType>(fileSystemType)))) {
+                fsTypeName = Utils::fileSystemTypeToString(FSType::FS_EXT4);
+            } else {
+                if (luksInfo.m_crypt == CRYPT_CIPHER::AES_XTS_PLAIN64) {
+                    fsTypeName = QString("%1 (%2)").arg(Utils::fileSystemTypeToString(static_cast<FSType>(fileSystemType)))
+                            .arg(tr("AES Encryption"));
+                } else if (luksInfo.m_crypt == CRYPT_CIPHER::SM4_XTS_PLAIN64){
+                    fsTypeName = QString("%1 (%2)").arg(Utils::fileSystemTypeToString(static_cast<FSType>(fileSystemType)))
+                            .arg(tr("SM4 Encryption"));
+                }
+            }
+        } else {
+            fsTypeName = Utils::fileSystemTypeToString(FSType::FS_EXT4);
+        }
+    }
+
+    if (-1 == fslist.indexOf(fsTypeName)) {
+        m_formatComboBox->setCurrentText("ext4");
     } else {
-        m_formatComboBox->setCurrentIndex(fslist.indexOf(Utils::fileSystemTypeToString(static_cast<FSType>(fileSystemType))));
+        m_formatComboBox->setCurrentText(fsTypeName);
     }
 
     DLabel *securityLabel = new DLabel(tr("Security:"), this);
@@ -168,6 +185,7 @@ void FormateDialog::initUi()
     m_describeInfo->setText(tr("It only deletes the partition info without erasing the files on the disk. "
                                "Disk recovery tools may recover the files at a certain probability."));
     m_describeInfo->setFixedHeight(30);
+    m_describeInfo->setAccessibleName("describeInfo");
     m_labelTmp->setFixedHeight(29);
 
     DLabel *wipingLabel = new DLabel(tr("Wiping method:"), this);
@@ -198,11 +216,24 @@ void FormateDialog::initUi()
     m_label->hide();
     m_wipingMethodWidget->hide();
 
+    m_encryptionInfo = new DLabel(this);
+    m_encryptionInfo->setFont(font);
+    m_encryptionInfo->setPalette(palette2);
+    m_encryptionInfo->adjustSize();
+    m_encryptionInfo->setWordWrap(true);
+    m_encryptionInfo->setAccessibleName("encryptionInfo");
+    m_encryptionInfo->hide();
+    m_emptyLabel = new DLabel(this);
+    m_emptyLabel->hide();
+    m_encryptionInfoHeight = 0;
+
     QVBoxLayout *layoutName = new QVBoxLayout;
     layoutName->addWidget(fileName);
     layoutName->addSpacing(10);
     layoutName->addWidget(formatName);
-    layoutName->addSpacing(10);
+    layoutName->addSpacing(5);
+    layoutName->addWidget(m_emptyLabel);
+    layoutName->addSpacing(5);
     layoutName->addWidget(securityLabel);
     layoutName->addSpacing(5);
     layoutName->addWidget(m_labelTmp);
@@ -215,7 +246,9 @@ void FormateDialog::initUi()
     layoutFormat->addWidget(m_fileNameEdit);
     layoutFormat->addSpacing(10);
     layoutFormat->addWidget(m_formatComboBox);
-    layoutFormat->addSpacing(10);
+    layoutFormat->addSpacing(5);
+    layoutFormat->addWidget(m_encryptionInfo);
+    layoutFormat->addSpacing(5);
     layoutFormat->addWidget(m_securityComboBox);
     layoutFormat->addSpacing(5);
     layoutFormat->addWidget(m_describeInfo);
@@ -316,6 +349,11 @@ void FormateDialog::initUi()
 
     mainLayout->addWidget(m_stackedWidget);
     mainLayout->setContentsMargins(0, 0, 0, 0);
+
+    if (m_formatComboBox->currentText().contains("AES") || m_formatComboBox->currentText().contains("SM4")) {
+        QFontMetrics fm(formatName->font());
+        updateEncryptionInfo(m_formatComboBox->currentText(), width() - fm.boundingRect(formatName->text()).width() - 40);
+    }
 }
 
 void FormateDialog::initConnection()
@@ -335,7 +373,7 @@ void FormateDialog::onTextChanged(const QString &text)
 {
     if (!text.isEmpty()) {
         QByteArray byteArray = text.toUtf8();
-        if (m_formatComboBox->currentText() == "fat32") {
+        if (m_formatComboBox->currentText().contains("fat32")) {
             if (byteArray.size() > 11) {
                 m_fileNameEdit->setAlert(true);
                 m_fileNameEdit->showAlertMessage(tr("The length exceeds the limit"), -1);
@@ -368,7 +406,7 @@ void FormateDialog::onComboxFormatTextChange(const QString &text)
     if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::PARTITION ||
             DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::DISK) {
         QByteArray byteArray = m_fileNameEdit->text().toUtf8();
-        if (text == "fat32") {
+        if (text.contains("fat32")) {
             if (byteArray.size() > 11) {
                 m_fileNameEdit->setAlert(true);
                 m_fileNameEdit->showAlertMessage(tr("The length exceeds the limit"), -1);
@@ -394,6 +432,40 @@ void FormateDialog::onComboxFormatTextChange(const QString &text)
             }
         }
     }
+
+    updateEncryptionInfo(text, m_formatComboBox->width());
+}
+
+void FormateDialog::updateEncryptionInfo(const QString &text, const int &width)
+{
+    if (text.contains("AES")) {
+        QString text = tr("Use the aes-xts-plain64 standard algorithm to encrypt the disk. "
+                          "You should decrypt it before mounting it again.");
+        m_encryptionInfoHeight = Common::getLabelAdjustHeight(width, text, m_encryptionInfo->font());
+        m_encryptionInfo->setText(text);
+        setFixedSize(450, m_height + m_encryptionInfoHeight);
+        m_encryptionInfo->setFixedHeight(m_encryptionInfoHeight);
+        m_emptyLabel->setFixedHeight(m_encryptionInfoHeight - 1);
+        m_encryptionInfo->show();
+        m_emptyLabel->show();
+    } else if (text.contains("SM4")) {
+        QString text = tr("Use the sm4-xts-plain state cryptographic algorithm to encrypt the disk. "
+                          "You should decrypt it before mounting it again. Operating Systems that do not support the state "
+                          "cryptographic algorithm will not be able to decrypt the disk.");
+        m_encryptionInfoHeight = Common::getLabelAdjustHeight(width, text, m_encryptionInfo->font());
+        m_encryptionInfo->setText(text);
+        setFixedSize(450, m_height + m_encryptionInfoHeight);
+        m_encryptionInfo->setFixedHeight(m_encryptionInfoHeight);
+        m_emptyLabel->setFixedHeight(m_encryptionInfoHeight - 1);
+        m_encryptionInfo->show();
+        m_emptyLabel->show();
+    } else {
+        m_encryptionInfoHeight = 0;
+        setFixedSize(450, m_height);
+        m_encryptionInfo->hide();
+        m_emptyLabel->hide();
+        m_encryptionInfo->setText("");
+    }
 }
 
 void FormateDialog::onSecurityCurrentIndexChanged(int index)
@@ -402,41 +474,48 @@ void FormateDialog::onSecurityCurrentIndexChanged(int index)
             DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::DISK) {
         switch (index) {
         case 0: {
-            setFixedSize(450, 355);
-            m_describeInfo->setFixedHeight(30);
-            m_labelTmp->setFixedHeight(29);
+            m_describeInfo->setText(tr("It only deletes the partition info without erasing the files on the disk. "
+                                       "Disk recovery tools may recover the files at a certain probability."));
+            int height = Common::getLabelAdjustHeight(m_securityComboBox->width(), m_describeInfo->text(), m_describeInfo->font());
+            m_height = 325 + height;
+            setFixedSize(450, m_height + m_encryptionInfoHeight);
+            m_describeInfo->setFixedHeight(height);
+            m_labelTmp->setFixedHeight(height - 1);
             m_buttonLayout->setContentsMargins(0, 0, 0, 0);
             m_label->hide();
             m_wipingMethodWidget->hide();
             m_curWipeMethod = WipeType::FAST;
-            m_describeInfo->setText(tr("It only deletes the partition info without erasing the files on the disk. "
-                                       "Disk recovery tools may recover the files at a certain probability."));
+
             break;
         }
         case 1: {
-            setFixedSize(450, 365);
-            m_describeInfo->setFixedHeight(40);
-            m_labelTmp->setFixedHeight(40);
+            m_describeInfo->setText(tr("It is a one-time secure wipe that complies with NIST 800-88 and writes 0, 1, "
+                                       "and random data to the entire disk once. You will not be able to recover files, "
+                                       "and the process will be slow."));
+            int height = Common::getLabelAdjustHeight(m_securityComboBox->width(), m_describeInfo->text(), m_describeInfo->font());
+            m_height = 325 + height;
+            setFixedSize(450, m_height + m_encryptionInfoHeight);
+            m_describeInfo->setFixedHeight(height);
+            m_labelTmp->setFixedHeight(height - 1);
             m_buttonLayout->setContentsMargins(0, 0, 0, 0);
             m_label->hide();
             m_wipingMethodWidget->hide();
             m_curWipeMethod = WipeType::SECURE;
-            m_describeInfo->setText(tr("It is a one-time secure wipe that complies with NIST 800-88 and writes 0, 1, "
-                                       "and random data to the entire disk once. You will not be able to recover files, "
-                                       "and the process will be slow."));
             break;
         }
         case 2: {
-            setFixedSize(450, 412);
-            m_describeInfo->setFixedHeight(40);
-            m_labelTmp->setFixedHeight(40);
+            m_describeInfo->setText(tr("It writes 0, 1, and random data to the entire disk several times. You can set the "
+                                       "number of times to erase disks and overwrite data, but the process will be very slow."));
+            int height = Common::getLabelAdjustHeight(m_securityComboBox->width(), m_describeInfo->text(), m_describeInfo->font());
+            m_height = 372 + height;
+            setFixedSize(450, m_height + m_encryptionInfoHeight);
+            m_describeInfo->setFixedHeight(height);
+            m_labelTmp->setFixedHeight(height - 1);
             m_buttonLayout->setContentsMargins(0, 10, 0, 0);
             m_label->show();
             m_wipingMethodWidget->show();
             m_wipingMethodComboBox->setCurrentIndex(0);
             m_curWipeMethod = WipeType::DOD;
-            m_describeInfo->setText(tr("It writes 0, 1, and random data to the entire disk several times. You can set the "
-                                       "number of times to erase disks and overwrite data, but the process will be very slow."));
             break;
         }
         default:
@@ -445,25 +524,29 @@ void FormateDialog::onSecurityCurrentIndexChanged(int index)
     } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::LOGICALVOLUME) {
         switch (index) {
         case 0: {
-            setFixedSize(450, 315);
-            m_describeInfo->setFixedHeight(10);
-            m_labelTmp->setFixedHeight(9);
+            m_describeInfo->setText(tr("You may be able to recover files after the wipe."));
+            int height = Common::getLabelAdjustHeight(m_securityComboBox->width(), m_describeInfo->text(), m_describeInfo->font());
+            m_height = 305 + height;
+            setFixedSize(450, m_height + m_encryptionInfoHeight);
+            m_describeInfo->setFixedHeight(height);
+            m_labelTmp->setFixedHeight(height - 1);
             m_buttonLayout->setContentsMargins(0, 0, 0, 0);
             m_label->hide();
             m_wipingMethodWidget->hide();
             m_curWipeMethod = WipeType::FAST;
-            m_describeInfo->setText(tr("You may be able to recover files after the wipe."));
             break;
         }
         case 1: {
-            setFixedSize(450, 335);
-            m_describeInfo->setFixedHeight(30);
-            m_labelTmp->setFixedHeight(29);
+            m_describeInfo->setText(tr("You will not be able to recover files after the wipe, and the process will be slow."));
+            int height = Common::getLabelAdjustHeight(m_securityComboBox->width(), m_describeInfo->text(), m_describeInfo->font());
+            m_height = 305 + height;
+            setFixedSize(450, m_height + m_encryptionInfoHeight);
+            m_describeInfo->setFixedHeight(height);
+            m_labelTmp->setFixedHeight(height - 1);
             m_buttonLayout->setContentsMargins(0, 0, 0, 0);
             m_label->hide();
             m_wipingMethodWidget->hide();
             m_curWipeMethod = WipeType::SECURE;
-            m_describeInfo->setText(tr("You will not be able to recover files after the wipe, and the process will be slow."));
             break;
         }
         default:
@@ -498,14 +581,79 @@ void FormateDialog::onWipeButtonClicked()
     QString userName = QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
     userName.remove(0, 6);
 
+    QString formate = m_formatComboBox->currentText();
+    QString password = "";
+    QString passwordHint = "";
+    QString encryptName = "";
+    CRYPT_CIPHER encryption = CRYPT_CIPHER::NOT_CRYPT;
+    bool isEncryption = false;
+    if (formate.contains("AES") || formate.contains("SM4")) {
+        PasswordInputDialog passwordInputDialog(this);
+        passwordInputDialog.setDeviceName(m_pathInfo);
+        passwordInputDialog.setAccessibleName("passwordInputDialog");
+        if (passwordInputDialog.exec() != DDialog::Accepted) {
+            return;
+        } else {
+            password = passwordInputDialog.getPassword();
+            passwordHint = passwordInputDialog.getPasswordHint();
+            if (formate.contains("AES")) {
+                encryption = CRYPT_CIPHER::AES_XTS_PLAIN64;
+                encryptName = "aesE";
+            } else if (formate.contains("SM4")) {
+                encryption = CRYPT_CIPHER::SM4_XTS_PLAIN64;
+                encryptName = "sm4E";
+            }
+            isEncryption = true;
+
+            MessageBox warningBox(this);
+            warningBox.setObjectName("messageBox");
+            warningBox.setAccessibleName("messageBox");
+            // 为防止遗忘密码，请您自行备份密码，并妥善保存！  确 定
+            warningBox.setWarings(tr("To avoid losing the password, please back up your password and keep it properly!"),
+                                  tr("OK", "button"), DDialog::ButtonRecommend, "OK");
+            warningBox.setGeometry(pos().x() + (width() - warningBox.width()) / 2, pos().y() + (height() - warningBox.height()) / 2,
+                                   warningBox.width(), warningBox.height());
+            warningBox.exec();
+        }
+
+        formate = formate.trimmed().split(" ").at(0);
+    }
+
     if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::PARTITION ||
             DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::DISK) {
-        if (m_fileNameEdit->text().isEmpty()) {
-            DMDbusHandler::instance()->clear(m_formatComboBox->currentText(), m_pathInfo, " ",
-                                             userName, DMDbusHandler::instance()->getCurLevel(), m_curWipeMethod);
+        WipeAction wipe;
+        wipe.m_fstype = formate;
+        wipe.m_path = m_pathInfo;
+        wipe.m_user = userName;
+        wipe.m_diskType = DMDbusHandler::instance()->getCurLevel();
+        wipe.m_clearType = m_curWipeMethod;
+        wipe.m_crypt = encryption;
+        wipe.m_decryptStr = password;
+        if (isEncryption) {
+            wipe.m_luksFlag = LUKSFlag::IS_CRYPT_LUKS;
+            QStringList tokenList;
+            if (!passwordHint.isEmpty()) {
+                tokenList.append(passwordHint);
+            }
+
+            wipe.m_tokenList = tokenList;
+            if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::DISK) {
+                wipe.m_dmName = "";
+            } else {
+                m_pathInfo == "unallocated" ? wipe.m_dmName = "" : wipe.m_dmName = QString("%1_%2").arg(m_pathInfo.remove("/dev/")).arg(encryptName);
+            }
         } else {
-            DMDbusHandler::instance()->clear(m_formatComboBox->currentText(), m_pathInfo, m_fileNameEdit->text(),
-                                             userName, DMDbusHandler::instance()->getCurLevel(), m_curWipeMethod);
+            wipe.m_luksFlag = LUKSFlag::NOT_CRYPT_LUKS;
+            wipe.m_tokenList = QStringList();
+            wipe.m_dmName = "";
+        }
+
+        if (m_fileNameEdit->text().isEmpty()) {
+            wipe.m_fileSystemLabel  = " ";
+            DMDbusHandler::instance()->clear(wipe);
+        } else {
+            wipe.m_fileSystemLabel  = m_fileNameEdit->text();
+            DMDbusHandler::instance()->clear(wipe);
         }
     } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::LOGICALVOLUME) {
         LVInfo lvInfo = DMDbusHandler::instance()->getCurLVInfo();
@@ -513,17 +661,33 @@ void FormateDialog::onWipeButtonClicked()
         LVAction lvAction;
         lvAction.m_vgName = lvInfo.m_vgName;
         lvAction.m_lvName = lvInfo.m_lvName;
-        lvAction.m_lvFs = Utils::stringToFileSystemType(m_formatComboBox->currentText());
+        lvAction.m_lvFs = Utils::stringToFileSystemType(formate);
         lvAction.m_user = userName;
         lvAction.m_lvSize = lvInfo.m_lvSize;
         lvAction.m_lvByteSize = lvInfo.m_lvLECount * lvInfo.m_LESize;
         lvAction.m_lvAct = (m_curWipeMethod == WipeType::FAST) ? LVMAction::LVM_ACT_LV_FAST_CLEAR : LVMAction::LVM_ACT_LV_SECURE_CLEAR;
+        lvAction.m_crypt = encryption;
+        lvAction.m_decryptStr = password;
+        if (isEncryption) {
+            lvAction.m_luksFlag = LUKSFlag::IS_CRYPT_LUKS;
+            QStringList tokenList;
+            if (!passwordHint.isEmpty()) {
+                tokenList.append(passwordHint);
+            }
+
+            lvAction.m_tokenList = tokenList;
+            lvAction.m_dmName = QString("%1_%2_%3").arg(lvInfo.m_vgName).arg(lvInfo.m_lvName).arg(encryptName);
+        } else {
+            lvAction.m_luksFlag = LUKSFlag::NOT_CRYPT_LUKS;
+            lvAction.m_tokenList = QStringList();
+            lvAction.m_dmName = "";
+        }
 
         DMDbusHandler::instance()->onClearLV(lvAction);
     }
 
     // 擦除等待动画
-    m_titleLabel->setText(tr("Wiping %1").arg(m_pathInfo) + "...");
+    setTitle(tr("Wiping %1").arg(m_pathInfo) + "...");
     m_stackedWidget->setCurrentIndex(1);
     DWindowCloseButton *button = findChild<DWindowCloseButton *>("DTitlebarDWindowCloseButton");
     if (button != nullptr) {
@@ -538,12 +702,17 @@ void FormateDialog::onWipeResult(const QString &info)
 {
     QStringList infoList = info.split(":");
 
-    if (infoList.count() <= 1) {
+    if (infoList.count() <= 2) {
         return;
     }
 
     m_waterLoadingWidget->stopTimer();
-    if (infoList.at(0) == "1") {
+    bool isSuccess = false;
+    if (infoList.at(0) == "DISK_ERROR" && infoList.at(1).toInt() == DISK_ERROR::DISK_ERR_NORMAL) {
+        isSuccess = true;
+    }
+
+    if (isSuccess) {
         DMessageManager::instance()->sendMessage(this->parentWidget()->parentWidget()->parentWidget()->parentWidget(),
                                                  QIcon::fromTheme("://icons/deepin/builtin/ok.svg"),
                                                  tr("\"%1\" wiped").arg(m_pathInfo));
@@ -552,33 +721,15 @@ void FormateDialog::onWipeResult(const QString &info)
 
         close();
     } else {
-        m_titleLabel->setText(tr("Failed to wipe %1").arg(m_pathInfo));
+        QString failedReason = DMDbusHandler::instance()->getFailedMessage(infoList.at(0), infoList.at(1).toInt(), "");
+        setTitle(tr("Failed to wipe %1").arg(m_pathInfo));
         m_stackedWidget->setCurrentIndex(2);
 
         DWindowCloseButton *button = findChild<DWindowCloseButton *>("DTitlebarDWindowCloseButton");
         button->setDisabled(false);
         button->show();
 
-        switch (infoList.at(1).toInt()) {
-        case DISK_ERROR::DISK_ERR_DISK_INFO: {
-            m_failLabel->setText(tr("Failed to find the disk"));
-            break;
-        }
-        case DISK_ERROR::DISK_ERR_PART_INFO: {
-            m_failLabel->setText(tr("Failed to get the partition info"));
-            break;
-        }
-        case DISK_ERROR::DISK_ERR_DELETE_PART_FAILED: {
-            m_failLabel->setText(tr("Failed to delete the partition"));
-            break;
-        }
-        case DISK_ERROR::DISK_ERR_UPDATE_KERNEL_FAILED: {
-            m_failLabel->setText(tr("Failed to submit the request to the kernel"));
-            break;
-        }
-        default:
-            break;
-        }
+        m_failLabel->setText(failedReason);
     }
 }
 
