@@ -1,29 +1,8 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file formatedialog.h
- *
- * @brief 格式化窗口类
- *
- * @date 2020-09-10 17:22
- *
- * Author: yuandandan  <yuandandan@uniontech.com>
- *
- * Maintainer: yuandandan  <yuandandan@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
+
 #ifndef FORMATEDIALOG_H
 #define FORMATEDIALOG_H
 
@@ -70,6 +49,12 @@ private:
      */
     void initConnection();
 
+    /**
+     * @brief 更新加密算法信息
+     */
+    void updateEncryptionInfo(const QString &text, const int &width);
+
+private:
     DComboBox *m_formatComboBox;
     DLineEdit *m_fileNameEdit;
     DComboBox *m_securityComboBox;
@@ -82,12 +67,15 @@ private:
     DWarningButton *m_warningButton;
     DStackedWidget *m_stackedWidget;
     DLabel *m_failLabel;
-    DLabel *m_titleLabel;
     QString m_pathInfo;
     int m_curWipeMethod;
     QString m_curDiskMediaType;
     QHBoxLayout *m_buttonLayout;
     WaterLoadingWidget *m_waterLoadingWidget;
+    DLabel *m_encryptionInfo;
+    DLabel *m_emptyLabel;
+    int m_height;
+    int m_encryptionInfoHeight;
 signals:
 
 private slots:
