@@ -1,29 +1,8 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file unmountdialog.cpp
- *
- * @brief 实现分区卸载
- *
- * @date 2020-09-17 09:12
- *
- * Author: yuandandan  <yuandandan@uniontech.com>
- *
- * Maintainer: yuandandan  <yuandandan@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
+
 #include "unmountdialog.h"
 #include "partedproxy/dmdbushandler.h"
 #include "messagebox.h"
@@ -60,6 +39,9 @@ void UnmountDialog::initUi()
         setTitle(tr("Unmount %1").arg(lvInfo.m_lvName));
 
         tipLabel->setText(tr("Make sure there are no programs running on the logical volume"));
+    } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::DISK) {
+        DeviceInfo info = DMDbusHandler::instance()->getCurDeviceInfo();
+        setTitle(tr("Unmount %1").arg(info.m_path));
     }
 
     int index = addButton(tr("Cancel"), false, ButtonNormal);
@@ -78,19 +60,32 @@ void UnmountDialog::initConnection()
 void UnmountDialog::umountCurMountPoints()
 {
     if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::PARTITION) {
-        DMDbusHandler::instance()->unmount();
+        PartitionInfo info = DMDbusHandler::instance()->getCurPartititonInfo();
+        if (info.m_luksFlag == LUKSFlag::IS_CRYPT_LUKS) {
+            DMDbusHandler::instance()->cryptUmount(DMDbusHandler::instance()->probLUKSInfo().m_luksMap.value(info.m_path), info.m_path);
+        } else {
+            DMDbusHandler::instance()->unmount();
+        }
     } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::LOGICALVOLUME) {
         LVInfo lvInfo = DMDbusHandler::instance()->getCurLVInfo();
+        if (lvInfo.m_luksFlag == LUKSFlag::IS_CRYPT_LUKS) {
+            DMDbusHandler::instance()->cryptUmount(DMDbusHandler::instance()->probLUKSInfo().m_luksMap.value(lvInfo.m_lvPath), lvInfo.m_lvName);
+        } else {
+            LVAction lvAction;
+            lvAction.m_vgName = lvInfo.m_vgName;
+            lvAction.m_lvName = lvInfo.m_lvName;
+            lvAction.m_lvFs = lvInfo.m_lvFsType;
+            lvAction.m_lvSize = lvInfo.m_lvSize;
+            lvAction.m_lvByteSize = lvInfo.m_lvLECount * lvInfo.m_LESize;
+            lvAction.m_lvAct = LVMAction::LVM_ACT_LV_UMOUNT;
 
-        LVAction lvAction;
-        lvAction.m_vgName = lvInfo.m_vgName;
-        lvAction.m_lvName = lvInfo.m_lvName;
-        lvAction.m_lvFs = lvInfo.m_lvFsType;
-        lvAction.m_lvSize = lvInfo.m_lvSize;
-        lvAction.m_lvByteSize = lvInfo.m_lvLECount * lvInfo.m_LESize;
-        lvAction.m_lvAct = LVMAction::LVM_ACT_LV_UMOUNT;
-
-        DMDbusHandler::instance()->onUmountLV(lvAction);
+            DMDbusHandler::instance()->onUmountLV(lvAction);
+        }
+    } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::DISK) {
+        DeviceInfo info = DMDbusHandler::instance()->getCurDeviceInfo();
+        if (info.m_luksFlag == LUKSFlag::IS_CRYPT_LUKS) {
+            DMDbusHandler::instance()->cryptUmount(DMDbusHandler::instance()->probLUKSInfo().m_luksMap.value(info.m_path), info.m_path);
+        }
     }
 }
 
@@ -98,26 +93,34 @@ void UnmountDialog::onButtonClicked(int index, const QString &text)
 {
     Q_UNUSED(text);
     if (m_okCode == index) {
-        QString mountPoints;
-        int flag = 0;
+        int partitionFlag = 0;
+        bool isSysPath = false;
+        bool lvFlag = false;
         if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::PARTITION) {
             PartitionInfo info = DMDbusHandler::instance()->getCurPartititonInfo();
+            partitionFlag = info.m_flag;
 
             for (int i = 0; i < info.m_mountPoints.size(); i++) {
-                mountPoints += info.m_mountPoints[i];
+                if (info.m_mountPoints[i] == "/boot/efi" || info.m_mountPoints[i] == "/boot"
+                        || info.m_mountPoints[i] == "/" || info.m_mountPoints[i] == "/recovery") {
+                    isSysPath = true;
+                    break;
+                }
             }
-
-            flag = info.m_flag;
-        } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::PARTITION) {
+        } else if (DMDbusHandler::instance()->getCurLevel() == DMDbusHandler::LOGICALVOLUME) {
             LVInfo lvInfo = DMDbusHandler::instance()->getCurLVInfo();
+            lvFlag = lvInfo.m_dataFlag;
             for (int i = 0; i < lvInfo.m_mountPoints.size(); i++) {
-                mountPoints += lvInfo.m_mountPoints[i];
+                if (lvInfo.m_mountPoints[i] == "/boot/efi" || lvInfo.m_mountPoints[i] == "/boot"
+                        || lvInfo.m_mountPoints[i] == "/" || lvInfo.m_mountPoints[i] == "/recovery") {
+                    isSysPath = true;
+                    break;
+                }
             }
         }
 
         qDebug() << __FUNCTION__;
-        if (mountPoints == "/boot/efi" || mountPoints == "/boot" || mountPoints == "/"
-                || mountPoints == "/recovery" || flag == 4) {
+        if (isSysPath || partitionFlag == 4 || lvFlag) {
             UnmountWarningDialog unmountWarningDialog;
             unmountWarningDialog.setObjectName("firstWarning");
             unmountWarningDialog.setAccessibleName("firstWarning");
