@@ -1,61 +1,11 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
 #include "deviceinfo.h"
 #include <QDBusArgument>
 
-QDBusArgument &operator<<(QDBusArgument &argument, const DeviceInfo &info)
-{
-    argument.beginStructure();
-    argument << info.m_length
-             << info.m_heads
-             << info.m_path
-             << info.m_sectors
-             << info.m_cylinders
-             << info.m_cylsize
-             << info.m_model
-             << info.m_serialNumber
-             << info.m_disktype
-             << info.m_sectorSize
-             << info.m_maxPrims
-             << info.m_highestBusy
-             << info.m_readonly
-             << info.m_maxPartitionNameLength
-             << info.m_partition
-             << info.m_mediaType
-             << info.m_interface
-             << static_cast<int>(info.m_vgFlag)
-             << info.m_vglist;
-    argument.endStructure();
-
-    return argument;
-}
-
-const QDBusArgument &operator>>(const QDBusArgument &argument, DeviceInfo &info)
-{
-    argument.beginStructure();
-    int flag=0;
-    argument >> info.m_length
-             >> info.m_heads
-             >> info.m_path
-             >> info.m_sectors
-             >> info.m_cylinders
-             >> info.m_cylsize
-             >> info.m_model
-             >> info.m_serialNumber
-             >> info.m_disktype
-             >> info.m_sectorSize
-             >> info.m_maxPrims
-             >> info.m_highestBusy
-             >> info.m_readonly
-             >> info.m_maxPartitionNameLength
-             >> info.m_partition
-             >> info.m_mediaType
-             >> info.m_interface
-             >> flag
-             >> info.m_vglist;
-    info.m_vgFlag = static_cast<LVMFlag>(flag);
-    argument.endStructure();
-    return argument;
-}
-
+/*********************************** stCustest          *********************************************/
 QDBusArgument &operator<<(QDBusArgument &argument, const stCustest &stcus)
 {
     argument.beginStructure();
@@ -76,6 +26,7 @@ const QDBusArgument &operator>>(const QDBusArgument &argument, stCustest &stcus)
     argument.endStructure();
     return argument;
 }
+/*********************************** HardDiskInfo       *********************************************/
 QDBusArgument &operator<<(QDBusArgument &argument, const HardDiskInfo &inhdinfo)
 {
     argument.beginStructure();
@@ -117,7 +68,7 @@ const QDBusArgument &operator>>(const QDBusArgument &argument, HardDiskInfo &inh
     argument.endStructure();
     return argument;
 }
-
+/*********************************** HardDiskStatusInfo *********************************************/
 QDBusArgument &operator<<(QDBusArgument &argument, const HardDiskStatusInfo &inhdinfo)
 {
     argument.beginStructure();
@@ -150,6 +101,66 @@ const QDBusArgument &operator>>(const QDBusArgument &argument, HardDiskStatusInf
     argument.endStructure();
     return argument;
 }
+/*********************************** DeviceInfo         *********************************************/
+QDBusArgument &operator<<(QDBusArgument &argument, const DeviceInfo &info)
+{
+    argument.beginStructure();
+    argument << info.m_length
+             << info.m_heads
+             << info.m_path
+             << info.m_sectors
+             << info.m_cylinders
+             << info.m_cylsize
+             << info.m_model
+             << info.m_serialNumber
+             << info.m_disktype
+             << info.m_sectorSize
+             << info.m_maxPrims
+             << info.m_highestBusy
+             << info.m_readonly
+             << info.m_maxPartitionNameLength
+             << info.m_partition
+             << info.m_mediaType
+             << info.m_interface
+             << static_cast<int>(info.m_vgFlag)
+             << info.m_vglist
+             << static_cast<int>(info.m_luksFlag)
+             << info.m_crySupport;
+    argument.endStructure();
+    return argument;
+}
+
+const QDBusArgument &operator>>(const QDBusArgument &argument, DeviceInfo &info)
+{
+    argument.beginStructure();
+    int flag = 0;
+    int flag2 = 0;
+    argument >> info.m_length
+             >> info.m_heads
+             >> info.m_path
+             >> info.m_sectors
+             >> info.m_cylinders
+             >> info.m_cylsize
+             >> info.m_model
+             >> info.m_serialNumber
+             >> info.m_disktype
+             >> info.m_sectorSize
+             >> info.m_maxPrims
+             >> info.m_highestBusy
+             >> info.m_readonly
+             >> info.m_maxPartitionNameLength
+             >> info.m_partition
+             >> info.m_mediaType
+             >> info.m_interface
+             >> flag
+             >> info.m_vglist
+             >> flag2
+             >> info.m_crySupport;
+    info.m_vgFlag = static_cast<LVMFlag>(flag);
+    info.m_luksFlag = static_cast<LUKSFlag>(flag2);
+    argument.endStructure();
+    return argument;
+}
 
 DeviceInfo::DeviceInfo()
     : m_readonly(false)
@@ -159,4 +170,44 @@ DeviceInfo::DeviceInfo()
     m_partition.clear();
     m_vgFlag = LVM_FLAG_NOT_PV;
     m_vglist.clear();
+    m_luksFlag = LUKSFlag::NOT_CRYPT_LUKS;
+}
+/*********************************** WipeAction         *********************************************/
+QDBusArgument &operator<<(QDBusArgument &argument, const WipeAction &data)
+{
+    argument.beginStructure();
+    argument << data.m_fstype
+             << data.m_path
+             << data.m_fileSystemLabel
+             << data.m_user
+             << data.m_diskType
+             << data.m_clearType
+             << static_cast<int>(data.m_luksFlag)
+             << static_cast<int>(data.m_crypt)
+             << data.m_tokenList
+             << data.m_decryptStr
+             << data.m_dmName;
+    argument.endStructure();
+    return argument;
+}
+
+const QDBusArgument &operator>>(const QDBusArgument &argument, WipeAction &data)
+{
+    argument.beginStructure();
+    int flag1, flag2;
+    argument >> data.m_fstype
+             >> data.m_path
+             >> data.m_fileSystemLabel
+             >> data.m_user
+             >> data.m_diskType
+             >> data.m_clearType
+             >> flag1
+             >> flag2
+             >> data.m_tokenList
+             >> data.m_decryptStr
+             >> data.m_dmName;
+    data.m_luksFlag = static_cast<LUKSFlag>(flag1);
+    data.m_crypt = static_cast<CRYPT_CIPHER>(flag2);
+    argument.endStructure();
+    return argument;
 }
