@@ -1,29 +1,7 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file partitioninfo.cpp
- *
- * @brief 分区信息类
- *
- * @date 2020-09-21 14:49
- *
- * Author: liweigang  <liweigang@uniontech.com>
- *
- * Maintainer: liweigang  <liweigang@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
 
 #include "partitioninfo.h"
 
@@ -94,8 +72,12 @@ QDBusArgument &operator<<(QDBusArgument &argument, const PartitionInfo &info)
              << static_cast<int>(info.m_vgFlag)
              << info.m_vgData
              << info.m_fsLimits.min_size
-             << info.m_fsLimits.max_size;
-
+             << info.m_fsLimits.max_size
+             << static_cast<int>(info.m_luksFlag)
+             << static_cast<int>(info.m_crypt)
+             << info.m_tokenList
+             << info.m_decryptStr
+             << info.m_dmName;;
     argument.endStructure();
 
     return argument;
@@ -105,6 +87,8 @@ const QDBusArgument &operator>>(const QDBusArgument &argument, PartitionInfo &in
 {
     argument.beginStructure();
     int flag = 0;
+    int flag2 = 0;
+    int crypt = 0;
     argument >> info.m_devicePath
              >> info.m_partitionNumber
              >> info.m_type
@@ -132,8 +116,15 @@ const QDBusArgument &operator>>(const QDBusArgument &argument, PartitionInfo &in
              >> flag
              >> info.m_vgData
              >> info.m_fsLimits.min_size
-             >> info.m_fsLimits.max_size;
+             >> info.m_fsLimits.max_size
+             >> flag2
+             >> crypt
+             >> info.m_tokenList
+             >> info.m_decryptStr
+             >> info.m_dmName;
     info.m_vgFlag = static_cast<LVMFlag>(flag);
+    info.m_luksFlag = static_cast<LUKSFlag>(flag2);
+    info.m_crypt = static_cast<CRYPT_CIPHER>(crypt);
     argument.endStructure();
 
     return argument;
