@@ -1,29 +1,7 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file utils.cpp
- *
- * @brief 公共方法类
- *
- * @date 2020-09-21 14:41
- *
- * Author: liweigang  <liweigang@uniontech.com>
- *
- * Maintainer: liweigang  <liweigang@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
 
 #include "lvmstruct.h"
 #include "utils.h"
@@ -36,6 +14,8 @@
 #include <QDebug>
 #include <algorithm>
 #include <math.h>
+#include <QFile>
+#include <QDir>
 
 Utils::Utils()
 {
@@ -415,7 +395,7 @@ QString Utils::getFileSystemSoftWare(FSType fileSystemType)
 {
     switch (fileSystemType) {
     case FS_BTRFS:
-        return "btrfs-progs / btrfs-tools";
+        return "btrfs.h-progs / btrfs.h-tools";
     case FS_EXT2:
         return "e2fsprogs";
     case FS_EXT3:
@@ -599,7 +579,7 @@ bool Utils::adjudicationPVDelete(LVMInfo lvmInfo, const set<QString> &pvStrList,
         }
 
         PVInfo pv =  lvmInfo.getPV(pvPath);
-        if(pv.noJoinVG()){              //只获取加入vg的pv路径
+        if (pv.noJoinVG()) {            //只获取加入vg的pv路径
             continue;
         }
 
@@ -637,6 +617,83 @@ bool Utils::adjudicationPVDelete(LVMInfo lvmInfo, const set<QString> &pvStrList,
     return true;
 }
 
+QString Utils::getCipherStr(CRYPT_CIPHER cipher)
+{
+    switch (cipher) {
+    case CRYPT_CIPHER::NOT_CRYPT:
+        return QString("not_crypt");
+    case CRYPT_CIPHER::AES_XTS_PLAIN64:
+        return QString("aes-xts-plain64");
+    case CRYPT_CIPHER::SM4_XTS_PLAIN64:
+        return QString("sm4-xts-plain64");
+    default:
+        return QString("crypt_unknow");
+    }
+}
+
+CRYPT_CIPHER Utils::getCipher(QString cipher)
+{
+    if (cipher.contains("not_crypt")) {
+        return  CRYPT_CIPHER::NOT_CRYPT;
+    } else if (cipher.contains("aes-xts-plain64")) {
+        return  CRYPT_CIPHER::AES_XTS_PLAIN64;
+    } else if (cipher.contains("sm4-xts-plain64")) {
+        return  CRYPT_CIPHER::SM4_XTS_PLAIN64;
+    } else {
+        return  CRYPT_CIPHER::CRYPT_UNkNOW;
+    }
+
+}
+
+bool Utils::kernelSupportFS(const QString &fsType)
+{
+    bool supported = false;
+    QFile file("/proc/filesystems");
+    if (file.open(QIODevice::ReadOnly)) {
+        QString info = file.readAll();
+        if (info.contains(fsType)) {
+            supported = true;
+        }
+        file.close();
+    }
+    return supported;
+}
+
+QString Utils::mkTempDir(const QString &infix)
+{
+    // Construct template like "/var/tmp/diskmanager-XXXXXX" or "/var/tmp/diskmanager-INFIX-XXXXXX"
+    QString dirTemplate = "/var/tmp/";
+
+    if (!infix.isEmpty()) {
+        dirTemplate += infix + "-" ;
+    }
+    dirTemplate += "XXXXXX" ;
+    QDir dir(dirTemplate);
+    if (!dir.exists() && dir.mkpath(dirTemplate)) {
+        return dirTemplate;
+    }
+    return dirTemplate;
+}
+
+void Utils::rmTempDir(QString &dirName)
+{
+    QDir dir(dirName);
+    if (dir.exists()) {
+        dir.remove(dirName);
+    }
+}
+
+int Utils::executCmd(const QString &strCmd)
+{
+    QProcess proc;
+    proc.setProgram(strCmd);
+    proc.start(QIODevice::ReadWrite);
+    proc.waitForFinished(-1);
+    int exitcode = proc.exitCode();
+    proc.close();
+    return exitcode;
+}
+
 
 
 
