@@ -1,33 +1,12 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file utils.h
- *
- * @brief 公共方法类
- *
- * @date 2020-09-21 14:13
- *
- * Author: liweigang  <liweigang@uniontech.com>
- *
- * Maintainer: liweigang  <liweigang@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
 
 #ifndef UTILS_H
 #define UTILS_H
 #include "commondef.h"
+#include "luksenum.h"
 
 #include <QString>
 #include <QStringList>
@@ -73,6 +52,8 @@ public:
      */
     static int executCmd(const QString &strCmd, QString &outPut, QString &error);
 
+    static int executCmd(const QString &strCmd);
+
     /**
      * @brief 执行外部命令，使用 /bin/bash -c 执行管道命令
      * @param strCmd：命令
@@ -213,7 +194,42 @@ public:
      */
     static bool adjudicationPVDelete(LVMInfo lvmInfo, const set<QString> &pvStrList, bool &bigDataMove, QStringList &realMovePvList);
 
+    /**
+     * @brief 删除指针
+     * @param point:待删除指针
+     */
+    template<typename T>
+    static inline void deletePoint( T *& point){
+        if(point !=nullptr){
+            delete point;
+            point = nullptr;
+        }
+    }
 
+    /**
+     * @brief 根据枚举获取算法字符串
+     * @param cipher:算法枚举
+     * @return 算法字符串
+     */
+    static QString getCipherStr(CRYPT_CIPHER cipher);
+
+    /**
+     * @brief 根据字符串获取枚举值
+     * @param cipher:算法字符串
+     * @return 算法枚举
+     */
+    static CRYPT_CIPHER getCipher(QString cipher);
+
+    /**
+    * @brief 判断内核是否支持指定的文件系统
+    * @param fsType:文件系统类型名，如ext4
+    * @return 支持：true，否则false
+    */
+    static bool kernelSupportFS(const QString &fsType);
+
+    static QString mkTempDir(const QString &infix);
+
+    static void  rmTempDir(QString &dirName);
 };
 
 #endif // UTILS_H
