@@ -1,29 +1,6 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file diskmanagerservice.cpp
- *
- * @brief 磁盘分区操作封装类
- *
- * @date 2020-09-04 11:10
- *
- * Author: liweigang  <liweigang@uniontech.com>
- *
- * Maintainer: liweigang  <liweigang@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
 
 #include "diskmanagerservice.h"
 
@@ -41,6 +18,30 @@ DiskManagerService::DiskManagerService(QObject *parent)
     initConnection();
 }
 
+void DiskManagerService::initConnection()
+{
+    connect(m_partedcore, &PartedCore::updateDeviceInfo, this, &DiskManagerService::updateDeviceInfo);
+    connect(m_partedcore, &PartedCore::updateLUKSInfo, this, &DiskManagerService::updateLUKSInfo);
+    connect(m_partedcore, &PartedCore::deletePartitionMessage, this, &DiskManagerService::deletePartition);
+    connect(m_partedcore, &PartedCore::hidePartitionInfo, this, &DiskManagerService::hidePartitionInfo);
+    connect(m_partedcore, &PartedCore::showPartitionInfo, this, &DiskManagerService::showPartitionInfo);
+    connect(m_partedcore, &PartedCore::usbUpdated, this, &DiskManagerService::usbUpdated);
+    connect(m_partedcore, &PartedCore::checkBadBlocksCountInfo, this, &DiskManagerService::checkBadBlocksCountInfo);
+    connect(m_partedcore, &PartedCore::fixBadBlocksInfo, this, &DiskManagerService::fixBadBlocksInfo);
+    connect(m_partedcore, &PartedCore::checkBadBlocksFinished, this, &DiskManagerService::checkBadBlocksFinished);
+    connect(m_partedcore, &PartedCore::fixBadBlocksFinished, this, &DiskManagerService::fixBadBlocksFinished);
+    connect(m_partedcore, &PartedCore::unmountPartition, this, &DiskManagerService::unmountPartition);
+    connect(m_partedcore, &PartedCore::createTableMessage, this, &DiskManagerService::createTableMessage);
+    connect(m_partedcore, &PartedCore::vgCreateMessage, this, &DiskManagerService::vgCreateMessage);
+    connect(m_partedcore, &PartedCore::pvDeleteMessage, this, &DiskManagerService::pvDeleteMessage);
+    connect(m_partedcore, &PartedCore::vgDeleteMessage, this, &DiskManagerService::vgDeleteMessage);
+    connect(m_partedcore, &PartedCore::lvDeleteMessage, this, &DiskManagerService::lvDeleteMessage);
+    connect(m_partedcore, &PartedCore::clearMessage, this, &DiskManagerService::clearMessage);
+    connect(m_partedcore, &PartedCore::deCryptMessage, this, &DiskManagerService::deCryptMessage);
+    connect(m_partedcore, &PartedCore::createFailedMessage, this, &DiskManagerService::createFailedMessage);
+    connect(this, &DiskManagerService::getAllDeviceInfomation, this, &DiskManagerService::onGetAllDeviceInfomation);
+}
+
 void DiskManagerService::Quit()
 {
     qDebug() << "DiskManagerService::Quit called";
@@ -74,6 +75,7 @@ DeviceInfo DiskManagerService::getDeviceinfo()
     return m_partedcore->getDeviceinfo();
 }
 
+//TODO： 这里感觉没有必要发送信号 等之后有时间测试一下 能否去掉多余的代码
 void DiskManagerService::getalldevice()
 {
 //    qDebug() << "DiskManagerService::getalldevice";
@@ -86,6 +88,8 @@ void DiskManagerService::onGetAllDeviceInfomation()
 {
     DeviceInfoMap infores = m_partedcore->getAllDeviceinfo();
     LVMInfo lvmInfo = m_partedcore->getAllLVMinfo();
+    LUKSMap luksInfo = m_partedcore->getAllLUKSinfo();
+    Q_EMIT updateLUKSInfo(luksInfo);
     Q_EMIT updateDeviceInfo(infores, lvmInfo);
 }
 
@@ -104,6 +108,21 @@ bool DiskManagerService::mount(const QString &mountpath)
     return m_partedcore->mountAndWriteFstab(mountpath);
 }
 
+bool DiskManagerService::deCrypt(const LUKS_INFO &luks)
+{
+    return m_partedcore->deCrypt(luks);
+}
+
+bool DiskManagerService::cryptMount(const LUKS_INFO &luks)
+{
+    return m_partedcore->cryptMount(luks);
+}
+
+bool DiskManagerService::cryptUmount(const LUKS_INFO &luks)
+{
+    return m_partedcore->cryptUmount(luks);
+}
+
 QStringList DiskManagerService::getallsupportfs()
 {
     return m_partedcore->getallsupportfs();
@@ -114,9 +133,9 @@ bool DiskManagerService::format(const QString &fstype, const QString &name)
     return m_partedcore->format(fstype, name);
 }
 
-bool DiskManagerService::clear(const QString &fstype, const QString &path, const QString &name, const QString &user, const int &diskType, const int &clearType)
+bool DiskManagerService::clear(const WipeAction &wipe)
 {
-    return m_partedcore->clear(fstype, path, name, user, diskType, clearType);
+    return m_partedcore->clear(wipe);
 }
 
 bool DiskManagerService::resize(const PartitionInfo &info)
@@ -129,27 +148,6 @@ bool DiskManagerService::create(const PartitionVec &infovec)
     return m_partedcore->create(infovec);
 }
 
-void DiskManagerService::initConnection()
-{
-    connect(m_partedcore, &PartedCore::updateDeviceInfo, this, &DiskManagerService::updateDeviceInfo);
-    connect(m_partedcore, &PartedCore::deletePartitionMessage, this, &DiskManagerService::deletePartition);
-    connect(m_partedcore, &PartedCore::hidePartitionInfo, this, &DiskManagerService::hidePartitionInfo);
-    connect(m_partedcore, &PartedCore::showPartitionInfo, this, &DiskManagerService::showPartitionInfo);
-    connect(m_partedcore, &PartedCore::usbUpdated, this, &DiskManagerService::usbUpdated);
-    connect(m_partedcore, &PartedCore::checkBadBlocksCountInfo, this, &DiskManagerService::checkBadBlocksCountInfo);
-    connect(m_partedcore, &PartedCore::fixBadBlocksInfo, this, &DiskManagerService::fixBadBlocksInfo);
-    connect(m_partedcore, &PartedCore::checkBadBlocksFinished, this, &DiskManagerService::checkBadBlocksFinished);
-    connect(m_partedcore, &PartedCore::fixBadBlocksFinished, this, &DiskManagerService::fixBadBlocksFinished);
-    connect(m_partedcore, &PartedCore::unmountPartition, this, &DiskManagerService::unmountPartition);
-    connect(m_partedcore, &PartedCore::createTableMessage, this, &DiskManagerService::createTableMessage);
-    connect(m_partedcore, &PartedCore::vgCreateMessage, this, &DiskManagerService::vgCreateMessage);
-    connect(m_partedcore, &PartedCore::pvDeleteMessage, this, &DiskManagerService::pvDeleteMessage);
-    connect(m_partedcore, &PartedCore::vgDeleteMessage, this, &DiskManagerService::vgDeleteMessage);
-    connect(m_partedcore, &PartedCore::lvDeleteMessage, this, &DiskManagerService::lvDeleteMessage);
-    connect(this, &DiskManagerService::getAllDeviceInfomation, this, &DiskManagerService::onGetAllDeviceInfomation);
-    connect(m_partedcore, &PartedCore::clearMessage, this, &DiskManagerService::clearMessage);
-}
-
 HardDiskInfo DiskManagerService::onGetDeviceHardInfo(const QString &devicepath)
 {
     return m_partedcore->getDeviceHardInfo(devicepath);
