@@ -1,29 +1,6 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file diskmanagerservice.h
- *
- * @brief 磁盘分区操作封装类
- *
- * @date 2020-09-01 10:49
- *
- * Author: liweigang  <liweigang@uniontech.com>
- *
- * Maintainer: liweigang  <liweigang@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
 
 #ifndef DISKMANAGERSERVICE_H
 #define DISKMANAGERSERVICE_H
@@ -72,9 +49,17 @@ Q_SIGNALS:
     /**
      * @brief 刷新设备信息信号
      * @param infomap：所有设备分区信息
+     * @param lvmInfo：lvm信息
      */
     Q_SCRIPTABLE void updateDeviceInfo(const DeviceInfoMap &infomap, const LVMInfo &lvmInfo);
 
+
+    /**
+     * @brief 刷新加密设备信息信号
+     * @param infomap：所有加密设备分区信息
+     */
+    Q_SCRIPTABLE void updateLUKSInfo(const LUKSMap &infomap);
+
     /**
      * @brief 卸载状态信号
      * @param umountMessage:卸载信息
@@ -132,7 +117,9 @@ Q_SIGNALS:
 
     /**
      * @brief 清除信号
-     * @param clearMessage：清除信息
+     * @param clearMessage：清除信息 enum:errcode:devicePath   示例: DISK_ERROR:1:/dev/sda1
+     *                                                             LVMError:1:/dev/vg01/lv01
+     *                                                             CRYPTError:1:/dev/mapper/sda1-aesE
      */
     Q_SCRIPTABLE void clearMessage(const QString &clearMessage);
 
@@ -161,6 +148,20 @@ Q_SIGNALS:
      */
     Q_SCRIPTABLE void lvDeleteMessage(const QString &lvMessage);
 
+    /**
+     * @brief 解密消息
+     * @param luks:解密消息
+     */
+    Q_SCRIPTABLE void deCryptMessage(const LUKS_INFO &luks);
+
+    /**
+     * @brief 创建失败(lv/分区 (加密/未加密))
+     * @param message:失败信息  enum:errcode:devicePath   示例: DISK_ERROR:1:/dev/sda1
+     *                                                        LVMError:1:/dev/vg01/lv01
+     *                                                        CRYPTError:1:/dev/mapper/sda1-aesE
+     *
+     */
+    Q_SCRIPTABLE void createFailedMessage(const QString &message);
 
 public Q_SLOTS:
     /**
@@ -207,6 +208,29 @@ public Q_SLOTS:
      */
     Q_SCRIPTABLE bool mount(const QString &mountpath);
 
+
+    /**
+     * @brief 加密磁盘解密
+     * @param luks  加密磁盘属性
+     * @return true成功false失败
+     */
+    Q_SCRIPTABLE bool deCrypt(const LUKS_INFO&luks);
+
+
+    /**
+     * @brief 加密磁盘挂载
+     * @param luks  加密磁盘属性
+     * @return true成功false失败
+     */
+    Q_SCRIPTABLE bool cryptMount(const LUKS_INFO&luks);
+
+    /**
+     * @brief 加密磁盘卸载
+     * @param luks  加密磁盘属性
+     * @return true成功false失败
+     */
+    Q_SCRIPTABLE bool cryptUmount(const LUKS_INFO&luks);
+
     /**
      * @brief 获取全部文件系统格式支持
      * @return 返回支持文件系统格式列表
@@ -230,7 +254,8 @@ public Q_SLOTS:
      * @param clearType: 擦除标准， 0为快速，1为安全（NIST），2为DoD标准， 3为古德曼标准
      * @return true成功false失败
      */
-    Q_SCRIPTABLE bool clear(const QString &fstype, const QString &path, const QString &name, const QString &user, const int &diskType, const int &clearType);
+    Q_SCRIPTABLE bool clear(const WipeAction&wipe);
+
 
     /**
      * @brief 扩容分区
