@@ -1,29 +1,6 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file device.cpp
- *
- * @brief 设备信息类
- *
- * @date 2020-09-09 13:39
- *
- * Author: liweigang  <liweigang@uniontech.com>
- *
- * Maintainer: liweigang  <liweigang@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
 
 #include "device.h"
 
@@ -57,6 +34,14 @@ Device::Device()
     qDBusRegisterMetaType<QList<PVData>>();
     qDBusRegisterMetaType<QList<LVAction>>();
 
+    //注册结构体 luks dbus通信使用
+    qDBusRegisterMetaType<LUKS_INFO>();
+    qDBusRegisterMetaType<LUKS_MapperInfo>();
+    qDBusRegisterMetaType<CRYPT_CIPHER_Support>();
+    qDBusRegisterMetaType<LUKSInfoMap>();
+    qDBusRegisterMetaType<LUKSMap>();
+    qDBusRegisterMetaType<WipeAction>();
+
     m_sectorSize = 0;
     m_maxPrims = 0;
     m_highestBusy = 0;
@@ -68,8 +53,7 @@ void Device::enablePartitionNaming(int length)
 {
     if (length > 0) {
         m_maxPartitionNameLength = length;
-    }
-    else {
+    } else {
         m_maxPartitionNameLength = 0;
     }
 }
@@ -102,6 +86,7 @@ DeviceInfo Device::getDeviceInfo()
     info.m_maxPartitionNameLength = m_maxPartitionNameLength;
     info.m_interface = m_interface;
     info.m_mediaType = m_mediaType;
+
 //        qDebug() << __FUNCTION__ << info.m_path << info.length << info.heads << info.sectors
 //                 << info.cylinders << info.cylsize << info.model << info.serial_number << info.disktype
 //                 << info.sector_size << info.max_prims << info.highest_busy << info.readonly
