@@ -1,29 +1,6 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file partedcore.h
- *
- * @brief 磁盘操作类
- *
- * @date 2020-09-01 16:47
- *
- * Author: liweigang  <liweigang@uniontech.com>
- *
- * Maintainer: liweigang  <liweigang@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
 
 #ifndef PARTEDCORE_H
 #define PARTEDCORE_H
@@ -56,6 +33,8 @@ class PartedCore : public QObject
 public:
     explicit PartedCore(QObject *parent = nullptr);
     ~PartedCore();
+    //DBUS 调用
+    //信息获取操作
     /**
      * @brief 获取设备信息
      * @return 返回设备信息
@@ -68,7 +47,6 @@ public:
      */
     DeviceInfoMap getAllDeviceinfo();
 
-
     /**
      * @brief 获取LVM设备信息
      * @return 返回LVM设备信息
@@ -76,58 +54,10 @@ public:
     LVMInfo getAllLVMinfo();
 
     /**
-     * @brief 获取当前页面选择分区信息
-     * @param info：当前选择分区信息
+     * @brief 获取LUKS设备信息
+     * @return 返回LUKS设备信息
      */
-    void setCurSelect(const PartitionInfo &info);
-
-    //operationstuff...
-    /**
-     * @brief 挂载分区
-     * @param mountpath：挂载路径
-     * @return true成功false失败
-     */
-    bool mountAndWriteFstab(const QString &mountpath);
-
-
-    /**
-     * @brief 卸载分区
-     * @return true成功false失败
-     */
-    bool unmount();
-
-    /**
-     * @brief 挂载分区
-     * @param infovec：要创建的分区信息列表
-     * @return true成功false失败
-     */
-    bool create(const PartitionVec &infovec);
-
-    /**
-     * @brief 格式化分区
-     * @param fstype：格式化格式
-     * @param name：分区别名
-     * @return true成功false失败
-     */
-    bool format(const QString &fstype, const QString &name);
-
-    /**
-     * @brief 清除磁盘
-     * @param fstype：格式化格式
-     * @param path：分区别名
-     * @param name: 劵标名
-     * @param diskType : 0为磁盘，1为分区
-     * @param clearType: 清除标准， 1为快速，2为安全（NIST），3为DoD标准， 4为古德曼标准
-     * @return true成功false失败
-     */
-    bool clear(const QString &fstype, const QString &path, const QString &name, const QString &user, const int &diskType, const int &clearType);
-
-    /**
-     * @brief 扩容分区
-     * @param info：扩容分区信息
-     * @return true成功false失败
-     */
-    bool resize(const PartitionInfo &info);
+    LUKSMap getAllLUKSinfo();
 
     /**
      * @brief 获取支持格式列表
@@ -156,30 +86,7 @@ public:
      */
     HardDiskStatusInfoList getDeviceHardStatusInfo(const QString &devicepath);
 
-    /**
-     * @brief 删除分区实际操作
-     * @param devicePath：设备路径
-     * @param parttitionPath：分区路径
-     * @return true成功false失败
-     */
-    bool deletePartition();
-
-    /**
-     * @brief 隐藏分区
-     * @param devicePath：设备路径
-     * @param parttitionPath：分区路径
-     * @return true成功false失败
-     */
-    bool hidePartition();
-
-    /**
-     * @brief 显示分区
-     * @param devicePath：设备路径
-     * @param parttitionPath：分区路径
-     * @return true成功false失败
-     */
-    bool showPartition();
-
+    //分区表与分区相关
     /**
      * @brief 创建分区表
      * @param devicepath：设备信息路径
@@ -197,6 +104,107 @@ public:
      */
     bool detectionPartitionTableError(const QString &devicePath);
 
+    /**
+     * @brief 创建分区
+     * @param infovec：要创建的分区信息列表
+     * @return true成功false失败
+     */
+    bool create(const PartitionVec &infovec);
+
+    /**
+     * @brief 格式化分区
+     * @param fstype：格式化格式
+     * @param name：分区别名
+     * @return true成功false失败
+     */
+    bool format(const QString &fstype, const QString &name);
+
+    /**
+     * @brief 清除磁盘
+     * @param fstype：格式化格式
+     * @param path：分区别名
+     * @param name: 劵标名
+     * @param diskType : 0为磁盘，1为分区
+     * @param clearType: 清除标准， 1为快速，2为安全（NIST），3为DoD标准， 4为古德曼标准
+     * @return true成功false失败
+     */
+    bool clear(const WipeAction &wipe);
+
+    /**
+     * @brief 扩容分区
+     * @param info：扩容分区信息
+     * @return true成功false失败
+     */
+    bool resize(const PartitionInfo &info);
+
+    /**
+     * @brief 删除分区实际操作
+     * @param devicePath：设备路径
+     * @param parttitionPath：分区路径
+     * @return true成功false失败
+     */
+    bool deletePartition();
+
+    /**
+     * @brief 显示分区
+     * @param devicePath：设备路径
+     * @param parttitionPath：分区路径
+     * @return true成功false失败
+     */
+    bool showPartition();
+
+    /**
+     * @brief 隐藏分区
+     * @param devicePath：设备路径
+     * @param parttitionPath：分区路径
+     * @return true成功false失败
+     */
+    bool hidePartition();
+
+    /**
+     * @brief 获取当前页面选择分区信息
+     * @param info：当前选择分区信息
+     */
+    void setCurSelect(const PartitionInfo &info);
+
+
+    //挂载相关
+    /**
+     * @brief 挂载分区
+     * @param mountpath：挂载路径
+     * @return true成功false失败
+     */
+    bool mountAndWriteFstab(const QString &mountpath);
+
+    /**
+     * @brief 卸载分区
+     * @return true成功false失败
+     */
+    bool unmount();
+
+    /**
+     * @brief 加密磁盘挂载
+     * @param luks  加密磁盘属性
+     * @return true成功false失败
+     */
+    bool cryptMount(const LUKS_INFO &luks);
+
+    /**
+     * @brief 加密磁盘卸载
+     * @param luks  加密磁盘属性
+     * @return true成功false失败
+     */
+    bool cryptUmount(const LUKS_INFO &luks);
+
+    /**
+     * @brief 加密磁盘解密
+     * @param luks  加密磁盘属性
+     * @return true成功false失败
+     */
+    bool deCrypt(const LUKS_INFO &luks);
+
+
+    //外接设备刷新相关
     /**
      * @brief USB刷新(插入)
      */
@@ -207,12 +215,8 @@ public:
      */
     bool updateUsbRemove();
 
-    /**
-     * @brief 获取隐藏分区是否隐藏属性
-     * @return 0成功-1失败
-     */
-    int getPartitionHiddenFlag();
 
+    //线程相关
     /**
      * @brief 坏道检测（检测次数）
      * @param devicePath：设备信息路径
@@ -245,41 +249,12 @@ public:
     bool fixBadBlocks(const QString &devicePath, QStringList badBlocksList, int checkSize, int flag);
 
     /**
-     * @brief 刷新按钮
+     * @brief 刷新按钮 启动刷新硬件线程
      */
     void refreshFunc();
 
-    /**
-     * @brief 个人测试
-     */
-    int test();
-
-    /**
-     * @brief 确定是否是真正的设备
-     * @param lpDisk：设备信息
-     * @return true确定false不确定
-     */
-    static bool useableDevice(const PedDevice *lpDevice);
-
-    /**
-     * @brief 设置设备信息根据磁盘
-     * @param device：设备信息
-     * @param devicePath：设备路径
-     */
-    void setDeviceFromDisk(Device &device, const QString &devicePath);
-
-    /**
-     * @brief 删除临时挂载文件
-     */
-    bool delTempMountFile();
-
-    /**
-    * @brief 判断设备有否经历过gpt分区表扩容
-    * @param devicePath：设备路径
-    * @return true扩展后gpt分区表状态与实际不一致, false分区表状态正常
-    */
-    bool gptIsExpanded(const QString &devicePath);
 
+    //lvm相关
     /**
      * @brief 创建vg
      * @param vgName:待创建vg名称
@@ -289,6 +264,13 @@ public:
      */
     bool createVG(QString vgName, QList<PVData>devList, long long size);
 
+    /**
+     * @brief 删除vg
+     * @param vglist: 待删除vg列表
+     * @return true 成功 false 失败
+     */
+    bool deleteVG(QStringList vglist);
+
     /**
      * @brief 创建lv
      * @param vgName:vg名称
@@ -297,13 +279,6 @@ public:
      */
     bool createLV(QString vgName, QList<LVAction>lvList);
 
-    /**
-     * @brief 删除vg
-     * @param vglist: 待删除vg列表
-     * @return true 成功 false 失败
-     */
-    bool deleteVG(QStringList vglist);
-
     /**
      * @brief 删除lv
      * @param lvlist: 待删除lv列表
@@ -348,7 +323,6 @@ public:
      */
     bool clearLV(const LVAction &lvAction);
 
-
     /**
      * @brief pv删除
      * @param devList: 待删除pv设备集合
@@ -356,7 +330,67 @@ public:
      */
     bool deletePVList(QList<PVData>devList);
 
+    //其他
+    /**
+     * @brief 个人测试
+     */
+    int test();
+public:
+    //外部调用 非DBUS
+    /**
+     * @brief 设置设备信息根据磁盘
+     * @param device：设备信息
+     * @param devicePath：设备路径
+     */
+    void setDeviceFromDisk(Device &device, const QString &devicePath);
+
+    /**
+     * @brief 确定是否是真正的设备
+     * @param lpDisk：设备信息
+     * @return true确定false不确定
+     */
+    static bool useableDevice(const PedDevice *lpDevice);
+
+    /**
+     * @brief 删除临时挂载文件
+     */
+    bool delTempMountFile();
+
 private:
+    //general..
+    /**
+     * @brief 初始化信号槽链接
+     */
+    void initConnection();
+
+    /**
+     * @brief 获取hdparm和udevadm的是否支持状态
+     */
+    static void findSupportedCore();
+
+    /**
+     * @brief 设置设备序列号
+     * @param device：设备信息
+     */
+    void setDeviceSerialNumber(Device &device);
+
+    /**
+     * @brief 获取隐藏分区是否隐藏属性
+     * @return 0成功-1失败
+     */
+    int getPartitionHiddenFlag();
+
+    /**
+    * @brief 判断设备有否经历过gpt分区表扩容
+    * @param devicePath：设备路径
+    * @return true扩展后gpt分区表状态与实际不一致, false分区表状态正常
+    */
+    bool gptIsExpanded(const QString &devicePath);
+
+    /**
+     * @brief USB设备插入，自动挂载
+     */
+    void autoMount();
 
     /**
      * @brief USB设备拔出，自动卸载
@@ -364,68 +398,31 @@ private:
     void autoUmount();
 
     /**
-     * @brief USB设备插入，自动挂载
+     * @brief 获取设备详细信息
+     * @param path：默认空
      */
-    void autoMount();
-
-    //static
-    /**
-     * @brief 获取hdparm和udevadm的是否支持状态
-     */
-    static void findSupportedCore();
+    void probeDeviceInfo(const QString &path = QString());
 
     /**
-     * @brief 获取是否支持文件系统格式
-     * @param fstype：文件系统格式
-     * @return true支持false不支持
+     * @brief 刷新信息槽函数
      */
-    static bool supportedFileSystem(FSType fstype);
+    void onRefreshDeviceInfo(int type = 0, bool arg1 = true, QString arg2 = "");
 
     /**
-     * @brief 获取支持文件系统格式
-     * @param fstype：文件系统格式
-     * @return 支持的文件系统格式
-     */
-    const FS &getFileSystem(FSType fstype) const;
+      * @brief 刷新硬件信息
+      */
+    void syncDeviceInfo(const DeviceInfoMap inforesult, const LVMInfo lvmInfo, const LUKSMap &luks);
 
     /**
-     * @brief 获取文件系统对象
-     * @param fstype：文件系统格式
-     * @return 文件系统对象
+     * @brief 发送刷新信号并且返回bool值
+     * @param flag：设置的返回值
+     * @return true false 与flag相同
      */
-    static FileSystem *getFileSystemObject(FSType fstype);
-//    static bool filesystem_resize_disallowed(const Partition &partition);
-
-    /**
-     * @brief 设置空闲空间
-     * @param devicePath：设备路径
-     * @param partitions：分区信息列表
-     * @param start：扇区开始
-     * @param end：扇区结束
-     * @param sectorSize：扇区大小
-     * @param insideExtended：扩展分区标志
-     */
-    static void insertUnallocated(const QString &devicePath,
-                                  QVector<Partition *> &partitions,
-                                  Sector start,
-                                  Sector end,
-                                  Byte_Value sectorSize,
-                                  bool insideExtended);
-
-    /**
-     * @brief 设置分区标志
-     * @param partition：分区信息
-     * @param lpPartition：（库）分区详细信息
-     */
-    void setFlags(Partition &partition, PedPartition *lpPartition);
-
-    /**
-     * @brief 最小和最大文件系统大小限制
-     * @param fstype：文件系统格式
-     * @param partition：分区信息
-     * @return 最小和最大文件系统大小限制结构体
-     */
-    static FS_Limits getFileSystemLimits(FSType fstype, const Partition &partition);
+    inline bool sendRefSigAndReturn(bool flag, int type = 0, bool arg1 = true, QString arg2 = "")
+    {
+        emit refreshDeviceInfo(type, arg1, arg2);
+        return flag;
+    }
 
     /**
      * @brief 安全擦除算法
@@ -440,99 +437,7 @@ private:
     bool secuClear(const QString &path, const Sector &start, const Sector &end, const Byte_Value &size, const QString &fstype, const QString &name = " ", const int &count = 1);
 
 
-    /**
-     * @brief 挂载设备
-     * @param mountpath:挂载点
-     * @param devPath:设备路径
-     * @param fsType:文件系统类型
-     * @return true 挂载成功 false 挂载失败
-     */
-    bool mountDevice(const QString &mountpath, const QString devPath, const FSType &fsType);
-
-
-    /**
-     * @brief 卸载设备
-     * @param mountPoints:挂载点集合
-     * @return true 卸载成功 false 卸载失败
-     */
-    bool umontDevice(QVector<QString>mountPoints,QString devPath = "");
-
-    /**
-     * @brief 写fstab文件
-     * @param uuid:设备（磁盘分区，lvm lv）uuid
-     * @param mountpath:挂载点
-     * @param type:文件系统类型
-     * @param isMount:true 挂载 false 卸载
-     * @return true 写入成功 false 写入失败
-     */
-    bool writeFstab(const QString &uuid, const QString &mountpath, const QString &type, bool isMount = true);
-
-    /**
-     * @brief 创建临时挂载目录
-     * @param mountpath:挂载目录
-     * @return true 创建成功 false 创建失败
-     */
-    bool createTmpMountDir(const QString &mountPath);
-
-    /**
-     * @brief 修改文件属主
-     * @param user:用户名
-     * @param path:文件路径
-     * @return true 修改成功 false 修改失败
-     */
-    bool changeOwner(const QString &user, const QString &path);
-
-
-    /**
-     * @brief 创建pv使用的分区
-     * @param pv:pv数据结构体 创建分区依据
-     * @return true 分区创建成功 false 失败
-     */
-    bool createPVPart(PVData &pv);
-
-private:
-    //general..
-    /**
-     * @brief 初始化信号槽链接
-     */
-    void initConnection();
-
-    /**
-     * @brief 创建分区表
-     * @param devicePath:设备路径
-     * @param diskLabel:分区表格式
-     * @return true成功false失败
-     */
-    bool newDiskLabel(const QString &devicePath, const QString &diskLabel);
-
-    /**
-     * @brief 刷新设备设置
-     * @param lpDevice：设备信息
-     * @return true成功false失败
-     */
-    static bool flushDevice(PedDevice *lpDevice);
-
-//    /**
-//     * @brief 刷新udev事件队列
-//     * @param timeout：超时时间
-//     */
-//    static void settleDevice(std::time_t timeout);
-
-    /**
-     * @brief 等待udev时间处理，启动分区内核更新
-     * @param lpDisk：设备信息
-     * @param timeout：超时时间
-     * @return true成功false失败
-     */
-    static bool commitToOs(PedDisk *lpDisk);
-
-    /**
-     * @brief 确定是否是真正的设备
-     * @param lpDisk：设备信息
-     * @return true确定false不确定
-     */
-    //static bool useableDevice(const PedDevice *lpDevice);
-
+    //gparted 分区表 分区 文件系统
     /**
      * @brief 获取设备
      * @param devicePath：设备路径
@@ -551,21 +456,6 @@ private:
      */
     static bool getDisk(PedDevice *&lpDevice, PedDisk *&lpDisk, bool strict = true);
 
-    /**
-     * @brief 销毁磁盘信息和设备信息
-     * @param lpDevice：设备信息
-     * @param lpDisk：磁盘信息
-     */
-    static void destroyDeviceAndDisk(PedDevice *&lpDevice, PedDisk *&lpDisk);
-
-    /**
-     * @brief 同步页面选择分区信息
-     * @param partition：分区信息
-     * @param info：分区详细信息
-     * @return true成功false失败
-     */
-    bool infoBelongToPartition(const Partition &partition, const PartitionInfo &info);
-
     /**
      * @brief 获取磁盘和设备信息
      * @param devicePath：设备路径
@@ -578,6 +468,36 @@ private:
     static bool getDeviceAndDisk(const QString &devicePath, PedDevice *&lpDevice,
                                  PedDisk *&lpDisk, bool strict = true, bool flush = false);
 
+    /**
+     * @brief 销毁磁盘信息和设备信息
+     * @param lpDevice：设备信息
+     * @param lpDisk：磁盘信息
+     */
+    static void destroyDeviceAndDisk(PedDevice *&lpDevice, PedDisk *&lpDisk);
+
+
+    /**
+     * @brief 分区是否挂载状态
+     * @param fstype：文件系统格式
+     * @param path：挂载路径
+     * @param lp_partition：分区详细信息
+     * @return true挂载false没挂载
+     */
+    bool isBusy(FSType fstype, const QString &path, const PedPartition *lpPartition = nullptr);
+
+    /**
+     * @brief 刷新设备设置
+     * @param lpDevice：设备信息
+     * @return true成功false失败
+     */
+    static bool flushDevice(PedDevice *lpDevice);
+
+//    /**
+//     * @brief 刷新udev事件队列
+//     * @param timeout：超时时间
+//     */
+//    static void settleDevice(std::time_t timeout);
+
     /**
      * @brief 更新到磁盘信息
      * @param lpDisk：磁盘信息
@@ -585,6 +505,29 @@ private:
      */
     static bool commit(PedDisk *lpDisk);
 
+    /**
+     * @brief 等待udev时间处理，启动分区内核更新
+     * @param lpDisk：设备信息
+     * @param timeout：超时时间
+     * @return true成功false失败
+     */
+    static bool commitToOs(PedDisk *lpDisk);
+
+    /**
+     * @brief 确定是否是真正的设备
+     * @param lpDisk：设备信息
+     * @return true确定false不确定
+     */
+    //static bool useableDevice(const PedDevice *lpDevice);
+
+    /**
+     * @brief 同步页面选择分区信息
+     * @param partition：分区信息
+     * @param info：分区详细信息
+     * @return true成功false失败
+     */
+    bool infoBelongToPartition(const Partition &partition, const PartitionInfo &info);
+
     /**
      * @brief 获取分区详细信息
      * @param lp_disk：磁盘信息
@@ -593,12 +536,6 @@ private:
     static PedPartition *getLpPartition(const PedDisk *lpDisk, const Partition &partition);
     //detectionstuff..
 
-    /**
-     * @brief 获取分区详细信息
-     * @param path：默认空
-     */
-    void probeDeviceInfo(const QString &path = QString());
-
     /**
      * @brief 设置设备信息根据磁盘
      * @param device：设备信息
@@ -606,12 +543,6 @@ private:
      */
     //void setDeviceFromDisk(Device &device, const QString &devicePath);
 
-    /**
-     * @brief 设置设备序列号
-     * @param device：设备信息
-     */
-    void setDeviceSerialNumber(Device &device);
-
     /**
      * @brief 设置设备分区信息
      * @param device：设备信息
@@ -626,27 +557,6 @@ private:
      */
     void setPartitionLabelAndUuid(Partition &partition);
 
-    /**
-     * @brief 分区是否挂载状态
-     * @param fstype：文件系统格式
-     * @param path：挂载路径
-     * @param lp_partition：分区详细信息
-     * @return true挂载false没挂载
-     */
-    bool isBusy(FSType fstype, const QString &path, const PedPartition *lpPartition = nullptr);
-
-    /**
-     * @brief 读取分区表
-     * @param partition：分区信息
-     */
-    void readLabel(Partition &partition);
-
-    /**
-     * @brief 读取UUid
-     * @param partition：分区信息
-     */
-    void readUuid(Partition &partition);
-
     /**
      * @brief 设置分区挂载点信息
      * @param partition：分区信息
@@ -661,6 +571,7 @@ private:
      */
     bool setMountPointsHelper(Partition &partition, const QString &path);
 
+
     /**
      * @brief 设置分区已用空间
      * @param partition：分区信息
@@ -734,13 +645,6 @@ private:
      */
     bool setPartitionType(const Partition &partition);
 
-    /**
-     * @brief 创建分区文件系统
-     * @param partition：分区信息
-     * @return true成功false失败
-     */
-    bool createFileSystem(const Partition &partition);
-
     /**
      * @brief 格式化分区
      * @param partition：分区信息
@@ -755,13 +659,6 @@ private:
      */
     bool resize(const Partition &partitionNew);
 
-    /**
-     * @brief 检查修复文件系统
-     * @param partition：分区信息
-     * @return true成功false失败
-     */
-    bool checkRepairFileSystem(const Partition &partition);
-
     /**
      * @brief 调整移动分区大小
      * @param partitionOld：旧分区信息
@@ -771,7 +668,6 @@ private:
      */
     bool resizeMovePartition(const Partition &partitionOld, const Partition &partitionNew, bool rollbackOnFail);
 
-
     /**
      * @brief 调整移动分区实现大小
      * @param partitionOld：旧分区信息
@@ -805,6 +701,22 @@ private:
      */
     bool resizeMoveFileSystemUsingLibparted(const Partition &partitionOld, const Partition &partitionNew);
 
+    //分区表
+    /**
+     * @brief 创建分区表
+     * @param devicePath:设备路径
+     * @param diskLabel:分区表格式
+     * @return true成功false失败
+     */
+    bool newDiskLabel(const QString &devicePath, const QString &diskLabel);
+
+    /**
+     * @brief 重写分区表
+     * @param devicePath：设备名称
+     */
+    void reWritePartition(const QString &devicePath);
+
+    //分区
     /**
      * @brief 创建分区
      * @param partition：分区信息
@@ -815,27 +727,176 @@ private:
     /**
      * @brief 创建分区
      * @param partition：分区信息
-     * @return true成功false失败
+     * @return true成功false失败  QString partName
      */
     bool createPartition(Partition &newPartition, Sector minSize = 0);
 
     /**
-     * @brief 重写分区表
-     * @param devicePath：设备名称
+     * @brief 设置空闲空间
+     * @param devicePath：设备路径
+     * @param partitions：分区信息列表
+     * @param start：扇区开始
+     * @param end：扇区结束
+     * @param sectorSize：扇区大小
+     * @param insideExtended：扩展分区标志
      */
-    void reWritePartition(const QString &devicePath);
+    static void insertUnallocated(const QString &devicePath,
+                                  QVector<Partition *> &partitions,
+                                  Sector start,
+                                  Sector end,
+                                  Byte_Value sectorSize,
+                                  bool insideExtended);
 
     /**
-     * @brief 发送刷新信号并且返回bool值
-     * @param flag：设置的返回值
-     * @return true false 与flag相同
+     * @brief 设置分区标志
+     * @param partition：分区信息
+     * @param lpPartition：（库）分区详细信息
      */
-    inline bool sendRefSigAndReturn(bool flag, int type = 0, bool arg1 = true, QString arg2 = "")
-    {
-        emit refreshDeviceInfo(type, arg1, arg2);
-        return flag;
-    }
+    void setFlags(Partition &partition, PedPartition *lpPartition);
 
+    /**
+     * @brief 读取分区标签
+     * @param partition：分区信息
+     */
+    void readLabel(Partition &partition);
+
+    /**
+     * @brief 读取UUid
+     * @param partition：分区信息
+     */
+    void readUuid(Partition &partition);
+
+
+
+    //文件系统
+
+    /**
+     * @brief 获取是否支持文件系统格式
+     * @param fstype：文件系统格式
+     * @return true支持false不支持
+     */
+    static SupportedFileSystems* supportedFSInstance();
+
+    /**
+     * @brief 获取是否支持文件系统格式
+     * @param fstype：文件系统格式
+     * @return true支持false不支持
+     */
+    static bool supportedFileSystem(FSType fstype);
+
+    /**
+     * @brief 获取支持文件系统格式
+     * @param fstype：文件系统格式
+     * @return 支持的文件系统格式
+     */
+    const FS &getFileSystem(FSType fstype) const;
+
+    /**
+     * @brief 获取文件系统对象
+     * @param fstype：文件系统格式
+     * @return 文件系统对象
+     */
+    static FileSystem *getFileSystemObject(FSType fstype);
+//    static bool filesystem_resize_disallowed(const Partition &partition);
+
+    /**
+     * @brief 最小和最大文件系统大小限制
+     * @param fstype：文件系统格式
+     * @param partition：分区信息
+     * @return 最小和最大文件系统大小限制结构体
+     */
+    static FS_Limits getFileSystemLimits(FSType fstype, const Partition &partition);
+
+    /**
+     * @brief 创建分区文件系统
+     * @param partition：分区信息
+     * @return true成功false失败
+     */
+    bool createFileSystem(const Partition &partition);
+
+    /**
+     * @brief 创建分区文件系统
+     * @param type:文件系统
+     * @param busy:是否使用
+     * @param path:设备路径
+     * @param lable:卷标
+     * @param partition:分区
+     * @return true成功false失败
+     */
+    bool createFileSystem(const FSType &type, const bool &busy, const QString &path, const QString lable = "", const Partition &partition = Partition());
+
+    /**
+     * @brief 检查修复文件系统
+     * @param partition：分区信息
+     * @return true成功false失败
+     */
+    bool checkRepairFileSystem(const Partition &partition);
+
+
+    //挂载
+    /**
+     * @brief 挂载设备
+     * @param mountpath:挂载点
+     * @param devPath:设备路径
+     * @param fsType:文件系统类型
+     * @return true 挂载成功 false 挂载失败
+     */
+    bool mountDevice(const QString &mountpath, const QString devPath, const FSType &fsType);
+
+    /**
+     * @brief 卸载设备
+     * @param mountPoints:挂载点集合
+     * @return true 卸载成功 false 卸载失败
+     */
+    bool umontDevice(QVector<QString>mountPoints, QString devPath = "");
+
+
+    /**
+     * @brief 写fstab文件
+     * @param uuid:设备（磁盘分区，lvm lv）uuid
+     * @param mountpath:挂载点
+     * @param type:文件系统类型
+     * @param isMount:true 挂载 false 卸载
+     * @return true 写入成功 false 写入失败
+     */
+    bool writeFstab(const QString &uuid, const QString &mountpath, const QString &type, bool isMount = true);
+
+    /**
+     * @brief 挂载设备
+     * @param mountpath:挂载点
+     * @param devPath:设备路径
+     * @param fsType:文件系统类型
+     * @return true 挂载成功 false 挂载失败
+     */
+    QPair<bool, QString> tmpMountDevice(const QString &mountpath, const QString devPath, const FSType &fsType, const QString &userName);
+
+    /**
+     * @brief 获取可用的临时挂载路径
+     * @param user:用户名
+     * @param lable: 卷标
+     * @param uuid: 设备uuid
+     * @param devPath: 设备路径
+     * @return 临时挂载路径
+     */
+    QString getTmpMountPath(const QString &user, const QString &lable, const QString &uuid, const QString &devPath);
+
+    /**
+     * @brief 创建临时挂载目录
+     * @param mountpath:挂载目录
+     * @return true 创建成功 false 创建失败
+     */
+    bool createTmpMountDir(const QString &mountPath);
+
+    /**
+     * @brief 修改文件属主
+     * @param user:用户名
+     * @param path:文件路径
+     * @return true 修改成功 false 修改失败
+     */
+    bool changeOwner(const QString &user, const QString &path);
+
+
+    //lvm
     /**
      * @brief 获取创建VG的pvdata 列表
      * @param devList: 设备列表
@@ -884,6 +945,13 @@ private:
      */
     bool createPVPartition(PVData &pv);
 
+    /**
+     * @brief 创建pv使用的分区
+     * @param pv:pv数据结构体 创建分区依据
+     * @return true 分区创建成功 false 失败
+     */
+    bool createPVPart(PVData &pv);
+
     /**
      * @brief 检查pv设备
      * @param vgName: vg名称
@@ -904,21 +972,105 @@ private:
      */
     void resizeVGMessage(bool flag);
 
+
+    //luks
+    /**
+     * @brief 创建加密结构体数据
+     * @param part:分区数据
+     * @return 加密结构体
+     */
+    LUKS_INFO getNewLUKSInfo(const Partition &part);
+
+    /**
+     * @brief 创建加密结构体数据
+     * @param lvAct:lv操作结构体
+     * @return 加密结构体
+     */
+    LUKS_INFO getNewLUKSInfo(const LVAction &lvAct);
+
+    /**
+     * @brief 创建加密结构体数据
+     * @param type：文件系统类型
+     * @param token：密钥提示信息
+     * @param cipher：加密算法
+     * @param decryptStr：加密密码
+     * @param dmName：映射名称
+     * @param devPath：设备路径
+     * @param label：卷标
+     * @return 加密结构体
+     */
+    LUKS_INFO getNewLUKSInfo(const FSType &type, const QStringList &token, const CRYPT_CIPHER &cipher, const QString &decryptStr, const QString &dmName, const QString devPath, const QString &label);
+
+    /**
+     * @brief 关闭加密映射
+     * @param disk:磁盘结构体数据
+     * @param isCLose:是否执行关闭操作
+     * @return true 关闭成功 false 失败
+     */
+    bool closeLUKSMap(const Device& disk,bool &isCLose);
+
+    /**
+     * @brief 关闭加密映射
+     * @param wipe:擦除结构体
+     * @param isCLose:是否执行关闭操作
+     * @return true 关闭成功 false 失败
+     */
+    bool closeLUKSMap(const WipeAction&wipe,bool &isCLose);
+
+    /**
+     * @brief 关闭加密映射
+     * @param pvlist:pvdata 数据集合
+     * @param isCLose:是否执行关闭操作
+     * @return true 关闭成功 false 失败
+     */
+    bool closeLUKSMap(const QList<PVData>& pvlist,bool &isCLose);
+
+    /**
+     * @brief 关闭加密映射
+     * @param vglist:vg名称
+     * @param isCLose:是否执行关闭操作
+     * @return true 关闭成功 false 失败
+     */
+    bool closeLUKSMap(const QStringList& vglist,bool &isCLose,bool);
+
+    /**
+     * @brief 关闭加密映射
+     * @param lvlist:lv路径
+     * @param isCLose:是否执行关闭操作
+     * @return true 关闭成功 false 失败
+     */
+    bool closeLUKSMap(const QStringList& lvlist,bool &isCLose);
+
+    /**
+     * @brief 关闭加密映射
+     * @param devPath:设备路径
+     * @param isCLose:是否执行关闭操作
+     * @return true 关闭成功 false 失败
+     */
+    bool closeLUKSMap(const QString&devPath,bool &isCLose);
+
+    /**
+    * @brief 增加挂载过滤项
+    * @param devPath:设备路径
+    * @param
+    * @return
+    */
+    void addMountPointExclude(const QString &devPath);
+
+    /**
+    * @brief 删除挂载过滤项
+    * @param devPath:设备路径
+    * @param
+    * @return
+    */
+    void deleteMountPointExclude(const QString &devPath);
 signals:
+    //硬件刷新相关信号
+    /**
+     * @brief 刷新硬件信息 启动刷新硬件线程
+     */
     void probeAllInfo();
 
-    /**
-     * @brief 创建分区表信号
-     * @param flag:true成功false失败
-     */
-    void createTableMessage(const bool &flag);
-
-    /**
-     * @brief 更新信息信号
-     * @param infomap：硬盘信息
-     */
-    void updateDeviceInfo(const DeviceInfoMap &infomap, const LVMInfo &lvmInfo);
-
     /**
      * @brief 刷新信息信号
      * @param type:信号类型 详细类型见sigtype.h
@@ -928,33 +1080,27 @@ signals:
     void refreshDeviceInfo(int type = 0, bool arg1 = true, QString arg2 = "");
 
     /**
-     * @brief 卸载状态信号
-     * @param umountMessage:卸载信息
+     * @brief 更新信息信号
+     * @param infomap：硬盘信息
      */
-    void unmountPartition(const QString &unmountMessage);
+    void updateDeviceInfo(const DeviceInfoMap &infomap, const LVMInfo &lvmInfo);
 
     /**
-     * @brief 删除分区信号
-     * @param deleteMessage：删除结果
+     * @brief 刷新加密设备信息信号
+     * @param infomap：所有加密设备分区信息
      */
-    void deletePartitionMessage(const QString &deleteMessage);
+    void updateLUKSInfo(const LUKSMap &luks);
+
+    //坏道检测相关信号
+    /**
+     * @brief 坏道检查线程启动信号(次数)
+     */
+    void checkBadBlocksRunCountStart();
 
     /**
-     * @brief 隐藏分区信号
-     * @param hideMessage：隐藏结果
+     * @brief 坏道检查线程启动信号(时间)
      */
-    void hidePartitionInfo(const QString &hideMessage);
-
-    /**
-     * @brief 显示分区信号
-     * @param hideMessage：显示结果
-     */
-    void showPartitionInfo(const QString &showMessage);
-
-    /**
-     * @brief USB信号
-     */
-    void usbUpdated();
+    void checkBadBlocksRunTimeStart();
 
     /**
      * @brief 坏道检测检测信息信号(次数检测)
@@ -970,6 +1116,12 @@ signals:
      */
     void checkBadBlocksFinished();
 
+    //坏道修复相关信号
+    /**
+     * @brief 坏道修复线程启动信号
+     */
+    void fixBadBlocksStart();
+
     /**
      * @brief 坏道修复完成信号
      */
@@ -982,21 +1134,7 @@ signals:
      */
     void fixBadBlocksInfo(const QString &cylinderNumber, const QString &cylinderStatus, const QString &cylinderTimeConsuming);
 
-    /**
-     * @brief 坏道检查线程启动信号(次数)
-     */
-    void checkBadBlocksRunCountStart();
-
-    /**
-     * @brief 坏道检查线程启动信号(时间)
-     */
-    void checkBadBlocksRunTimeStart();
-
-    /**
-     * @brief 坏道修复线程启动信号
-     */
-    void fixBadBlocksStart();
-
+    //lvm线程相关信号
     /**
      * @brief 删除pv列表
      * @param lvmInfo:lvm属性类
@@ -1013,31 +1151,24 @@ signals:
      */
     void resizeVGStart(LVMInfo lvmInfo, QString vgName, QList<PVData>devList, long long size);
 
-    /**
-     * @brief 清除信号
-     * @param clearMessage：清除结果
-     */
-    void clearMessage(const QString &clearMessage);
-
+    //lvm相关信号
     /**
      * @brief vg创建
      * @param vgMessage:创建结果
      */
     void vgCreateMessage(const QString &vgMessage);
 
-    /**
-     * @brief pv删除
-     * @param pvMessage:删除结果
-     */
-    void pvDeleteMessage(const QString &pvMessage);
-
-
     /**
      * @brief vg删除
      * @param vgMessage:删除结果
      */
     void vgDeleteMessage(const QString &vgMessage);
 
+    /**
+     * @brief pv删除
+     * @param pvMessage:删除结果
+     */
+    void pvDeleteMessage(const QString &pvMessage);
 
     /**
      * @brief lg删除
@@ -1045,18 +1176,64 @@ signals:
      */
     void lvDeleteMessage(const QString &lvMessage);
 
-public slots:
-
+    //luks信号
     /**
-     * @brief 刷新信息槽函数
+     * @brief 解密消息
+     * @param luks:解密结果
      */
-    void onRefreshDeviceInfo(int type = 0, bool arg1 = true, QString arg2 = "");
+    void deCryptMessage(const LUKS_INFO &luks);
+
+
+    //其他通用信号
+    /**
+     * @brief 创建分区表信号
+     * @param flag:true成功false失败
+     */
+    void createTableMessage(const bool &flag);
 
     /**
-      * @brief 刷新硬件信息
-      */
-    void syncDeviceInfo(/*const QMap<QString, Device> deviceMap, */const DeviceInfoMap inforesult, const LVMInfo lvmInfo);
+     * @brief 创建失败(lv/分区 (加密/未加密))
+     * @param message:失败信息  enum:errcode:devicePath   示例: DISK_ERROR:1:/dev/sda1
+     *                                                        LVMError:1:/dev/vg01/lv01
+     *                                                        CRYPTError:1:/dev/mapper/sda1-aesE
+     *
+     */
+    void createFailedMessage(const QString &message);
 
+    /**
+     * @brief 擦除设备信号
+     * @param clearMessage：清除结果
+     */
+    void clearMessage(const QString &clearMessage);
+
+    /**
+     * @brief 删除分区信号
+     * @param deleteMessage：删除结果
+     */
+    void deletePartitionMessage(const QString &deleteMessage);
+
+    /**
+     * @brief 显示分区信号
+     * @param hideMessage：显示结果
+     */
+    void showPartitionInfo(const QString &showMessage);
+
+    /**
+     * @brief 隐藏分区信号
+     * @param hideMessage：隐藏结果
+     */
+    void hidePartitionInfo(const QString &hideMessage);
+
+    /**
+     * @brief USB信号
+     */
+    void usbUpdated();
+
+    /**
+     * @brief 卸载状态信号
+     * @param umountMessage:卸载信息
+     */
+    void unmountPartition(const QString &unmountMessage);
 private:
     QVector<PedPartitionFlag> m_flags;    //分区标志hidden boot efi等
     QMap<QString, Device> m_deviceMap;    //设备对应信息表
@@ -1068,14 +1245,23 @@ private:
     QThread *m_workerFixThread;           //坏道修复线程对象
     QThread *m_workerThreadProbe;         //硬件刷新专用
     QThread *m_workerLVMThread;           //lvm专用线程对象
-    WorkThread m_checkThread;
-    FixThread m_fixthread;
-    ProbeThread m_probeThread;
-    LVMThread m_lvmThread;                //lvm线程工作类
+    WorkThread m_checkThread;             //坏道检查线程对象
+    FixThread m_fixthread;                //坏道修复线程对象
+    ProbeThread m_probeThread;            //硬件刷新专用
+    LVMThread m_lvmThread;                //lvm线程工作对象
     bool m_isClear;
 
     LVMInfo m_lvmInfo;                    //lvm 数据集合
+    LUKSMap m_LUKSInfo;                   //luks 数据集合
 
+    int m_type{0};                        //刷新结束后需要发送的信号类型
+    bool m_arg1{false};                   //需要发送的信号bool类型参数
+    QString m_arg2;                       //需要发送的信号QString类型参数
+
+    int m_usbSig{0};                      //刷新结束后需要发送的信号类型
+    bool m_usbArg1{false};                //需要发送的信号bool类型参数
+    QString m_usbArg2;                    //需要发送的信号QString类型参数
+    QStringList m_mountPointExclude;      //被操作卸载的分区列表
 };
 
 } // namespace DiskManager
