@@ -1,29 +1,6 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file partition.cpp
- *
- * @brief 分区信息类
- *
- * @date 2020-09-04 17:06
- *
- * Author: liweigang  <liweigang@uniontech.com>
- *
- * Maintainer: liweigang  <liweigang@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
 
 #include "partition.h"
 #include "utils.h"
@@ -79,6 +56,11 @@ void Partition::reset()
     m_flags.clear();
     m_mountpoints.clear();
     m_fsLimits = FS_Limits();
+    m_luksFlag = LUKSFlag::NOT_CRYPT_LUKS;
+    m_cryptCipher = CRYPT_CIPHER::NOT_CRYPT;
+    m_tokenList.clear();
+    m_decryptStr = "";
+    m_dmName = "";
 }
 
 void Partition::reset(const PartitionInfo &info)
@@ -99,6 +81,13 @@ void Partition::reset(const PartitionInfo &info)
     m_devicePath = info.m_devicePath;
     setFilesystemLabel(info.m_fileSystemLabel);
     m_fsLimits = info.m_fsLimits;
+
+    m_luksFlag = info.m_luksFlag;
+    m_cryptCipher = info.m_crypt;
+    m_tokenList = info.m_tokenList;
+    m_decryptStr = info.m_decryptStr;
+    m_dmName = info.m_dmName;
+
 }
 
 void Partition::set(const QString &devicePath, const QString &partition, int partitionNumber, PartitionType type, FSType fstype, Sector sectorStart, Sector sectorEnd, Byte_Value sectorSize, bool insideExtended, bool busy)
