@@ -1,29 +1,6 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file partition.h
- *
- * @brief 分区消息类
- *
- * @date 2020-09-04 13:19
- *
- * Author: liweigang  <liweigang@uniontech.com>
- *
- * Maintainer: liweigang  <liweigang@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
 
 #ifndef PARTITION_H
 #define PARTITION_H
@@ -221,6 +198,12 @@ public:
     Byte_Value m_fsBlockSize; // Block size of of the file system, or -1 when unknown.
 
     FS_Limits m_fsLimits; //分区上文件系统限制 该属性在没有文件系统存在时无效
+
+    LUKSFlag m_luksFlag{LUKSFlag::NOT_CRYPT_LUKS};          //创建分区时 该属性为确认是否创建加密  其余情况为确认该分区是否为加密分区
+    CRYPT_CIPHER m_cryptCipher{CRYPT_CIPHER::NOT_CRYPT};          //加密算法(创建分区时该属性有效)
+    QStringList m_tokenList;                                //密钥提示   luks####提示信息####(创建分区时该属性有效)
+    QString m_decryptStr;                                   //用户解密密码字符串(创建分区时该属性有效)
+    QString m_dmName;
 private:
     /**
      * @brief 计算重要未分配扇区
