@@ -1,29 +1,7 @@
-/**
- * @copyright 2020-2020 Uniontech Technology Co., Ltd.
- *
- * @file thread.cpp
- *
- * @brief 坏道检测修复线程类
- *
- * @date 2021-01-04 13:58
- *
- * Author: liweigang  <liweigang@uniontech.com>
- *
- * Maintainer: liweigang  <liweigang@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
 #include "thread.h"
 #include "commondef.h"
 #include "blockspecial.h"
@@ -31,6 +9,7 @@
 #include "fsinfo.h"
 #include "mountinfo.h"
 #include "partedcore.h"
+#include "luksoperator/luksoperator.h"
 
 #include <QDebug>
 #include <QProcess>
@@ -227,67 +206,11 @@ void FixThread::setFixBadBlocksInfo(const QString &devicePath, QStringList list,
 ProbeThread::ProbeThread(QObject *parent)
 {
     Q_UNUSED(parent);
-    m_type = 0;
-}
-
-void ProbeThread::setSignal(int type, bool arg1, QString arg2)
-{
-    m_type = type;
-    m_arg1 = arg1;
-    m_arg2 = arg2;
-}
-
-void ProbeThread::sendsignals()
-{
-    qDebug() << __FILE__ << ":" << __FUNCTION__ << " m_type:" << m_type;
-    switch (m_type) {
-    case DISK_SIGNAL_TYPE_UMNT:
-        emit unmountPartition(m_arg2);
-        break;
-    case DISK_SIGNAL_TYPE_DEL:
-        emit deletePartitionMessage(m_arg2);
-        break;
-    case DISK_SIGNAL_TYPE_SHOW:
-        emit showPartitionInfo(m_arg2);
-        break;
-    case DISK_SIGNAL_TYPE_CREATE_TABLE:
-        emit createTableMessage(m_arg1);
-        break;
-    case DISK_SIGNAL_USBUPDATE:
-        emit usbUpdated();
-        break;
-    case DISK_SIGNAL_TYPE_CLEAR:
-        emit clearPartitionMessage(m_arg2);
-        break;
-    case DISK_SIGNAL_TYPE_VGCREATE:
-        emit vgCreateMessage(m_arg2);
-        break;
-    case DISK_SIGNAL_TYPE_PVDELETE:
-        emit pvDeleteMessage(m_arg2);
-        break;
-    case DISK_SIGNAL_TYPE_VGDELETE:
-        emit vgDeleteMessage(m_arg2);
-        break;
-    case DISK_SIGNAL_TYPE_LVDELETE:
-        emit lvDeleteMessage(m_arg2);
-        break;
-    default:
-        break;
-    }
-    m_type = 0;
 }
 
 void ProbeThread::probeDeviceInfo()
 {
     qDebug() << __FILE__ << ":" << __FUNCTION__ << "Someone call me in thread!";
-
-    if (DISK_SIGNAL_TYPE_AUTOMNT == m_type) {
-        //Only usb add need to sleep 5 seconds
-        qDebug() << __FUNCTION__ << "From auto Mount, So i will sleep 5 seconds! type:" << m_type;
-        //相传有一块移动硬盘，需要先 sleep 一下才能正确读取。
-        sleep(5);
-    }
-
     QString rootFsName;
     m_inforesult.clear();
     m_deviceMap.clear();
@@ -369,9 +292,10 @@ void ProbeThread::probeDeviceInfo()
 
     //todo 2022.1.26 获取m_lvminfo
     LVMOperator::getDeviceDataAndLVMInfo(m_inforesult, m_lvmInfo);
-    emit updateDeviceInfo(/*m_deviceMap,*/ m_inforesult, m_lvmInfo);
+    LUKSOperator::updateLUKSInfo(m_inforesult,m_lvmInfo,m_luksInfo);
+
+    emit updateDeviceInfo(/*m_deviceMap,*/ m_inforesult, m_lvmInfo,m_luksInfo);
 
-    sendsignals();
     qDebug() << __FILE__ << ":" << __FUNCTION__ << "Someone call me in thread，working done!";
     qDebug() << __FILE__ << "Now I am working on thread:" << QThread::currentThreadId();
 }
